# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/gcsystemmsgs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/gcsystemmsgs.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\'demoparser/protobufs/gcsystemmsgs.proto\"S\n\x1c\x43MsgGCHVacVerificationChange\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x13\n\x0bis_verified\x18\x03 \x01(\x08\"\x80\x01\n\x1f\x43MsgGCHAccountPhoneNumberChange\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x10\n\x08phone_id\x18\x03 \x01(\x04\x12\x13\n\x0bis_verified\x18\x04 \x01(\x08\x12\x16\n\x0eis_identifying\x18\x05 \x01(\x08\"j\n\x18\x43MsgGCHInviteUserToLobby\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x17\n\x0fsteamid_invited\x18\x03 \x01(\x06\x12\x15\n\rsteamid_lobby\x18\x04 \x01(\x06*\xc7\x14\n\x0c\x45GCSystemMsg\x12\x13\n\x0fk_EGCMsgInvalid\x10\x00\x12\x11\n\rk_EGCMsgMulti\x10\x01\x12\x18\n\x14k_EGCMsgGenericReply\x10\n\x12\x16\n\x12k_EGCMsgSystemBase\x10\x32\x12\x1e\n\x1ak_EGCMsgAchievementAwarded\x10\x33\x12\x16\n\x12k_EGCMsgConCommand\x10\x34\x12\x18\n\x14k_EGCMsgStartPlaying\x10\x35\x12\x17\n\x13k_EGCMsgStopPlaying\x10\x36\x12\x1b\n\x17k_EGCMsgStartGameserver\x10\x37\x12\x1a\n\x16k_EGCMsgStopGameserver\x10\x38\x12\x15\n\x11k_EGCMsgWGRequest\x10\x39\x12\x16\n\x12k_EGCMsgWGResponse\x10:\x12\"\n\x1ek_EGCMsgGetUserGameStatsSchema\x10;\x12*\n&k_EGCMsgGetUserGameStatsSchemaResponse\x10<\x12\"\n\x1ek_EGCMsgGetUserStatsDEPRECATED\x10=\x12 \n\x1ck_EGCMsgGetUserStatsResponse\x10>\x12\x1a\n\x16k_EGCMsgAppInfoUpdated\x10?\x12\x1b\n\x17k_EGCMsgValidateSession\x10@\x12#\n\x1fk_EGCMsgValidateSessionResponse\x10\x41\x12\"\n\x1ek_EGCMsgLookupAccountFromInput\x10\x42\x12\x1b\n\x17k_EGCMsgSendHTTPRequest\x10\x43\x12#\n\x1fk_EGCMsgSendHTTPRequestResponse\x10\x44\x12\x18\n\x14k_EGCMsgPreTestSetup\x10\x45\x12\x1f\n\x1bk_EGCMsgRecordSupportAction\x10\x46\x12(\n$k_EGCMsgGetAccountDetails_DEPRECATED\x10G\x12\"\n\x1ek_EGCMsgReceiveInterAppMessage\x10I\x12\x18\n\x14k_EGCMsgFindAccounts\x10J\x12\x15\n\x11k_EGCMsgPostAlert\x10K\x12\x17\n\x13k_EGCMsgGetLicenses\x10L\x12\x18\n\x14k_EGCMsgGetUserStats\x10M\x12\x17\n\x13k_EGCMsgGetCommands\x10N\x12\x1f\n\x1bk_EGCMsgGetCommandsResponse\x10O\x12\x1a\n\x16k_EGCMsgAddFreeLicense\x10P\x12\"\n\x1ek_EGCMsgAddFreeLicenseResponse\x10Q\x12\x19\n\x15k_EGCMsgGetIPLocation\x10R\x12!\n\x1dk_EGCMsgGetIPLocationResponse\x10S\x12\x1d\n\x19k_EGCMsgSystemStatsSchema\x10T\x12\x1a\n\x16k_EGCMsgGetSystemStats\x10U\x12\"\n\x1ek_EGCMsgGetSystemStatsResponse\x10V\x12\x15\n\x11k_EGCMsgSendEmail\x10W\x12\x1d\n\x19k_EGCMsgSendEmailResponse\x10X\x12\x1c\n\x18k_EGCMsgGetEmailTemplate\x10Y\x12$\n k_EGCMsgGetEmailTemplateResponse\x10Z\x12\x1a\n\x16k_EGCMsgGrantGuestPass\x10[\x12\"\n\x1ek_EGCMsgGrantGuestPassResponse\x10\\\x12\x1d\n\x19k_EGCMsgGetAccountDetails\x10]\x12%\n!k_EGCMsgGetAccountDetailsResponse\x10^\x12\x1b\n\x17k_EGCMsgGetPersonaNames\x10_\x12#\n\x1fk_EGCMsgGetPersonaNamesResponse\x10`\x12\x18\n\x14k_EGCMsgMultiplexMsg\x10\x61\x12 \n\x1ck_EGCMsgMultiplexMsgResponse\x10\x62\x12$\n k_EGCMsgWebAPIRegisterInterfaces\x10\x65\x12\x1c\n\x18k_EGCMsgWebAPIJobRequest\x10\x66\x12(\n$k_EGCMsgWebAPIJobRequestHttpResponse\x10h\x12+\n\'k_EGCMsgWebAPIJobRequestForwardResponse\x10i\x12\x19\n\x14k_EGCMsgMemCachedGet\x10\xc8\x01\x12!\n\x1ck_EGCMsgMemCachedGetResponse\x10\xc9\x01\x12\x19\n\x14k_EGCMsgMemCachedSet\x10\xca\x01\x12\x1c\n\x17k_EGCMsgMemCachedDelete\x10\xcb\x01\x12\x1b\n\x16k_EGCMsgMemCachedStats\x10\xcc\x01\x12#\n\x1ek_EGCMsgMemCachedStatsResponse\x10\xcd\x01\x12\x1f\n\x1ak_EGCMsgMasterSetDirectory\x10\xdc\x01\x12\'\n\"k_EGCMsgMasterSetDirectoryResponse\x10\xdd\x01\x12#\n\x1ek_EGCMsgMasterSetWebAPIRouting\x10\xde\x01\x12+\n&k_EGCMsgMasterSetWebAPIRoutingResponse\x10\xdf\x01\x12&\n!k_EGCMsgMasterSetClientMsgRouting\x10\xe0\x01\x12.\n)k_EGCMsgMasterSetClientMsgRoutingResponse\x10\xe1\x01\x12\x17\n\x12k_EGCMsgSetOptions\x10\xe2\x01\x12\x1f\n\x1ak_EGCMsgSetOptionsResponse\x10\xe3\x01\x12\x18\n\x13k_EGCMsgSystemBase2\x10\xf4\x03\x12#\n\x1ek_EGCMsgGetPurchaseTrustStatus\x10\xf5\x03\x12+\n&k_EGCMsgGetPurchaseTrustStatusResponse\x10\xf6\x03\x12\x1a\n\x15k_EGCMsgUpdateSession\x10\xf7\x03\x12%\n k_EGCMsgGCAccountVacStatusChange\x10\xf8\x03\x12\x1c\n\x17k_EGCMsgCheckFriendship\x10\xf9\x03\x12$\n\x1fk_EGCMsgCheckFriendshipResponse\x10\xfa\x03\x12\"\n\x1dk_EGCMsgGetPartnerAccountLink\x10\xfb\x03\x12*\n%k_EGCMsgGetPartnerAccountLinkResponse\x10\xfc\x03\x12\"\n\x1dk_EGCMsgVacVerificationChange\x10\x86\x04\x12%\n k_EGCMsgAccountPhoneNumberChange\x10\x87\x04\x12\x1e\n\x19k_EGCMsgInviteUserToLobby\x10\x8b\x04*\xef\x01\n\x06\x45SOMsg\x12\x13\n\x0fk_ESOMsg_Create\x10\x15\x12\x13\n\x0fk_ESOMsg_Update\x10\x16\x12\x14\n\x10k_ESOMsg_Destroy\x10\x17\x12\x1c\n\x18k_ESOMsg_CacheSubscribed\x10\x18\x12\x1e\n\x1ak_ESOMsg_CacheUnsubscribed\x10\x19\x12\x1b\n\x17k_ESOMsg_UpdateMultiple\x10\x1a\x12#\n\x1fk_ESOMsg_CacheSubscriptionCheck\x10\x1b\x12%\n!k_ESOMsg_CacheSubscriptionRefresh\x10\x1c*\xd9\x02\n\x10\x45GCBaseClientMsg\x12\x1a\n\x15k_EMsgGCClientWelcome\x10\xa4\x1f\x12\x1a\n\x15k_EMsgGCServerWelcome\x10\xa5\x1f\x12\x18\n\x13k_EMsgGCClientHello\x10\xa6\x1f\x12\x18\n\x13k_EMsgGCServerHello\x10\xa7\x1f\x12#\n\x1ek_EMsgGCClientConnectionStatus\x10\xa9\x1f\x12#\n\x1ek_EMsgGCServerConnectionStatus\x10\xaa\x1f\x12\x1f\n\x1ak_EMsgGCClientHelloPartner\x10\xab\x1f\x12\x1a\n\x15k_EMsgGCClientHelloPW\x10\xac\x1f\x12\x1a\n\x15k_EMsgGCClientHelloR2\x10\xad\x1f\x12\x1a\n\x15k_EMsgGCClientHelloR3\x10\xae\x1f\x12\x1a\n\x15k_EMsgGCClientHelloR4\x10\xaf\x1f*\x89\x02\n\nEGCToGCMsg\x12\x1a\n\x15k_EGCToGCMsgMasterAck\x10\x96\x01\x12\"\n\x1dk_EGCToGCMsgMasterAckResponse\x10\x97\x01\x12\x17\n\x12k_EGCToGCMsgRouted\x10\x98\x01\x12\x1c\n\x17k_EGCToGCMsgRoutedReply\x10\x99\x01\x12\x1a\n\x15k_EMsgUpdateSessionIP\x10\x9a\x01\x12\x1b\n\x16k_EMsgRequestSessionIP\x10\x9b\x01\x12#\n\x1ek_EMsgRequestSessionIPResponse\x10\x9c\x01\x12&\n!k_EGCToGCMsgMasterStartupComplete\x10\x9d\x01\x42\x05H\x01\x80\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EGCSYSTEMMSG = _descriptor.EnumDescriptor(
  name='EGCSystemMsg',
  full_name='EGCSystemMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInvalid', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMulti', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGenericReply', index=2, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSystemBase', index=3, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAchievementAwarded', index=4, number=51,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgConCommand', index=5, number=52,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgStartPlaying', index=6, number=53,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgStopPlaying', index=7, number=54,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgStartGameserver', index=8, number=55,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgStopGameserver', index=9, number=56,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWGRequest', index=10, number=57,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWGResponse', index=11, number=58,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserGameStatsSchema', index=12, number=59,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserGameStatsSchemaResponse', index=13, number=60,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserStatsDEPRECATED', index=14, number=61,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserStatsResponse', index=15, number=62,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAppInfoUpdated', index=16, number=63,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgValidateSession', index=17, number=64,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgValidateSessionResponse', index=18, number=65,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgLookupAccountFromInput', index=19, number=66,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSendHTTPRequest', index=20, number=67,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSendHTTPRequestResponse', index=21, number=68,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgPreTestSetup', index=22, number=69,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgRecordSupportAction', index=23, number=70,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetAccountDetails_DEPRECATED', index=24, number=71,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgReceiveInterAppMessage', index=25, number=73,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgFindAccounts', index=26, number=74,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgPostAlert', index=27, number=75,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetLicenses', index=28, number=76,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetUserStats', index=29, number=77,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetCommands', index=30, number=78,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetCommandsResponse', index=31, number=79,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAddFreeLicense', index=32, number=80,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAddFreeLicenseResponse', index=33, number=81,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetIPLocation', index=34, number=82,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetIPLocationResponse', index=35, number=83,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSystemStatsSchema', index=36, number=84,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetSystemStats', index=37, number=85,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetSystemStatsResponse', index=38, number=86,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSendEmail', index=39, number=87,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSendEmailResponse', index=40, number=88,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetEmailTemplate', index=41, number=89,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetEmailTemplateResponse', index=42, number=90,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGrantGuestPass', index=43, number=91,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGrantGuestPassResponse', index=44, number=92,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetAccountDetails', index=45, number=93,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetAccountDetailsResponse', index=46, number=94,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPersonaNames', index=47, number=95,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPersonaNamesResponse', index=48, number=96,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMultiplexMsg', index=49, number=97,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMultiplexMsgResponse', index=50, number=98,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWebAPIRegisterInterfaces', index=51, number=101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWebAPIJobRequest', index=52, number=102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWebAPIJobRequestHttpResponse', index=53, number=104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgWebAPIJobRequestForwardResponse', index=54, number=105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedGet', index=55, number=200,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedGetResponse', index=56, number=201,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedSet', index=57, number=202,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedDelete', index=58, number=203,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedStats', index=59, number=204,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMemCachedStatsResponse', index=60, number=205,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetDirectory', index=61, number=220,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetDirectoryResponse', index=62, number=221,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetWebAPIRouting', index=63, number=222,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetWebAPIRoutingResponse', index=64, number=223,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetClientMsgRouting', index=65, number=224,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgMasterSetClientMsgRoutingResponse', index=66, number=225,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSetOptions', index=67, number=226,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSetOptionsResponse', index=68, number=227,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgSystemBase2', index=69, number=500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPurchaseTrustStatus', index=70, number=501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPurchaseTrustStatusResponse', index=71, number=502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUpdateSession', index=72, number=503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGCAccountVacStatusChange', index=73, number=504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgCheckFriendship', index=74, number=505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgCheckFriendshipResponse', index=75, number=506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPartnerAccountLink', index=76, number=507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgGetPartnerAccountLinkResponse', index=77, number=508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgVacVerificationChange', index=78, number=518,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgAccountPhoneNumberChange', index=79, number=519,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInviteUserToLobby', index=80, number=523,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=368,
  serialized_end=2999,
)
_sym_db.RegisterEnumDescriptor(_EGCSYSTEMMSG)

EGCSystemMsg = enum_type_wrapper.EnumTypeWrapper(_EGCSYSTEMMSG)
_ESOMSG = _descriptor.EnumDescriptor(
  name='ESOMsg',
  full_name='ESOMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_Create', index=0, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_Update', index=1, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_Destroy', index=2, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_CacheSubscribed', index=3, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_CacheUnsubscribed', index=4, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_UpdateMultiple', index=5, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_CacheSubscriptionCheck', index=6, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESOMsg_CacheSubscriptionRefresh', index=7, number=28,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3002,
  serialized_end=3241,
)
_sym_db.RegisterEnumDescriptor(_ESOMSG)

ESOMsg = enum_type_wrapper.EnumTypeWrapper(_ESOMSG)
_EGCBASECLIENTMSG = _descriptor.EnumDescriptor(
  name='EGCBaseClientMsg',
  full_name='EGCBaseClientMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientWelcome', index=0, number=4004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerWelcome', index=1, number=4005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientHello', index=2, number=4006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerHello', index=3, number=4007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientConnectionStatus', index=4, number=4009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerConnectionStatus', index=5, number=4010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientHelloPartner', index=6, number=4011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientHelloPW', index=7, number=4012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientHelloR2', index=8, number=4013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientHelloR3', index=9, number=4014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientHelloR4', index=10, number=4015,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3244,
  serialized_end=3589,
)
_sym_db.RegisterEnumDescriptor(_EGCBASECLIENTMSG)

EGCBaseClientMsg = enum_type_wrapper.EnumTypeWrapper(_EGCBASECLIENTMSG)
_EGCTOGCMSG = _descriptor.EnumDescriptor(
  name='EGCToGCMsg',
  full_name='EGCToGCMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgMasterAck', index=0, number=150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgMasterAckResponse', index=1, number=151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgRouted', index=2, number=152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgRoutedReply', index=3, number=153,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgUpdateSessionIP', index=4, number=154,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRequestSessionIP', index=5, number=155,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgRequestSessionIPResponse', index=6, number=156,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCToGCMsgMasterStartupComplete', index=7, number=157,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3592,
  serialized_end=3857,
)
_sym_db.RegisterEnumDescriptor(_EGCTOGCMSG)

EGCToGCMsg = enum_type_wrapper.EnumTypeWrapper(_EGCTOGCMSG)
k_EGCMsgInvalid = 0
k_EGCMsgMulti = 1
k_EGCMsgGenericReply = 10
k_EGCMsgSystemBase = 50
k_EGCMsgAchievementAwarded = 51
k_EGCMsgConCommand = 52
k_EGCMsgStartPlaying = 53
k_EGCMsgStopPlaying = 54
k_EGCMsgStartGameserver = 55
k_EGCMsgStopGameserver = 56
k_EGCMsgWGRequest = 57
k_EGCMsgWGResponse = 58
k_EGCMsgGetUserGameStatsSchema = 59
k_EGCMsgGetUserGameStatsSchemaResponse = 60
k_EGCMsgGetUserStatsDEPRECATED = 61
k_EGCMsgGetUserStatsResponse = 62
k_EGCMsgAppInfoUpdated = 63
k_EGCMsgValidateSession = 64
k_EGCMsgValidateSessionResponse = 65
k_EGCMsgLookupAccountFromInput = 66
k_EGCMsgSendHTTPRequest = 67
k_EGCMsgSendHTTPRequestResponse = 68
k_EGCMsgPreTestSetup = 69
k_EGCMsgRecordSupportAction = 70
k_EGCMsgGetAccountDetails_DEPRECATED = 71
k_EGCMsgReceiveInterAppMessage = 73
k_EGCMsgFindAccounts = 74
k_EGCMsgPostAlert = 75
k_EGCMsgGetLicenses = 76
k_EGCMsgGetUserStats = 77
k_EGCMsgGetCommands = 78
k_EGCMsgGetCommandsResponse = 79
k_EGCMsgAddFreeLicense = 80
k_EGCMsgAddFreeLicenseResponse = 81
k_EGCMsgGetIPLocation = 82
k_EGCMsgGetIPLocationResponse = 83
k_EGCMsgSystemStatsSchema = 84
k_EGCMsgGetSystemStats = 85
k_EGCMsgGetSystemStatsResponse = 86
k_EGCMsgSendEmail = 87
k_EGCMsgSendEmailResponse = 88
k_EGCMsgGetEmailTemplate = 89
k_EGCMsgGetEmailTemplateResponse = 90
k_EGCMsgGrantGuestPass = 91
k_EGCMsgGrantGuestPassResponse = 92
k_EGCMsgGetAccountDetails = 93
k_EGCMsgGetAccountDetailsResponse = 94
k_EGCMsgGetPersonaNames = 95
k_EGCMsgGetPersonaNamesResponse = 96
k_EGCMsgMultiplexMsg = 97
k_EGCMsgMultiplexMsgResponse = 98
k_EGCMsgWebAPIRegisterInterfaces = 101
k_EGCMsgWebAPIJobRequest = 102
k_EGCMsgWebAPIJobRequestHttpResponse = 104
k_EGCMsgWebAPIJobRequestForwardResponse = 105
k_EGCMsgMemCachedGet = 200
k_EGCMsgMemCachedGetResponse = 201
k_EGCMsgMemCachedSet = 202
k_EGCMsgMemCachedDelete = 203
k_EGCMsgMemCachedStats = 204
k_EGCMsgMemCachedStatsResponse = 205
k_EGCMsgMasterSetDirectory = 220
k_EGCMsgMasterSetDirectoryResponse = 221
k_EGCMsgMasterSetWebAPIRouting = 222
k_EGCMsgMasterSetWebAPIRoutingResponse = 223
k_EGCMsgMasterSetClientMsgRouting = 224
k_EGCMsgMasterSetClientMsgRoutingResponse = 225
k_EGCMsgSetOptions = 226
k_EGCMsgSetOptionsResponse = 227
k_EGCMsgSystemBase2 = 500
k_EGCMsgGetPurchaseTrustStatus = 501
k_EGCMsgGetPurchaseTrustStatusResponse = 502
k_EGCMsgUpdateSession = 503
k_EGCMsgGCAccountVacStatusChange = 504
k_EGCMsgCheckFriendship = 505
k_EGCMsgCheckFriendshipResponse = 506
k_EGCMsgGetPartnerAccountLink = 507
k_EGCMsgGetPartnerAccountLinkResponse = 508
k_EGCMsgVacVerificationChange = 518
k_EGCMsgAccountPhoneNumberChange = 519
k_EGCMsgInviteUserToLobby = 523
k_ESOMsg_Create = 21
k_ESOMsg_Update = 22
k_ESOMsg_Destroy = 23
k_ESOMsg_CacheSubscribed = 24
k_ESOMsg_CacheUnsubscribed = 25
k_ESOMsg_UpdateMultiple = 26
k_ESOMsg_CacheSubscriptionCheck = 27
k_ESOMsg_CacheSubscriptionRefresh = 28
k_EMsgGCClientWelcome = 4004
k_EMsgGCServerWelcome = 4005
k_EMsgGCClientHello = 4006
k_EMsgGCServerHello = 4007
k_EMsgGCClientConnectionStatus = 4009
k_EMsgGCServerConnectionStatus = 4010
k_EMsgGCClientHelloPartner = 4011
k_EMsgGCClientHelloPW = 4012
k_EMsgGCClientHelloR2 = 4013
k_EMsgGCClientHelloR3 = 4014
k_EMsgGCClientHelloR4 = 4015
k_EGCToGCMsgMasterAck = 150
k_EGCToGCMsgMasterAckResponse = 151
k_EGCToGCMsgRouted = 152
k_EGCToGCMsgRoutedReply = 153
k_EMsgUpdateSessionIP = 154
k_EMsgRequestSessionIP = 155
k_EMsgRequestSessionIPResponse = 156
k_EGCToGCMsgMasterStartupComplete = 157



_CMSGGCHVACVERIFICATIONCHANGE = _descriptor.Descriptor(
  name='CMsgGCHVacVerificationChange',
  full_name='CMsgGCHVacVerificationChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgGCHVacVerificationChange.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgGCHVacVerificationChange.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_verified', full_name='CMsgGCHVacVerificationChange.is_verified', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=126,
)


_CMSGGCHACCOUNTPHONENUMBERCHANGE = _descriptor.Descriptor(
  name='CMsgGCHAccountPhoneNumberChange',
  full_name='CMsgGCHAccountPhoneNumberChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgGCHAccountPhoneNumberChange.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgGCHAccountPhoneNumberChange.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone_id', full_name='CMsgGCHAccountPhoneNumberChange.phone_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_verified', full_name='CMsgGCHAccountPhoneNumberChange.is_verified', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_identifying', full_name='CMsgGCHAccountPhoneNumberChange.is_identifying', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=257,
)


_CMSGGCHINVITEUSERTOLOBBY = _descriptor.Descriptor(
  name='CMsgGCHInviteUserToLobby',
  full_name='CMsgGCHInviteUserToLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgGCHInviteUserToLobby.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgGCHInviteUserToLobby.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamid_invited', full_name='CMsgGCHInviteUserToLobby.steamid_invited', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamid_lobby', full_name='CMsgGCHInviteUserToLobby.steamid_lobby', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=365,
)

DESCRIPTOR.message_types_by_name['CMsgGCHVacVerificationChange'] = _CMSGGCHVACVERIFICATIONCHANGE
DESCRIPTOR.message_types_by_name['CMsgGCHAccountPhoneNumberChange'] = _CMSGGCHACCOUNTPHONENUMBERCHANGE
DESCRIPTOR.message_types_by_name['CMsgGCHInviteUserToLobby'] = _CMSGGCHINVITEUSERTOLOBBY
DESCRIPTOR.enum_types_by_name['EGCSystemMsg'] = _EGCSYSTEMMSG
DESCRIPTOR.enum_types_by_name['ESOMsg'] = _ESOMSG
DESCRIPTOR.enum_types_by_name['EGCBaseClientMsg'] = _EGCBASECLIENTMSG
DESCRIPTOR.enum_types_by_name['EGCToGCMsg'] = _EGCTOGCMSG

CMsgGCHVacVerificationChange = _reflection.GeneratedProtocolMessageType('CMsgGCHVacVerificationChange', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCHVACVERIFICATIONCHANGE,
  __module__ = 'demoparser.protobufs.gcsystemmsgs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCHVacVerificationChange)
  ))
_sym_db.RegisterMessage(CMsgGCHVacVerificationChange)

CMsgGCHAccountPhoneNumberChange = _reflection.GeneratedProtocolMessageType('CMsgGCHAccountPhoneNumberChange', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCHACCOUNTPHONENUMBERCHANGE,
  __module__ = 'demoparser.protobufs.gcsystemmsgs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCHAccountPhoneNumberChange)
  ))
_sym_db.RegisterMessage(CMsgGCHAccountPhoneNumberChange)

CMsgGCHInviteUserToLobby = _reflection.GeneratedProtocolMessageType('CMsgGCHInviteUserToLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCHINVITEUSERTOLOBBY,
  __module__ = 'demoparser.protobufs.gcsystemmsgs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCHInviteUserToLobby)
  ))
_sym_db.RegisterMessage(CMsgGCHInviteUserToLobby)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\200\001\000'))
# @@protoc_insertion_point(module_scope)
