# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/gcsdk_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from demoparser.protobufs import steammessages_pb2 as demoparser_dot_protobufs_dot_steammessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/gcsdk_gcmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n+demoparser/protobufs/gcsdk_gcmessages.proto\x1a(demoparser/protobufs/steammessages.proto\")\n\rCMsgSOIDOwner\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\x04\"o\n\x12\x43MsgSOSingleObject\x12\x0f\n\x07type_id\x18\x02 \x01(\x05\x12\x13\n\x0bobject_data\x18\x03 \x01(\x0c\x12\x0f\n\x07version\x18\x04 \x01(\x06\x12\"\n\nowner_soid\x18\x05 \x01(\x0b\x32\x0e.CMsgSOIDOwner\"\xc7\x02\n\x15\x43MsgSOMultipleObjects\x12=\n\x10objects_modified\x18\x02 \x03(\x0b\x32#.CMsgSOMultipleObjects.SingleObject\x12\x0f\n\x07version\x18\x03 \x01(\x06\x12:\n\robjects_added\x18\x04 \x03(\x0b\x32#.CMsgSOMultipleObjects.SingleObject\x12<\n\x0fobjects_removed\x18\x05 \x03(\x0b\x32#.CMsgSOMultipleObjects.SingleObject\x12\"\n\nowner_soid\x18\x06 \x01(\x0b\x32\x0e.CMsgSOIDOwner\x1a@\n\x0cSingleObject\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\x13\n\x0bobject_data\x18\x02 \x01(\x0c:\n\x80\xa6\x1d\x80\x02\x88\xa6\x1d\x80\x08\"\xbc\x01\n\x15\x43MsgSOCacheSubscribed\x12\x36\n\x07objects\x18\x02 \x03(\x0b\x32%.CMsgSOCacheSubscribed.SubscribedType\x12\x0f\n\x07version\x18\x03 \x01(\x06\x12\"\n\nowner_soid\x18\x04 \x01(\x0b\x32\x0e.CMsgSOIDOwner\x1a\x36\n\x0eSubscribedType\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\x13\n\x0bobject_data\x18\x02 \x03(\x0c\"=\n\x17\x43MsgSOCacheUnsubscribed\x12\"\n\nowner_soid\x18\x02 \x01(\x0b\x32\x0e.CMsgSOIDOwner\"S\n\x1c\x43MsgSOCacheSubscriptionCheck\x12\x0f\n\x07version\x18\x02 \x01(\x06\x12\"\n\nowner_soid\x18\x03 \x01(\x0b\x32\x0e.CMsgSOIDOwner\"D\n\x1e\x43MsgSOCacheSubscriptionRefresh\x12\"\n\nowner_soid\x18\x02 \x01(\x0b\x32\x0e.CMsgSOIDOwner\"%\n\x12\x43MsgSOCacheVersion\x12\x0f\n\x07version\x18\x01 \x01(\x06\"\xa8\x03\n\x12\x43MsgAccountDetails\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x16\n\x0epublic_profile\x18\x04 \x01(\x08\x12\x18\n\x10public_inventory\x18\x05 \x01(\x08\x12\x12\n\nvac_banned\x18\x06 \x01(\x08\x12\x12\n\ncyber_cafe\x18\x07 \x01(\x08\x12\x16\n\x0eschool_account\x18\x08 \x01(\x08\x12\x1a\n\x12\x66ree_trial_account\x18\t \x01(\x08\x12\x12\n\nsubscribed\x18\n \x01(\x08\x12\x14\n\x0clow_violence\x18\x0b \x01(\x08\x12\x0f\n\x07limited\x18\x0c \x01(\x08\x12\x0f\n\x07trusted\x18\r \x01(\x08\x12\x0f\n\x07package\x18\x0e \x01(\r\x12\x13\n\x0btime_cached\x18\x0f \x01(\x07\x12\x16\n\x0e\x61\x63\x63ount_locked\x18\x10 \x01(\x08\x12\x18\n\x10\x63ommunity_banned\x18\x11 \x01(\x08\x12\x14\n\x0ctrade_banned\x18\x12 \x01(\x08\x12%\n\x1d\x65ligible_for_community_market\x18\x13 \x01(\x08\"_\n\x16\x43MsgGCMultiplexMessage\x12\x0f\n\x07msgtype\x18\x01 \x01(\r\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08steamids\x18\x03 \x03(\x06\x12\x11\n\treplytogc\x18\x04 \x01(\x08\"2\n\x1f\x43MsgGCMultiplexMessage_Response\x12\x0f\n\x07msgtype\x18\x01 \x01(\r\"9\n\x13\x43GCToGCMsgMasterAck\x12\x11\n\tdir_index\x18\x01 \x01(\r\x12\x0f\n\x07gc_type\x18\x02 \x01(\r\"2\n\x1c\x43GCToGCMsgMasterAck_Response\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"!\n\x1f\x43GCToGCMsgMasterStartupComplete\"L\n\x10\x43GCToGCMsgRouted\x12\x10\n\x08msg_type\x18\x01 \x01(\r\x12\x11\n\tsender_id\x18\x02 \x01(\x06\x12\x13\n\x0bnet_message\x18\x03 \x01(\x0c\">\n\x15\x43GCToGCMsgRoutedReply\x12\x10\n\x08msg_type\x18\x01 \x01(\r\x12\x13\n\x0bnet_message\x18\x02 \x01(\x0c\"4\n\x15\x43MsgGCUpdateSessionIP\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\n\n\x02ip\x18\x02 \x01(\x07\")\n\x16\x43MsgGCRequestSessionIP\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\",\n\x1e\x43MsgGCRequestSessionIPResponse\x12\n\n\x02ip\x18\x01 \x01(\x07\"G\n\x16\x43MsgSOCacheHaveVersion\x12\x1c\n\x04soid\x18\x01 \x01(\x0b\x32\x0e.CMsgSOIDOwner\x12\x0f\n\x07version\x18\x02 \x01(\x06\"\xe0\x01\n\x0f\x43MsgClientHello\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x36\n\x15socache_have_versions\x18\x02 \x03(\x0b\x32\x17.CMsgSOCacheHaveVersion\x12\x1b\n\x13\x63lient_session_need\x18\x03 \x01(\r\x12\x17\n\x0f\x63lient_launcher\x18\x04 \x01(\r\x12\x15\n\rpartner_srcid\x18\x05 \x01(\r\x12\x19\n\x11partner_accountid\x18\x06 \x01(\r\x12\x1c\n\x14partner_accountflags\x18\x07 \x01(\r\"\xb3\x01\n\x0f\x43MsgServerHello\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x36\n\x15socache_have_versions\x18\x02 \x03(\x0b\x32\x17.CMsgSOCacheHaveVersion\x12\"\n\x1alegacy_client_session_need\x18\x03 \x01(\r\x12\x17\n\x0f\x63lient_launcher\x18\x04 \x01(\r\x12\x1a\n\x12steamdatagram_port\x18\x05 \x01(\r\"\xf4\x02\n\x11\x43MsgClientWelcome\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x11\n\tgame_data\x18\x02 \x01(\x0c\x12;\n\x1boutofdate_subscribed_caches\x18\x03 \x03(\x0b\x32\x16.CMsgSOCacheSubscribed\x12\x41\n\x1auptodate_subscribed_caches\x18\x04 \x03(\x0b\x32\x1d.CMsgSOCacheSubscriptionCheck\x12-\n\x08location\x18\x05 \x01(\x0b\x32\x1b.CMsgClientWelcome.Location\x12\x12\n\ngame_data2\x18\x06 \x01(\x0c\x12$\n\x1crtime32_gc_welcome_timestamp\x18\x07 \x01(\r\x12\x10\n\x08\x63urrency\x18\x08 \x01(\r\x1a@\n\x08Location\x12\x10\n\x08latitude\x18\x01 \x01(\x02\x12\x11\n\tlongitude\x18\x02 \x01(\x02\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\"\xe5\x01\n\x14\x43MsgConnectionStatus\x12\x44\n\x06status\x18\x01 \x01(\x0e\x32\x13.GCConnectionStatus:\x1fGCConnectionStatus_HAVE_SESSION\x12\x1b\n\x13\x63lient_session_need\x18\x02 \x01(\r\x12\x16\n\x0equeue_position\x18\x03 \x01(\x05\x12\x12\n\nqueue_size\x18\x04 \x01(\x05\x12\x14\n\x0cwait_seconds\x18\x05 \x01(\x05\x12(\n estimated_wait_seconds_remaining\x18\x06 \x01(\x05\"\x86\x03\n*CWorkshop_PopulateItemDescriptions_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\\\n\tlanguages\x18\x02 \x03(\x0b\x32I.CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock\x1a^\n\x15SingleItemDescription\x12\x12\n\ngameitemid\x18\x01 \x01(\r\x12\x18\n\x10item_description\x18\x02 \x01(\t\x12\x17\n\x0fone_per_account\x18\x03 \x01(\x08\x1a\x8a\x01\n\x1dItemDescriptionsLanguageBlock\x12\x10\n\x08language\x18\x01 \x01(\t\x12W\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32\x41.CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription\"F\n!CWorkshop_GetContributors_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\ngameitemid\x18\x02 \x01(\r\":\n\"CWorkshop_GetContributors_Response\x12\x14\n\x0c\x63ontributors\x18\x01 \x03(\x06\"\xd5\x03\n%CWorkshop_SetItemPaymentRules_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\ngameitemid\x18\x02 \x01(\r\x12\x61\n\x19\x61ssociated_workshop_files\x18\x03 \x03(\x0b\x32>.CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule\x12W\n\x10partner_accounts\x18\x04 \x03(\x0b\x32=.CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule\x1ai\n\x17WorkshopItemPaymentRule\x12\x18\n\x10workshop_file_id\x18\x01 \x01(\x04\x12\x1a\n\x12revenue_percentage\x18\x02 \x01(\x02\x12\x18\n\x10rule_description\x18\x03 \x01(\t\x1a\x62\n\x16PartnerItemPaymentRule\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x1a\n\x12revenue_percentage\x18\x02 \x01(\x02\x12\x18\n\x10rule_description\x18\x03 \x01(\t\"(\n&CWorkshop_SetItemPaymentRules_Response*_\n\x14GCClientLauncherType\x12 \n\x1cGCClientLauncherType_DEFAULT\x10\x00\x12%\n!GCClientLauncherType_PERFECTWORLD\x10\x01*\xd5\x01\n\x12GCConnectionStatus\x12#\n\x1fGCConnectionStatus_HAVE_SESSION\x10\x00\x12$\n GCConnectionStatus_GC_GOING_DOWN\x10\x01\x12!\n\x1dGCConnectionStatus_NO_SESSION\x10\x02\x12\x30\n,GCConnectionStatus_NO_SESSION_IN_LOGON_QUEUE\x10\x03\x12\x1f\n\x1bGCConnectionStatus_NO_STEAM\x10\x04\x42\x05H\x01\x80\x01\x00')
  ,
  dependencies=[demoparser_dot_protobufs_dot_steammessages__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_GCCLIENTLAUNCHERTYPE = _descriptor.EnumDescriptor(
  name='GCClientLauncherType',
  full_name='GCClientLauncherType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GCClientLauncherType_DEFAULT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCClientLauncherType_PERFECTWORLD', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4158,
  serialized_end=4253,
)
_sym_db.RegisterEnumDescriptor(_GCCLIENTLAUNCHERTYPE)

GCClientLauncherType = enum_type_wrapper.EnumTypeWrapper(_GCCLIENTLAUNCHERTYPE)
_GCCONNECTIONSTATUS = _descriptor.EnumDescriptor(
  name='GCConnectionStatus',
  full_name='GCConnectionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_HAVE_SESSION', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_GC_GOING_DOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_NO_SESSION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_NO_SESSION_IN_LOGON_QUEUE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_NO_STEAM', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4256,
  serialized_end=4469,
)
_sym_db.RegisterEnumDescriptor(_GCCONNECTIONSTATUS)

GCConnectionStatus = enum_type_wrapper.EnumTypeWrapper(_GCCONNECTIONSTATUS)
GCClientLauncherType_DEFAULT = 0
GCClientLauncherType_PERFECTWORLD = 1
GCConnectionStatus_HAVE_SESSION = 0
GCConnectionStatus_GC_GOING_DOWN = 1
GCConnectionStatus_NO_SESSION = 2
GCConnectionStatus_NO_SESSION_IN_LOGON_QUEUE = 3
GCConnectionStatus_NO_STEAM = 4



_CMSGSOIDOWNER = _descriptor.Descriptor(
  name='CMsgSOIDOwner',
  full_name='CMsgSOIDOwner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgSOIDOwner.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgSOIDOwner.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=130,
)


_CMSGSOSINGLEOBJECT = _descriptor.Descriptor(
  name='CMsgSOSingleObject',
  full_name='CMsgSOSingleObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_id', full_name='CMsgSOSingleObject.type_id', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='CMsgSOSingleObject.object_data', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgSOSingleObject.version', index=2,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='CMsgSOSingleObject.owner_soid', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=243,
)


_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT = _descriptor.Descriptor(
  name='SingleObject',
  full_name='CMsgSOMultipleObjects.SingleObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_id', full_name='CMsgSOMultipleObjects.SingleObject.type_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='CMsgSOMultipleObjects.SingleObject.object_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\200\246\035\200\002\210\246\035\200\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=573,
)

_CMSGSOMULTIPLEOBJECTS = _descriptor.Descriptor(
  name='CMsgSOMultipleObjects',
  full_name='CMsgSOMultipleObjects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects_modified', full_name='CMsgSOMultipleObjects.objects_modified', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgSOMultipleObjects.version', index=1,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='objects_added', full_name='CMsgSOMultipleObjects.objects_added', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='objects_removed', full_name='CMsgSOMultipleObjects.objects_removed', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='CMsgSOMultipleObjects.owner_soid', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=573,
)


_CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE = _descriptor.Descriptor(
  name='SubscribedType',
  full_name='CMsgSOCacheSubscribed.SubscribedType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_id', full_name='CMsgSOCacheSubscribed.SubscribedType.type_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='CMsgSOCacheSubscribed.SubscribedType.object_data', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=764,
)

_CMSGSOCACHESUBSCRIBED = _descriptor.Descriptor(
  name='CMsgSOCacheSubscribed',
  full_name='CMsgSOCacheSubscribed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='CMsgSOCacheSubscribed.objects', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgSOCacheSubscribed.version', index=1,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='CMsgSOCacheSubscribed.owner_soid', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=764,
)


_CMSGSOCACHEUNSUBSCRIBED = _descriptor.Descriptor(
  name='CMsgSOCacheUnsubscribed',
  full_name='CMsgSOCacheUnsubscribed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='CMsgSOCacheUnsubscribed.owner_soid', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=827,
)


_CMSGSOCACHESUBSCRIPTIONCHECK = _descriptor.Descriptor(
  name='CMsgSOCacheSubscriptionCheck',
  full_name='CMsgSOCacheSubscriptionCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgSOCacheSubscriptionCheck.version', index=0,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='CMsgSOCacheSubscriptionCheck.owner_soid', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=912,
)


_CMSGSOCACHESUBSCRIPTIONREFRESH = _descriptor.Descriptor(
  name='CMsgSOCacheSubscriptionRefresh',
  full_name='CMsgSOCacheSubscriptionRefresh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='CMsgSOCacheSubscriptionRefresh.owner_soid', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=914,
  serialized_end=982,
)


_CMSGSOCACHEVERSION = _descriptor.Descriptor(
  name='CMsgSOCacheVersion',
  full_name='CMsgSOCacheVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgSOCacheVersion.version', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1021,
)


_CMSGACCOUNTDETAILS = _descriptor.Descriptor(
  name='CMsgAccountDetails',
  full_name='CMsgAccountDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='CMsgAccountDetails.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='CMsgAccountDetails.account_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_profile', full_name='CMsgAccountDetails.public_profile', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_inventory', full_name='CMsgAccountDetails.public_inventory', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vac_banned', full_name='CMsgAccountDetails.vac_banned', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cyber_cafe', full_name='CMsgAccountDetails.cyber_cafe', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='school_account', full_name='CMsgAccountDetails.school_account', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='free_trial_account', full_name='CMsgAccountDetails.free_trial_account', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscribed', full_name='CMsgAccountDetails.subscribed', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_violence', full_name='CMsgAccountDetails.low_violence', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limited', full_name='CMsgAccountDetails.limited', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trusted', full_name='CMsgAccountDetails.trusted', index=11,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='package', full_name='CMsgAccountDetails.package', index=12,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_cached', full_name='CMsgAccountDetails.time_cached', index=13,
      number=15, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_locked', full_name='CMsgAccountDetails.account_locked', index=14,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='community_banned', full_name='CMsgAccountDetails.community_banned', index=15,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trade_banned', full_name='CMsgAccountDetails.trade_banned', index=16,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eligible_for_community_market', full_name='CMsgAccountDetails.eligible_for_community_market', index=17,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1448,
)


_CMSGGCMULTIPLEXMESSAGE = _descriptor.Descriptor(
  name='CMsgGCMultiplexMessage',
  full_name='CMsgGCMultiplexMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msgtype', full_name='CMsgGCMultiplexMessage.msgtype', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payload', full_name='CMsgGCMultiplexMessage.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamids', full_name='CMsgGCMultiplexMessage.steamids', index=2,
      number=3, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replytogc', full_name='CMsgGCMultiplexMessage.replytogc', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1450,
  serialized_end=1545,
)


_CMSGGCMULTIPLEXMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CMsgGCMultiplexMessage_Response',
  full_name='CMsgGCMultiplexMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msgtype', full_name='CMsgGCMultiplexMessage_Response.msgtype', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=1597,
)


_CGCTOGCMSGMASTERACK = _descriptor.Descriptor(
  name='CGCToGCMsgMasterAck',
  full_name='CGCToGCMsgMasterAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dir_index', full_name='CGCToGCMsgMasterAck.dir_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gc_type', full_name='CGCToGCMsgMasterAck.gc_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1599,
  serialized_end=1656,
)


_CGCTOGCMSGMASTERACK_RESPONSE = _descriptor.Descriptor(
  name='CGCToGCMsgMasterAck_Response',
  full_name='CGCToGCMsgMasterAck_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CGCToGCMsgMasterAck_Response.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1708,
)


_CGCTOGCMSGMASTERSTARTUPCOMPLETE = _descriptor.Descriptor(
  name='CGCToGCMsgMasterStartupComplete',
  full_name='CGCToGCMsgMasterStartupComplete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1710,
  serialized_end=1743,
)


_CGCTOGCMSGROUTED = _descriptor.Descriptor(
  name='CGCToGCMsgRouted',
  full_name='CGCToGCMsgRouted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='CGCToGCMsgRouted.msg_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='CGCToGCMsgRouted.sender_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='net_message', full_name='CGCToGCMsgRouted.net_message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1745,
  serialized_end=1821,
)


_CGCTOGCMSGROUTEDREPLY = _descriptor.Descriptor(
  name='CGCToGCMsgRoutedReply',
  full_name='CGCToGCMsgRoutedReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='CGCToGCMsgRoutedReply.msg_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='net_message', full_name='CGCToGCMsgRoutedReply.net_message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1823,
  serialized_end=1885,
)


_CMSGGCUPDATESESSIONIP = _descriptor.Descriptor(
  name='CMsgGCUpdateSessionIP',
  full_name='CMsgGCUpdateSessionIP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgGCUpdateSessionIP.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='CMsgGCUpdateSessionIP.ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1887,
  serialized_end=1939,
)


_CMSGGCREQUESTSESSIONIP = _descriptor.Descriptor(
  name='CMsgGCRequestSessionIP',
  full_name='CMsgGCRequestSessionIP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgGCRequestSessionIP.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1941,
  serialized_end=1982,
)


_CMSGGCREQUESTSESSIONIPRESPONSE = _descriptor.Descriptor(
  name='CMsgGCRequestSessionIPResponse',
  full_name='CMsgGCRequestSessionIPResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='CMsgGCRequestSessionIPResponse.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1984,
  serialized_end=2028,
)


_CMSGSOCACHEHAVEVERSION = _descriptor.Descriptor(
  name='CMsgSOCacheHaveVersion',
  full_name='CMsgSOCacheHaveVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='soid', full_name='CMsgSOCacheHaveVersion.soid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgSOCacheHaveVersion.version', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2030,
  serialized_end=2101,
)


_CMSGCLIENTHELLO = _descriptor.Descriptor(
  name='CMsgClientHello',
  full_name='CMsgClientHello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgClientHello.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='socache_have_versions', full_name='CMsgClientHello.socache_have_versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_session_need', full_name='CMsgClientHello.client_session_need', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_launcher', full_name='CMsgClientHello.client_launcher', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_srcid', full_name='CMsgClientHello.partner_srcid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_accountid', full_name='CMsgClientHello.partner_accountid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_accountflags', full_name='CMsgClientHello.partner_accountflags', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2104,
  serialized_end=2328,
)


_CMSGSERVERHELLO = _descriptor.Descriptor(
  name='CMsgServerHello',
  full_name='CMsgServerHello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgServerHello.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='socache_have_versions', full_name='CMsgServerHello.socache_have_versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='legacy_client_session_need', full_name='CMsgServerHello.legacy_client_session_need', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_launcher', full_name='CMsgServerHello.client_launcher', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamdatagram_port', full_name='CMsgServerHello.steamdatagram_port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2331,
  serialized_end=2510,
)


_CMSGCLIENTWELCOME_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='CMsgClientWelcome.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='CMsgClientWelcome.Location.latitude', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='CMsgClientWelcome.Location.longitude', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country', full_name='CMsgClientWelcome.Location.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2821,
  serialized_end=2885,
)

_CMSGCLIENTWELCOME = _descriptor.Descriptor(
  name='CMsgClientWelcome',
  full_name='CMsgClientWelcome',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgClientWelcome.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_data', full_name='CMsgClientWelcome.game_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outofdate_subscribed_caches', full_name='CMsgClientWelcome.outofdate_subscribed_caches', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uptodate_subscribed_caches', full_name='CMsgClientWelcome.uptodate_subscribed_caches', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='CMsgClientWelcome.location', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_data2', full_name='CMsgClientWelcome.game_data2', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rtime32_gc_welcome_timestamp', full_name='CMsgClientWelcome.rtime32_gc_welcome_timestamp', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgClientWelcome.currency', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTWELCOME_LOCATION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2513,
  serialized_end=2885,
)


_CMSGCONNECTIONSTATUS = _descriptor.Descriptor(
  name='CMsgConnectionStatus',
  full_name='CMsgConnectionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgConnectionStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_session_need', full_name='CMsgConnectionStatus.client_session_need', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queue_position', full_name='CMsgConnectionStatus.queue_position', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queue_size', full_name='CMsgConnectionStatus.queue_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wait_seconds', full_name='CMsgConnectionStatus.wait_seconds', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='estimated_wait_seconds_remaining', full_name='CMsgConnectionStatus.estimated_wait_seconds_remaining', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2888,
  serialized_end=3117,
)


_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION = _descriptor.Descriptor(
  name='SingleItemDescription',
  full_name='CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gameitemid', full_name='CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription.gameitemid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_description', full_name='CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription.item_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='one_per_account', full_name='CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription.one_per_account', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3275,
  serialized_end=3369,
)

_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK = _descriptor.Descriptor(
  name='ItemDescriptionsLanguageBlock',
  full_name='CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock.descriptions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3372,
  serialized_end=3510,
)

_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST = _descriptor.Descriptor(
  name='CWorkshop_PopulateItemDescriptions_Request',
  full_name='CWorkshop_PopulateItemDescriptions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CWorkshop_PopulateItemDescriptions_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='languages', full_name='CWorkshop_PopulateItemDescriptions_Request.languages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION, _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3120,
  serialized_end=3510,
)


_CWORKSHOP_GETCONTRIBUTORS_REQUEST = _descriptor.Descriptor(
  name='CWorkshop_GetContributors_Request',
  full_name='CWorkshop_GetContributors_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CWorkshop_GetContributors_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameitemid', full_name='CWorkshop_GetContributors_Request.gameitemid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3512,
  serialized_end=3582,
)


_CWORKSHOP_GETCONTRIBUTORS_RESPONSE = _descriptor.Descriptor(
  name='CWorkshop_GetContributors_Response',
  full_name='CWorkshop_GetContributors_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contributors', full_name='CWorkshop_GetContributors_Response.contributors', index=0,
      number=1, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3584,
  serialized_end=3642,
)


_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE = _descriptor.Descriptor(
  name='WorkshopItemPaymentRule',
  full_name='CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workshop_file_id', full_name='CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule.workshop_file_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revenue_percentage', full_name='CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule.revenue_percentage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rule_description', full_name='CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule.rule_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3909,
  serialized_end=4014,
)

_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE = _descriptor.Descriptor(
  name='PartnerItemPaymentRule',
  full_name='CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revenue_percentage', full_name='CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule.revenue_percentage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rule_description', full_name='CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule.rule_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4016,
  serialized_end=4114,
)

_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST = _descriptor.Descriptor(
  name='CWorkshop_SetItemPaymentRules_Request',
  full_name='CWorkshop_SetItemPaymentRules_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CWorkshop_SetItemPaymentRules_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameitemid', full_name='CWorkshop_SetItemPaymentRules_Request.gameitemid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='associated_workshop_files', full_name='CWorkshop_SetItemPaymentRules_Request.associated_workshop_files', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_accounts', full_name='CWorkshop_SetItemPaymentRules_Request.partner_accounts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE, _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3645,
  serialized_end=4114,
)


_CWORKSHOP_SETITEMPAYMENTRULES_RESPONSE = _descriptor.Descriptor(
  name='CWorkshop_SetItemPaymentRules_Response',
  full_name='CWorkshop_SetItemPaymentRules_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4116,
  serialized_end=4156,
)

_CMSGSOSINGLEOBJECT.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT.containing_type = _CMSGSOMULTIPLEOBJECTS
_CMSGSOMULTIPLEOBJECTS.fields_by_name['objects_modified'].message_type = _CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT
_CMSGSOMULTIPLEOBJECTS.fields_by_name['objects_added'].message_type = _CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT
_CMSGSOMULTIPLEOBJECTS.fields_by_name['objects_removed'].message_type = _CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT
_CMSGSOMULTIPLEOBJECTS.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE.containing_type = _CMSGSOCACHESUBSCRIBED
_CMSGSOCACHESUBSCRIBED.fields_by_name['objects'].message_type = _CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE
_CMSGSOCACHESUBSCRIBED.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHEUNSUBSCRIBED.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHESUBSCRIPTIONCHECK.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHESUBSCRIPTIONREFRESH.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHEHAVEVERSION.fields_by_name['soid'].message_type = _CMSGSOIDOWNER
_CMSGCLIENTHELLO.fields_by_name['socache_have_versions'].message_type = _CMSGSOCACHEHAVEVERSION
_CMSGSERVERHELLO.fields_by_name['socache_have_versions'].message_type = _CMSGSOCACHEHAVEVERSION
_CMSGCLIENTWELCOME_LOCATION.containing_type = _CMSGCLIENTWELCOME
_CMSGCLIENTWELCOME.fields_by_name['outofdate_subscribed_caches'].message_type = _CMSGSOCACHESUBSCRIBED
_CMSGCLIENTWELCOME.fields_by_name['uptodate_subscribed_caches'].message_type = _CMSGSOCACHESUBSCRIPTIONCHECK
_CMSGCLIENTWELCOME.fields_by_name['location'].message_type = _CMSGCLIENTWELCOME_LOCATION
_CMSGCONNECTIONSTATUS.fields_by_name['status'].enum_type = _GCCONNECTIONSTATUS
_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION.containing_type = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST
_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK.fields_by_name['descriptions'].message_type = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION
_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK.containing_type = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST
_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST.fields_by_name['languages'].message_type = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK
_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE.containing_type = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST
_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE.containing_type = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST
_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST.fields_by_name['associated_workshop_files'].message_type = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE
_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST.fields_by_name['partner_accounts'].message_type = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE
DESCRIPTOR.message_types_by_name['CMsgSOIDOwner'] = _CMSGSOIDOWNER
DESCRIPTOR.message_types_by_name['CMsgSOSingleObject'] = _CMSGSOSINGLEOBJECT
DESCRIPTOR.message_types_by_name['CMsgSOMultipleObjects'] = _CMSGSOMULTIPLEOBJECTS
DESCRIPTOR.message_types_by_name['CMsgSOCacheSubscribed'] = _CMSGSOCACHESUBSCRIBED
DESCRIPTOR.message_types_by_name['CMsgSOCacheUnsubscribed'] = _CMSGSOCACHEUNSUBSCRIBED
DESCRIPTOR.message_types_by_name['CMsgSOCacheSubscriptionCheck'] = _CMSGSOCACHESUBSCRIPTIONCHECK
DESCRIPTOR.message_types_by_name['CMsgSOCacheSubscriptionRefresh'] = _CMSGSOCACHESUBSCRIPTIONREFRESH
DESCRIPTOR.message_types_by_name['CMsgSOCacheVersion'] = _CMSGSOCACHEVERSION
DESCRIPTOR.message_types_by_name['CMsgAccountDetails'] = _CMSGACCOUNTDETAILS
DESCRIPTOR.message_types_by_name['CMsgGCMultiplexMessage'] = _CMSGGCMULTIPLEXMESSAGE
DESCRIPTOR.message_types_by_name['CMsgGCMultiplexMessage_Response'] = _CMSGGCMULTIPLEXMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CGCToGCMsgMasterAck'] = _CGCTOGCMSGMASTERACK
DESCRIPTOR.message_types_by_name['CGCToGCMsgMasterAck_Response'] = _CGCTOGCMSGMASTERACK_RESPONSE
DESCRIPTOR.message_types_by_name['CGCToGCMsgMasterStartupComplete'] = _CGCTOGCMSGMASTERSTARTUPCOMPLETE
DESCRIPTOR.message_types_by_name['CGCToGCMsgRouted'] = _CGCTOGCMSGROUTED
DESCRIPTOR.message_types_by_name['CGCToGCMsgRoutedReply'] = _CGCTOGCMSGROUTEDREPLY
DESCRIPTOR.message_types_by_name['CMsgGCUpdateSessionIP'] = _CMSGGCUPDATESESSIONIP
DESCRIPTOR.message_types_by_name['CMsgGCRequestSessionIP'] = _CMSGGCREQUESTSESSIONIP
DESCRIPTOR.message_types_by_name['CMsgGCRequestSessionIPResponse'] = _CMSGGCREQUESTSESSIONIPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgSOCacheHaveVersion'] = _CMSGSOCACHEHAVEVERSION
DESCRIPTOR.message_types_by_name['CMsgClientHello'] = _CMSGCLIENTHELLO
DESCRIPTOR.message_types_by_name['CMsgServerHello'] = _CMSGSERVERHELLO
DESCRIPTOR.message_types_by_name['CMsgClientWelcome'] = _CMSGCLIENTWELCOME
DESCRIPTOR.message_types_by_name['CMsgConnectionStatus'] = _CMSGCONNECTIONSTATUS
DESCRIPTOR.message_types_by_name['CWorkshop_PopulateItemDescriptions_Request'] = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST
DESCRIPTOR.message_types_by_name['CWorkshop_GetContributors_Request'] = _CWORKSHOP_GETCONTRIBUTORS_REQUEST
DESCRIPTOR.message_types_by_name['CWorkshop_GetContributors_Response'] = _CWORKSHOP_GETCONTRIBUTORS_RESPONSE
DESCRIPTOR.message_types_by_name['CWorkshop_SetItemPaymentRules_Request'] = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST
DESCRIPTOR.message_types_by_name['CWorkshop_SetItemPaymentRules_Response'] = _CWORKSHOP_SETITEMPAYMENTRULES_RESPONSE
DESCRIPTOR.enum_types_by_name['GCClientLauncherType'] = _GCCLIENTLAUNCHERTYPE
DESCRIPTOR.enum_types_by_name['GCConnectionStatus'] = _GCCONNECTIONSTATUS

CMsgSOIDOwner = _reflection.GeneratedProtocolMessageType('CMsgSOIDOwner', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOIDOWNER,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOIDOwner)
  ))
_sym_db.RegisterMessage(CMsgSOIDOwner)

CMsgSOSingleObject = _reflection.GeneratedProtocolMessageType('CMsgSOSingleObject', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOSINGLEOBJECT,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOSingleObject)
  ))
_sym_db.RegisterMessage(CMsgSOSingleObject)

CMsgSOMultipleObjects = _reflection.GeneratedProtocolMessageType('CMsgSOMultipleObjects', (_message.Message,), dict(

  SingleObject = _reflection.GeneratedProtocolMessageType('SingleObject', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT,
    __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSOMultipleObjects.SingleObject)
    ))
  ,
  DESCRIPTOR = _CMSGSOMULTIPLEOBJECTS,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOMultipleObjects)
  ))
_sym_db.RegisterMessage(CMsgSOMultipleObjects)
_sym_db.RegisterMessage(CMsgSOMultipleObjects.SingleObject)

CMsgSOCacheSubscribed = _reflection.GeneratedProtocolMessageType('CMsgSOCacheSubscribed', (_message.Message,), dict(

  SubscribedType = _reflection.GeneratedProtocolMessageType('SubscribedType', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE,
    __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSOCacheSubscribed.SubscribedType)
    ))
  ,
  DESCRIPTOR = _CMSGSOCACHESUBSCRIBED,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOCacheSubscribed)
  ))
_sym_db.RegisterMessage(CMsgSOCacheSubscribed)
_sym_db.RegisterMessage(CMsgSOCacheSubscribed.SubscribedType)

CMsgSOCacheUnsubscribed = _reflection.GeneratedProtocolMessageType('CMsgSOCacheUnsubscribed', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHEUNSUBSCRIBED,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOCacheUnsubscribed)
  ))
_sym_db.RegisterMessage(CMsgSOCacheUnsubscribed)

CMsgSOCacheSubscriptionCheck = _reflection.GeneratedProtocolMessageType('CMsgSOCacheSubscriptionCheck', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHESUBSCRIPTIONCHECK,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOCacheSubscriptionCheck)
  ))
_sym_db.RegisterMessage(CMsgSOCacheSubscriptionCheck)

CMsgSOCacheSubscriptionRefresh = _reflection.GeneratedProtocolMessageType('CMsgSOCacheSubscriptionRefresh', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHESUBSCRIPTIONREFRESH,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOCacheSubscriptionRefresh)
  ))
_sym_db.RegisterMessage(CMsgSOCacheSubscriptionRefresh)

CMsgSOCacheVersion = _reflection.GeneratedProtocolMessageType('CMsgSOCacheVersion', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHEVERSION,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOCacheVersion)
  ))
_sym_db.RegisterMessage(CMsgSOCacheVersion)

CMsgAccountDetails = _reflection.GeneratedProtocolMessageType('CMsgAccountDetails', (_message.Message,), dict(
  DESCRIPTOR = _CMSGACCOUNTDETAILS,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAccountDetails)
  ))
_sym_db.RegisterMessage(CMsgAccountDetails)

CMsgGCMultiplexMessage = _reflection.GeneratedProtocolMessageType('CMsgGCMultiplexMessage', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCMULTIPLEXMESSAGE,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCMultiplexMessage)
  ))
_sym_db.RegisterMessage(CMsgGCMultiplexMessage)

CMsgGCMultiplexMessage_Response = _reflection.GeneratedProtocolMessageType('CMsgGCMultiplexMessage_Response', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCMULTIPLEXMESSAGE_RESPONSE,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCMultiplexMessage_Response)
  ))
_sym_db.RegisterMessage(CMsgGCMultiplexMessage_Response)

CGCToGCMsgMasterAck = _reflection.GeneratedProtocolMessageType('CGCToGCMsgMasterAck', (_message.Message,), dict(
  DESCRIPTOR = _CGCTOGCMSGMASTERACK,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CGCToGCMsgMasterAck)
  ))
_sym_db.RegisterMessage(CGCToGCMsgMasterAck)

CGCToGCMsgMasterAck_Response = _reflection.GeneratedProtocolMessageType('CGCToGCMsgMasterAck_Response', (_message.Message,), dict(
  DESCRIPTOR = _CGCTOGCMSGMASTERACK_RESPONSE,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CGCToGCMsgMasterAck_Response)
  ))
_sym_db.RegisterMessage(CGCToGCMsgMasterAck_Response)

CGCToGCMsgMasterStartupComplete = _reflection.GeneratedProtocolMessageType('CGCToGCMsgMasterStartupComplete', (_message.Message,), dict(
  DESCRIPTOR = _CGCTOGCMSGMASTERSTARTUPCOMPLETE,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CGCToGCMsgMasterStartupComplete)
  ))
_sym_db.RegisterMessage(CGCToGCMsgMasterStartupComplete)

CGCToGCMsgRouted = _reflection.GeneratedProtocolMessageType('CGCToGCMsgRouted', (_message.Message,), dict(
  DESCRIPTOR = _CGCTOGCMSGROUTED,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CGCToGCMsgRouted)
  ))
_sym_db.RegisterMessage(CGCToGCMsgRouted)

CGCToGCMsgRoutedReply = _reflection.GeneratedProtocolMessageType('CGCToGCMsgRoutedReply', (_message.Message,), dict(
  DESCRIPTOR = _CGCTOGCMSGROUTEDREPLY,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CGCToGCMsgRoutedReply)
  ))
_sym_db.RegisterMessage(CGCToGCMsgRoutedReply)

CMsgGCUpdateSessionIP = _reflection.GeneratedProtocolMessageType('CMsgGCUpdateSessionIP', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCUPDATESESSIONIP,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCUpdateSessionIP)
  ))
_sym_db.RegisterMessage(CMsgGCUpdateSessionIP)

CMsgGCRequestSessionIP = _reflection.GeneratedProtocolMessageType('CMsgGCRequestSessionIP', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTSESSIONIP,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCRequestSessionIP)
  ))
_sym_db.RegisterMessage(CMsgGCRequestSessionIP)

CMsgGCRequestSessionIPResponse = _reflection.GeneratedProtocolMessageType('CMsgGCRequestSessionIPResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTSESSIONIPRESPONSE,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCRequestSessionIPResponse)
  ))
_sym_db.RegisterMessage(CMsgGCRequestSessionIPResponse)

CMsgSOCacheHaveVersion = _reflection.GeneratedProtocolMessageType('CMsgSOCacheHaveVersion', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHEHAVEVERSION,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSOCacheHaveVersion)
  ))
_sym_db.RegisterMessage(CMsgSOCacheHaveVersion)

CMsgClientHello = _reflection.GeneratedProtocolMessageType('CMsgClientHello', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTHELLO,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientHello)
  ))
_sym_db.RegisterMessage(CMsgClientHello)

CMsgServerHello = _reflection.GeneratedProtocolMessageType('CMsgServerHello', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSERVERHELLO,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgServerHello)
  ))
_sym_db.RegisterMessage(CMsgServerHello)

CMsgClientWelcome = _reflection.GeneratedProtocolMessageType('CMsgClientWelcome', (_message.Message,), dict(

  Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTWELCOME_LOCATION,
    __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientWelcome.Location)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTWELCOME,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientWelcome)
  ))
_sym_db.RegisterMessage(CMsgClientWelcome)
_sym_db.RegisterMessage(CMsgClientWelcome.Location)

CMsgConnectionStatus = _reflection.GeneratedProtocolMessageType('CMsgConnectionStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONNECTIONSTATUS,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgConnectionStatus)
  ))
_sym_db.RegisterMessage(CMsgConnectionStatus)

CWorkshop_PopulateItemDescriptions_Request = _reflection.GeneratedProtocolMessageType('CWorkshop_PopulateItemDescriptions_Request', (_message.Message,), dict(

  SingleItemDescription = _reflection.GeneratedProtocolMessageType('SingleItemDescription', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION,
    __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription)
    ))
  ,

  ItemDescriptionsLanguageBlock = _reflection.GeneratedProtocolMessageType('ItemDescriptionsLanguageBlock', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK,
    __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock)
    ))
  ,
  DESCRIPTOR = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_PopulateItemDescriptions_Request)
  ))
_sym_db.RegisterMessage(CWorkshop_PopulateItemDescriptions_Request)
_sym_db.RegisterMessage(CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription)
_sym_db.RegisterMessage(CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock)

CWorkshop_GetContributors_Request = _reflection.GeneratedProtocolMessageType('CWorkshop_GetContributors_Request', (_message.Message,), dict(
  DESCRIPTOR = _CWORKSHOP_GETCONTRIBUTORS_REQUEST,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_GetContributors_Request)
  ))
_sym_db.RegisterMessage(CWorkshop_GetContributors_Request)

CWorkshop_GetContributors_Response = _reflection.GeneratedProtocolMessageType('CWorkshop_GetContributors_Response', (_message.Message,), dict(
  DESCRIPTOR = _CWORKSHOP_GETCONTRIBUTORS_RESPONSE,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_GetContributors_Response)
  ))
_sym_db.RegisterMessage(CWorkshop_GetContributors_Response)

CWorkshop_SetItemPaymentRules_Request = _reflection.GeneratedProtocolMessageType('CWorkshop_SetItemPaymentRules_Request', (_message.Message,), dict(

  WorkshopItemPaymentRule = _reflection.GeneratedProtocolMessageType('WorkshopItemPaymentRule', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE,
    __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule)
    ))
  ,

  PartnerItemPaymentRule = _reflection.GeneratedProtocolMessageType('PartnerItemPaymentRule', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE,
    __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule)
    ))
  ,
  DESCRIPTOR = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_SetItemPaymentRules_Request)
  ))
_sym_db.RegisterMessage(CWorkshop_SetItemPaymentRules_Request)
_sym_db.RegisterMessage(CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule)
_sym_db.RegisterMessage(CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule)

CWorkshop_SetItemPaymentRules_Response = _reflection.GeneratedProtocolMessageType('CWorkshop_SetItemPaymentRules_Response', (_message.Message,), dict(
  DESCRIPTOR = _CWORKSHOP_SETITEMPAYMENTRULES_RESPONSE,
  __module__ = 'demoparser.protobufs.gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_SetItemPaymentRules_Response)
  ))
_sym_db.RegisterMessage(CWorkshop_SetItemPaymentRules_Response)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\200\001\000'))
_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT.has_options = True
_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\200\246\035\200\002\210\246\035\200\010'))
# @@protoc_insertion_point(module_scope)
