# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/econ_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from demoparser.protobufs import steammessages_pb2 as demoparser_dot_protobufs_dot_steammessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/econ_gcmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n*demoparser/protobufs/econ_gcmessages.proto\x1a(demoparser/protobufs/steammessages.proto\"\x98\x01\n\x11\x43MsgGCGiftedItems\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x14\n\x0cgiftdefindex\x18\x02 \x01(\r\x12\x1a\n\x12max_gifts_possible\x18\x03 \x01(\r\x12\x1f\n\x17num_eligible_recipients\x18\x04 \x01(\r\x12\x1d\n\x15recipients_accountids\x18\x05 \x03(\r\"E\n\x12\x43MsgApplyAutograph\x12\x19\n\x11\x61utograph_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\"7\n&CMsgGCUserTrackTimePlayedConsecutively\x12\r\n\x05state\x18\x01 \x01(\r*\x83&\n\nEGCItemMsg\x12\x11\n\x0ck_EMsgGCBase\x10\xe8\x07\x12\x1c\n\x17k_EMsgGCSetItemPosition\x10\xe9\x07\x12\x12\n\rk_EMsgGCCraft\x10\xea\x07\x12\x1a\n\x15k_EMsgGCCraftResponse\x10\xeb\x07\x12\x13\n\x0ek_EMsgGCDelete\x10\xec\x07\x12$\n\x1fk_EMsgGCVerifyCacheSubscription\x10\xed\x07\x12\x15\n\x10k_EMsgGCNameItem\x10\xee\x07\x12\x18\n\x13k_EMsgGCUnlockCrate\x10\xef\x07\x12 \n\x1bk_EMsgGCUnlockCrateResponse\x10\xf0\x07\x12\x16\n\x11k_EMsgGCPaintItem\x10\xf1\x07\x12\x1e\n\x19k_EMsgGCPaintItemResponse\x10\xf2\x07\x12\"\n\x1dk_EMsgGCGoldenWrenchBroadcast\x10\xf3\x07\x12\x18\n\x13k_EMsgGCMOTDRequest\x10\xf4\x07\x12 \n\x1bk_EMsgGCMOTDRequestResponse\x10\xf5\x07\x12\'\n\"k_EMsgGCAddItemToSocket_DEPRECATED\x10\xf6\x07\x12/\n*k_EMsgGCAddItemToSocketResponse_DEPRECATED\x10\xf7\x07\x12+\n&k_EMsgGCAddSocketToBaseItem_DEPRECATED\x10\xf8\x07\x12\'\n\"k_EMsgGCAddSocketToItem_DEPRECATED\x10\xf9\x07\x12/\n*k_EMsgGCAddSocketToItemResponse_DEPRECATED\x10\xfa\x07\x12\x19\n\x14k_EMsgGCNameBaseItem\x10\xfb\x07\x12!\n\x1ck_EMsgGCNameBaseItemResponse\x10\xfc\x07\x12(\n#k_EMsgGCRemoveSocketItem_DEPRECATED\x10\xfd\x07\x12\x30\n+k_EMsgGCRemoveSocketItemResponse_DEPRECATED\x10\xfe\x07\x12!\n\x1ck_EMsgGCCustomizeItemTexture\x10\xff\x07\x12)\n$k_EMsgGCCustomizeItemTextureResponse\x10\x80\x08\x12\x1b\n\x16k_EMsgGCUseItemRequest\x10\x81\x08\x12\x1c\n\x17k_EMsgGCUseItemResponse\x10\x82\x08\x12#\n\x1ek_EMsgGCGiftedItems_DEPRECATED\x10\x83\x08\x12\x1b\n\x16k_EMsgGCRemoveItemName\x10\x86\x08\x12\x1c\n\x17k_EMsgGCRemoveItemPaint\x10\x87\x08\x12\x19\n\x14k_EMsgGCGiftWrapItem\x10\x88\x08\x12!\n\x1ck_EMsgGCGiftWrapItemResponse\x10\x89\x08\x12\x18\n\x13k_EMsgGCDeliverGift\x10\x8a\x08\x12%\n k_EMsgGCDeliverGiftResponseGiver\x10\x8b\x08\x12(\n#k_EMsgGCDeliverGiftResponseReceiver\x10\x8c\x08\x12\x1e\n\x19k_EMsgGCUnwrapGiftRequest\x10\x8d\x08\x12\x1f\n\x1ak_EMsgGCUnwrapGiftResponse\x10\x8e\x08\x12\x19\n\x14k_EMsgGCSetItemStyle\x10\x8f\x08\x12\x1e\n\x19k_EMsgGCUsedClaimCodeItem\x10\x90\x08\x12\x16\n\x11k_EMsgGCSortItems\x10\x91\x08\x12*\n%k_EMsgGC_RevolvingLootList_DEPRECATED\x10\x92\x08\x12\x1a\n\x15k_EMsgGCLookupAccount\x10\x93\x08\x12\"\n\x1dk_EMsgGCLookupAccountResponse\x10\x94\x08\x12\x1e\n\x19k_EMsgGCLookupAccountName\x10\x95\x08\x12&\n!k_EMsgGCLookupAccountNameResponse\x10\x96\x08\x12\x1d\n\x18k_EMsgGCUpdateItemSchema\x10\x99\x08\x12 \n\x1bk_EMsgGCRemoveCustomTexture\x10\x9b\x08\x12(\n#k_EMsgGCRemoveCustomTextureResponse\x10\x9c\x08\x12\x1d\n\x18k_EMsgGCRemoveMakersMark\x10\x9d\x08\x12%\n k_EMsgGCRemoveMakersMarkResponse\x10\x9e\x08\x12#\n\x1ek_EMsgGCRemoveUniqueCraftIndex\x10\x9f\x08\x12+\n&k_EMsgGCRemoveUniqueCraftIndexResponse\x10\xa0\x08\x12\x1b\n\x16k_EMsgGCSaxxyBroadcast\x10\xa1\x08\x12!\n\x1ck_EMsgGCBackpackSortFinished\x10\xa2\x08\x12$\n\x1fk_EMsgGCAdjustItemEquippedState\x10\xa3\x08\x12\x18\n\x13k_EMsgGCCollectItem\x10\xa5\x08\x12)\n$k_EMsgGCItemAcknowledged__DEPRECATED\x10\xa6\x08\x12\x19\n\x14k_EMsgGC_ReportAbuse\x10\xa9\x08\x12!\n\x1ck_EMsgGC_ReportAbuseResponse\x10\xaa\x08\x12!\n\x1ck_EMsgGCNameItemNotification\x10\xac\x08\x12#\n\x1ek_EMsgGCApplyConsumableEffects\x10\xad\x08\x12 \n\x1bk_EMsgGCConsumableExhausted\x10\xae\x08\x12\x1e\n\x19k_EMsgGCShowItemsPickedUp\x10\xaf\x08\x12&\n!k_EMsgGCClientDisplayNotification\x10\xb0\x08\x12\x1d\n\x18k_EMsgGCApplyStrangePart\x10\xb1\x08\x12)\n$k_EMsgGC_IncrementKillCountAttribute\x10\xb2\x08\x12(\n#k_EMsgGC_IncrementKillCountResponse\x10\xb3\x08\x12 \n\x1bk_EMsgGCApplyPennantUpgrade\x10\xb4\x08\x12\x1d\n\x18k_EMsgGCSetItemPositions\x10\xb5\x08\x12\x1c\n\x17k_EMsgGCApplyEggEssence\x10\xb6\x08\x12#\n\x1ek_EMsgGCNameEggEssenceResponse\x10\xb7\x08\x12\x19\n\x14k_EMsgGCPaintKitItem\x10\xb8\x08\x12\x1d\n\x18k_EMsgGCPaintKitBaseItem\x10\xb9\x08\x12!\n\x1ck_EMsgGCPaintKitItemResponse\x10\xba\x08\x12\x18\n\x13k_EMsgGCGiftedItems\x10\xbb\x08\x12\x1c\n\x17k_EMsgGCUnlockItemStyle\x10\xbc\x08\x12$\n\x1fk_EMsgGCUnlockItemStyleResponse\x10\xbd\x08\x12\x19\n\x14k_EMsgGCApplySticker\x10\xbe\x08\x12\x1d\n\x18k_EMsgGCItemAcknowledged\x10\xbf\x08\x12\x19\n\x14k_EMsgGCStatTrakSwap\x10\xc0\x08\x12-\n(k_EMsgGCUserTrackTimePlayedConsecutively\x10\xc1\x08\x12\x18\n\x13k_EMsgGCTradingBase\x10\xdc\x0b\x12)\n$k_EMsgGCTrading_InitiateTradeRequest\x10\xdd\x0b\x12*\n%k_EMsgGCTrading_InitiateTradeResponse\x10\xde\x0b\x12!\n\x1ck_EMsgGCTrading_StartSession\x10\xdf\x0b\x12\x1c\n\x17k_EMsgGCTrading_SetItem\x10\xe0\x0b\x12\x1f\n\x1ak_EMsgGCTrading_RemoveItem\x10\xe1\x0b\x12$\n\x1fk_EMsgGCTrading_UpdateTradeInfo\x10\xe2\x0b\x12!\n\x1ck_EMsgGCTrading_SetReadiness\x10\xe3\x0b\x12&\n!k_EMsgGCTrading_ReadinessResponse\x10\xe4\x0b\x12\"\n\x1dk_EMsgGCTrading_SessionClosed\x10\xe5\x0b\x12\"\n\x1dk_EMsgGCTrading_CancelSession\x10\xe6\x0b\x12!\n\x1ck_EMsgGCTrading_TradeChatMsg\x10\xe7\x0b\x12!\n\x1ck_EMsgGCTrading_ConfirmOffer\x10\xe8\x0b\x12\'\n\"k_EMsgGCTrading_TradeTypingChatMsg\x10\xe9\x0b\x12)\n$k_EMsgGCServerBrowser_FavoriteServer\x10\xc1\x0c\x12*\n%k_EMsgGCServerBrowser_BlacklistServer\x10\xc2\x0c\x12\x1e\n\x19k_EMsgGCServerRentalsBase\x10\xa4\r\x12#\n\x1ek_EMsgGCItemPreviewCheckStatus\x10\xa5\r\x12&\n!k_EMsgGCItemPreviewStatusResponse\x10\xa6\r\x12\x1f\n\x1ak_EMsgGCItemPreviewRequest\x10\xa7\r\x12\'\n\"k_EMsgGCItemPreviewRequestResponse\x10\xa8\r\x12\x1e\n\x19k_EMsgGCItemPreviewExpire\x10\xa9\r\x12*\n%k_EMsgGCItemPreviewExpireNotification\x10\xaa\r\x12.\n)k_EMsgGCItemPreviewItemBoughtNotification\x10\xab\r\x12\x1f\n\x1ak_EMsgGCDev_NewItemRequest\x10\xd1\x0f\x12\'\n\"k_EMsgGCDev_NewItemRequestResponse\x10\xd2\x0f\x12!\n\x1ck_EMsgGCDev_PaintKitDropItem\x10\xd3\x0f\x12\x1d\n\x18k_EMsgGCStoreGetUserData\x10\xc4\x13\x12%\n k_EMsgGCStoreGetUserDataResponse\x10\xc5\x13\x12)\n$k_EMsgGCStorePurchaseInit_DEPRECATED\x10\xc6\x13\x12\x31\n,k_EMsgGCStorePurchaseInitResponse_DEPRECATED\x10\xc7\x13\x12\"\n\x1dk_EMsgGCStorePurchaseFinalize\x10\xc8\x13\x12*\n%k_EMsgGCStorePurchaseFinalizeResponse\x10\xc9\x13\x12 \n\x1bk_EMsgGCStorePurchaseCancel\x10\xca\x13\x12(\n#k_EMsgGCStorePurchaseCancelResponse\x10\xcb\x13\x12\"\n\x1dk_EMsgGCStorePurchaseQueryTxn\x10\xcc\x13\x12*\n%k_EMsgGCStorePurchaseQueryTxnResponse\x10\xcd\x13\x12\x1e\n\x19k_EMsgGCStorePurchaseInit\x10\xce\x13\x12&\n!k_EMsgGCStorePurchaseInitResponse\x10\xcf\x13\x12\"\n\x1dk_EMsgGCBannedWordListRequest\x10\xd0\x13\x12#\n\x1ek_EMsgGCBannedWordListResponse\x10\xd1\x13\x12(\n#k_EMsgGCToGCBannedWordListBroadcast\x10\xd2\x13\x12&\n!k_EMsgGCToGCBannedWordListUpdated\x10\xd3\x13\x12\x1e\n\x19k_EMsgGCToGCDirtySDOCache\x10\xd4\x13\x12&\n!k_EMsgGCToGCDirtyMultipleSDOCache\x10\xd5\x13\x12\"\n\x1dk_EMsgGCToGCUpdateSQLKeyValue\x10\xd6\x13\x12 \n\x1bk_EMsgGCToGCIsTrustedServer\x10\xd7\x13\x12(\n#k_EMsgGCToGCIsTrustedServerResponse\x10\xd8\x13\x12(\n#k_EMsgGCToGCBroadcastConsoleCommand\x10\xd9\x13\x12!\n\x1ck_EMsgGCServerVersionUpdated\x10\xda\x13\x12\x1b\n\x16k_EMsgGCApplyAutograph\x10\xdb\x13\x12%\n k_EMsgGCToGCWebAPIAccountChanged\x10\xdc\x13\x12!\n\x1ck_EMsgGCRequestAnnouncements\x10\xdd\x13\x12)\n$k_EMsgGCRequestAnnouncementsResponse\x10\xde\x13\x12%\n k_EMsgGCRequestPassportItemGrant\x10\xdf\x13\x12!\n\x1ck_EMsgGCClientVersionUpdated\x10\xe0\x13*\x9b\x02\n\x0e\x45GCMsgResponse\x12\x16\n\x12k_EGCMsgResponseOK\x10\x00\x12\x1a\n\x16k_EGCMsgResponseDenied\x10\x01\x12\x1f\n\x1bk_EGCMsgResponseServerError\x10\x02\x12\x1b\n\x17k_EGCMsgResponseTimeout\x10\x03\x12\x1b\n\x17k_EGCMsgResponseInvalid\x10\x04\x12\x1b\n\x17k_EGCMsgResponseNoMatch\x10\x05\x12 \n\x1ck_EGCMsgResponseUnknownError\x10\x06\x12\x1f\n\x1bk_EGCMsgResponseNotLoggedOn\x10\x07\x12\x1a\n\x16k_EGCMsgFailedToCreate\x10\x08*\xe9\x01\n\x0c\x45UnlockStyle\x12\x1b\n\x17k_UnlockStyle_Succeeded\x10\x00\x12\x1f\n\x1bk_UnlockStyle_Failed_PreReq\x10\x01\x12#\n\x1fk_UnlockStyle_Failed_CantAfford\x10\x02\x12#\n\x1fk_UnlockStyle_Failed_CantCommit\x10\x03\x12&\n\"k_UnlockStyle_Failed_CantLockCache\x10\x04\x12)\n%k_UnlockStyle_Failed_CantAffordAttrib\x10\x05\x42\x05H\x01\x80\x01\x00')
  ,
  dependencies=[demoparser_dot_protobufs_dot_steammessages__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EGCITEMMSG = _descriptor.EnumDescriptor(
  name='EGCItemMsg',
  full_name='EGCItemMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBase', index=0, number=1000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemPosition', index=1, number=1001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCraft', index=2, number=1002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCraftResponse', index=3, number=1003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDelete', index=4, number=1004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCVerifyCacheSubscription', index=5, number=1005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameItem', index=6, number=1006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnlockCrate', index=7, number=1007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnlockCrateResponse', index=8, number=1008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintItem', index=9, number=1009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintItemResponse', index=10, number=1010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGoldenWrenchBroadcast', index=11, number=1011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMOTDRequest', index=12, number=1012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMOTDRequestResponse', index=13, number=1013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddItemToSocket_DEPRECATED', index=14, number=1014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddItemToSocketResponse_DEPRECATED', index=15, number=1015,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToBaseItem_DEPRECATED', index=16, number=1016,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToItem_DEPRECATED', index=17, number=1017,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToItemResponse_DEPRECATED', index=18, number=1018,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameBaseItem', index=19, number=1019,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameBaseItemResponse', index=20, number=1020,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveSocketItem_DEPRECATED', index=21, number=1021,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveSocketItemResponse_DEPRECATED', index=22, number=1022,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCustomizeItemTexture', index=23, number=1023,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCustomizeItemTextureResponse', index=24, number=1024,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUseItemRequest', index=25, number=1025,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUseItemResponse', index=26, number=1026,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftedItems_DEPRECATED', index=27, number=1027,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemName', index=28, number=1030,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemPaint', index=29, number=1031,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftWrapItem', index=30, number=1032,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftWrapItemResponse', index=31, number=1033,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDeliverGift', index=32, number=1034,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDeliverGiftResponseGiver', index=33, number=1035,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDeliverGiftResponseReceiver', index=34, number=1036,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnwrapGiftRequest', index=35, number=1037,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnwrapGiftResponse', index=36, number=1038,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemStyle', index=37, number=1039,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUsedClaimCodeItem', index=38, number=1040,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSortItems', index=39, number=1041,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_RevolvingLootList_DEPRECATED', index=40, number=1042,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLookupAccount', index=41, number=1043,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLookupAccountResponse', index=42, number=1044,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLookupAccountName', index=43, number=1045,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLookupAccountNameResponse', index=44, number=1046,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUpdateItemSchema', index=45, number=1049,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveCustomTexture', index=46, number=1051,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveCustomTextureResponse', index=47, number=1052,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveMakersMark', index=48, number=1053,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveMakersMarkResponse', index=49, number=1054,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveUniqueCraftIndex', index=50, number=1055,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveUniqueCraftIndexResponse', index=51, number=1056,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSaxxyBroadcast', index=52, number=1057,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBackpackSortFinished', index=53, number=1058,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAdjustItemEquippedState', index=54, number=1059,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCollectItem', index=55, number=1061,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemAcknowledged__DEPRECATED', index=56, number=1062,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_ReportAbuse', index=57, number=1065,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_ReportAbuseResponse', index=58, number=1066,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameItemNotification', index=59, number=1068,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyConsumableEffects', index=60, number=1069,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConsumableExhausted', index=61, number=1070,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCShowItemsPickedUp', index=62, number=1071,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientDisplayNotification', index=63, number=1072,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyStrangePart', index=64, number=1073,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_IncrementKillCountAttribute', index=65, number=1074,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_IncrementKillCountResponse', index=66, number=1075,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyPennantUpgrade', index=67, number=1076,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemPositions', index=68, number=1077,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyEggEssence', index=69, number=1078,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameEggEssenceResponse', index=70, number=1079,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintKitItem', index=71, number=1080,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintKitBaseItem', index=72, number=1081,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintKitItemResponse', index=73, number=1082,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftedItems', index=74, number=1083,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnlockItemStyle', index=75, number=1084,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnlockItemStyleResponse', index=76, number=1085,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplySticker', index=77, number=1086,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemAcknowledged', index=78, number=1087,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStatTrakSwap', index=79, number=1088,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUserTrackTimePlayedConsecutively', index=80, number=1089,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTradingBase', index=81, number=1500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_InitiateTradeRequest', index=82, number=1501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_InitiateTradeResponse', index=83, number=1502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_StartSession', index=84, number=1503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_SetItem', index=85, number=1504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_RemoveItem', index=86, number=1505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_UpdateTradeInfo', index=87, number=1506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_SetReadiness', index=88, number=1507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_ReadinessResponse', index=89, number=1508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_SessionClosed', index=90, number=1509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_CancelSession', index=91, number=1510,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_TradeChatMsg', index=92, number=1511,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_ConfirmOffer', index=93, number=1512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_TradeTypingChatMsg', index=94, number=1513,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerBrowser_FavoriteServer', index=95, number=1601,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerBrowser_BlacklistServer', index=96, number=1602,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerRentalsBase', index=97, number=1700,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewCheckStatus', index=98, number=1701,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewStatusResponse', index=99, number=1702,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewRequest', index=100, number=1703,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewRequestResponse', index=101, number=1704,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewExpire', index=102, number=1705,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewExpireNotification', index=103, number=1706,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPreviewItemBoughtNotification', index=104, number=1707,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_NewItemRequest', index=105, number=2001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_NewItemRequestResponse', index=106, number=2002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_PaintKitDropItem', index=107, number=2003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStoreGetUserData', index=108, number=2500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStoreGetUserDataResponse', index=109, number=2501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInit_DEPRECATED', index=110, number=2502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInitResponse_DEPRECATED', index=111, number=2503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseFinalize', index=112, number=2504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseFinalizeResponse', index=113, number=2505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseCancel', index=114, number=2506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseCancelResponse', index=115, number=2507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseQueryTxn', index=116, number=2508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseQueryTxnResponse', index=117, number=2509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInit', index=118, number=2510,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInitResponse', index=119, number=2511,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBannedWordListRequest', index=120, number=2512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBannedWordListResponse', index=121, number=2513,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBannedWordListBroadcast', index=122, number=2514,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBannedWordListUpdated', index=123, number=2515,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDirtySDOCache', index=124, number=2516,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDirtyMultipleSDOCache', index=125, number=2517,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateSQLKeyValue', index=126, number=2518,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCIsTrustedServer', index=127, number=2519,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCIsTrustedServerResponse', index=128, number=2520,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBroadcastConsoleCommand', index=129, number=2521,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerVersionUpdated', index=130, number=2522,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyAutograph', index=131, number=2523,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCWebAPIAccountChanged', index=132, number=2524,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestAnnouncements', index=133, number=2525,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestAnnouncementsResponse', index=134, number=2526,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestPassportItemGrant', index=135, number=2527,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientVersionUpdated', index=136, number=2528,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=372,
  serialized_end=5239,
)
_sym_db.RegisterEnumDescriptor(_EGCITEMMSG)

EGCItemMsg = enum_type_wrapper.EnumTypeWrapper(_EGCITEMMSG)
_EGCMSGRESPONSE = _descriptor.EnumDescriptor(
  name='EGCMsgResponse',
  full_name='EGCMsgResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseOK', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseDenied', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseServerError', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseTimeout', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseInvalid', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseNoMatch', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseUnknownError', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseNotLoggedOn', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgFailedToCreate', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5242,
  serialized_end=5525,
)
_sym_db.RegisterEnumDescriptor(_EGCMSGRESPONSE)

EGCMsgResponse = enum_type_wrapper.EnumTypeWrapper(_EGCMSGRESPONSE)
_EUNLOCKSTYLE = _descriptor.EnumDescriptor(
  name='EUnlockStyle',
  full_name='EUnlockStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_PreReq', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantAfford', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantCommit', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantLockCache', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantAffordAttrib', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5528,
  serialized_end=5761,
)
_sym_db.RegisterEnumDescriptor(_EUNLOCKSTYLE)

EUnlockStyle = enum_type_wrapper.EnumTypeWrapper(_EUNLOCKSTYLE)
k_EMsgGCBase = 1000
k_EMsgGCSetItemPosition = 1001
k_EMsgGCCraft = 1002
k_EMsgGCCraftResponse = 1003
k_EMsgGCDelete = 1004
k_EMsgGCVerifyCacheSubscription = 1005
k_EMsgGCNameItem = 1006
k_EMsgGCUnlockCrate = 1007
k_EMsgGCUnlockCrateResponse = 1008
k_EMsgGCPaintItem = 1009
k_EMsgGCPaintItemResponse = 1010
k_EMsgGCGoldenWrenchBroadcast = 1011
k_EMsgGCMOTDRequest = 1012
k_EMsgGCMOTDRequestResponse = 1013
k_EMsgGCAddItemToSocket_DEPRECATED = 1014
k_EMsgGCAddItemToSocketResponse_DEPRECATED = 1015
k_EMsgGCAddSocketToBaseItem_DEPRECATED = 1016
k_EMsgGCAddSocketToItem_DEPRECATED = 1017
k_EMsgGCAddSocketToItemResponse_DEPRECATED = 1018
k_EMsgGCNameBaseItem = 1019
k_EMsgGCNameBaseItemResponse = 1020
k_EMsgGCRemoveSocketItem_DEPRECATED = 1021
k_EMsgGCRemoveSocketItemResponse_DEPRECATED = 1022
k_EMsgGCCustomizeItemTexture = 1023
k_EMsgGCCustomizeItemTextureResponse = 1024
k_EMsgGCUseItemRequest = 1025
k_EMsgGCUseItemResponse = 1026
k_EMsgGCGiftedItems_DEPRECATED = 1027
k_EMsgGCRemoveItemName = 1030
k_EMsgGCRemoveItemPaint = 1031
k_EMsgGCGiftWrapItem = 1032
k_EMsgGCGiftWrapItemResponse = 1033
k_EMsgGCDeliverGift = 1034
k_EMsgGCDeliverGiftResponseGiver = 1035
k_EMsgGCDeliverGiftResponseReceiver = 1036
k_EMsgGCUnwrapGiftRequest = 1037
k_EMsgGCUnwrapGiftResponse = 1038
k_EMsgGCSetItemStyle = 1039
k_EMsgGCUsedClaimCodeItem = 1040
k_EMsgGCSortItems = 1041
k_EMsgGC_RevolvingLootList_DEPRECATED = 1042
k_EMsgGCLookupAccount = 1043
k_EMsgGCLookupAccountResponse = 1044
k_EMsgGCLookupAccountName = 1045
k_EMsgGCLookupAccountNameResponse = 1046
k_EMsgGCUpdateItemSchema = 1049
k_EMsgGCRemoveCustomTexture = 1051
k_EMsgGCRemoveCustomTextureResponse = 1052
k_EMsgGCRemoveMakersMark = 1053
k_EMsgGCRemoveMakersMarkResponse = 1054
k_EMsgGCRemoveUniqueCraftIndex = 1055
k_EMsgGCRemoveUniqueCraftIndexResponse = 1056
k_EMsgGCSaxxyBroadcast = 1057
k_EMsgGCBackpackSortFinished = 1058
k_EMsgGCAdjustItemEquippedState = 1059
k_EMsgGCCollectItem = 1061
k_EMsgGCItemAcknowledged__DEPRECATED = 1062
k_EMsgGC_ReportAbuse = 1065
k_EMsgGC_ReportAbuseResponse = 1066
k_EMsgGCNameItemNotification = 1068
k_EMsgGCApplyConsumableEffects = 1069
k_EMsgGCConsumableExhausted = 1070
k_EMsgGCShowItemsPickedUp = 1071
k_EMsgGCClientDisplayNotification = 1072
k_EMsgGCApplyStrangePart = 1073
k_EMsgGC_IncrementKillCountAttribute = 1074
k_EMsgGC_IncrementKillCountResponse = 1075
k_EMsgGCApplyPennantUpgrade = 1076
k_EMsgGCSetItemPositions = 1077
k_EMsgGCApplyEggEssence = 1078
k_EMsgGCNameEggEssenceResponse = 1079
k_EMsgGCPaintKitItem = 1080
k_EMsgGCPaintKitBaseItem = 1081
k_EMsgGCPaintKitItemResponse = 1082
k_EMsgGCGiftedItems = 1083
k_EMsgGCUnlockItemStyle = 1084
k_EMsgGCUnlockItemStyleResponse = 1085
k_EMsgGCApplySticker = 1086
k_EMsgGCItemAcknowledged = 1087
k_EMsgGCStatTrakSwap = 1088
k_EMsgGCUserTrackTimePlayedConsecutively = 1089
k_EMsgGCTradingBase = 1500
k_EMsgGCTrading_InitiateTradeRequest = 1501
k_EMsgGCTrading_InitiateTradeResponse = 1502
k_EMsgGCTrading_StartSession = 1503
k_EMsgGCTrading_SetItem = 1504
k_EMsgGCTrading_RemoveItem = 1505
k_EMsgGCTrading_UpdateTradeInfo = 1506
k_EMsgGCTrading_SetReadiness = 1507
k_EMsgGCTrading_ReadinessResponse = 1508
k_EMsgGCTrading_SessionClosed = 1509
k_EMsgGCTrading_CancelSession = 1510
k_EMsgGCTrading_TradeChatMsg = 1511
k_EMsgGCTrading_ConfirmOffer = 1512
k_EMsgGCTrading_TradeTypingChatMsg = 1513
k_EMsgGCServerBrowser_FavoriteServer = 1601
k_EMsgGCServerBrowser_BlacklistServer = 1602
k_EMsgGCServerRentalsBase = 1700
k_EMsgGCItemPreviewCheckStatus = 1701
k_EMsgGCItemPreviewStatusResponse = 1702
k_EMsgGCItemPreviewRequest = 1703
k_EMsgGCItemPreviewRequestResponse = 1704
k_EMsgGCItemPreviewExpire = 1705
k_EMsgGCItemPreviewExpireNotification = 1706
k_EMsgGCItemPreviewItemBoughtNotification = 1707
k_EMsgGCDev_NewItemRequest = 2001
k_EMsgGCDev_NewItemRequestResponse = 2002
k_EMsgGCDev_PaintKitDropItem = 2003
k_EMsgGCStoreGetUserData = 2500
k_EMsgGCStoreGetUserDataResponse = 2501
k_EMsgGCStorePurchaseInit_DEPRECATED = 2502
k_EMsgGCStorePurchaseInitResponse_DEPRECATED = 2503
k_EMsgGCStorePurchaseFinalize = 2504
k_EMsgGCStorePurchaseFinalizeResponse = 2505
k_EMsgGCStorePurchaseCancel = 2506
k_EMsgGCStorePurchaseCancelResponse = 2507
k_EMsgGCStorePurchaseQueryTxn = 2508
k_EMsgGCStorePurchaseQueryTxnResponse = 2509
k_EMsgGCStorePurchaseInit = 2510
k_EMsgGCStorePurchaseInitResponse = 2511
k_EMsgGCBannedWordListRequest = 2512
k_EMsgGCBannedWordListResponse = 2513
k_EMsgGCToGCBannedWordListBroadcast = 2514
k_EMsgGCToGCBannedWordListUpdated = 2515
k_EMsgGCToGCDirtySDOCache = 2516
k_EMsgGCToGCDirtyMultipleSDOCache = 2517
k_EMsgGCToGCUpdateSQLKeyValue = 2518
k_EMsgGCToGCIsTrustedServer = 2519
k_EMsgGCToGCIsTrustedServerResponse = 2520
k_EMsgGCToGCBroadcastConsoleCommand = 2521
k_EMsgGCServerVersionUpdated = 2522
k_EMsgGCApplyAutograph = 2523
k_EMsgGCToGCWebAPIAccountChanged = 2524
k_EMsgGCRequestAnnouncements = 2525
k_EMsgGCRequestAnnouncementsResponse = 2526
k_EMsgGCRequestPassportItemGrant = 2527
k_EMsgGCClientVersionUpdated = 2528
k_EGCMsgResponseOK = 0
k_EGCMsgResponseDenied = 1
k_EGCMsgResponseServerError = 2
k_EGCMsgResponseTimeout = 3
k_EGCMsgResponseInvalid = 4
k_EGCMsgResponseNoMatch = 5
k_EGCMsgResponseUnknownError = 6
k_EGCMsgResponseNotLoggedOn = 7
k_EGCMsgFailedToCreate = 8
k_UnlockStyle_Succeeded = 0
k_UnlockStyle_Failed_PreReq = 1
k_UnlockStyle_Failed_CantAfford = 2
k_UnlockStyle_Failed_CantCommit = 3
k_UnlockStyle_Failed_CantLockCache = 4
k_UnlockStyle_Failed_CantAffordAttrib = 5



_CMSGGCGIFTEDITEMS = _descriptor.Descriptor(
  name='CMsgGCGiftedItems',
  full_name='CMsgGCGiftedItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCGiftedItems.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='giftdefindex', full_name='CMsgGCGiftedItems.giftdefindex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_gifts_possible', full_name='CMsgGCGiftedItems.max_gifts_possible', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_eligible_recipients', full_name='CMsgGCGiftedItems.num_eligible_recipients', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recipients_accountids', full_name='CMsgGCGiftedItems.recipients_accountids', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=241,
)


_CMSGAPPLYAUTOGRAPH = _descriptor.Descriptor(
  name='CMsgApplyAutograph',
  full_name='CMsgApplyAutograph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='autograph_item_id', full_name='CMsgApplyAutograph.autograph_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgApplyAutograph.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=312,
)


_CMSGGCUSERTRACKTIMEPLAYEDCONSECUTIVELY = _descriptor.Descriptor(
  name='CMsgGCUserTrackTimePlayedConsecutively',
  full_name='CMsgGCUserTrackTimePlayedConsecutively',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgGCUserTrackTimePlayedConsecutively.state', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=369,
)

DESCRIPTOR.message_types_by_name['CMsgGCGiftedItems'] = _CMSGGCGIFTEDITEMS
DESCRIPTOR.message_types_by_name['CMsgApplyAutograph'] = _CMSGAPPLYAUTOGRAPH
DESCRIPTOR.message_types_by_name['CMsgGCUserTrackTimePlayedConsecutively'] = _CMSGGCUSERTRACKTIMEPLAYEDCONSECUTIVELY
DESCRIPTOR.enum_types_by_name['EGCItemMsg'] = _EGCITEMMSG
DESCRIPTOR.enum_types_by_name['EGCMsgResponse'] = _EGCMSGRESPONSE
DESCRIPTOR.enum_types_by_name['EUnlockStyle'] = _EUNLOCKSTYLE

CMsgGCGiftedItems = _reflection.GeneratedProtocolMessageType('CMsgGCGiftedItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGIFTEDITEMS,
  __module__ = 'demoparser.protobufs.econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCGiftedItems)
  ))
_sym_db.RegisterMessage(CMsgGCGiftedItems)

CMsgApplyAutograph = _reflection.GeneratedProtocolMessageType('CMsgApplyAutograph', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYAUTOGRAPH,
  __module__ = 'demoparser.protobufs.econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyAutograph)
  ))
_sym_db.RegisterMessage(CMsgApplyAutograph)

CMsgGCUserTrackTimePlayedConsecutively = _reflection.GeneratedProtocolMessageType('CMsgGCUserTrackTimePlayedConsecutively', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCUSERTRACKTIMEPLAYEDCONSECUTIVELY,
  __module__ = 'demoparser.protobufs.econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCUserTrackTimePlayedConsecutively)
  ))
_sym_db.RegisterMessage(CMsgGCUserTrackTimePlayedConsecutively)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\200\001\000'))
# @@protoc_insertion_point(module_scope)
