MAX_CUSTOM_FILES = 4
MAX_EDICT_BITS = 11
MAX_PATH = 260
MAX_SPLITSCREEN_CLIENTS = 2
MAX_PLAYER_NAME_LENGTH = 128
MAX_USERDATA_BITS = 14
NUM_NETWORKED_EHANDLE_SERIAL_NUMBER_BITS = 10
SIGNED_GUID_LEN = 33
SUBSTRING_BITS = 5

CW_None = 0
CW_LowPrecision = 1
CW_Integral = 2

COORD_INTEGER_BITS = 14
COORD_FRACTIONAL_BITS = 5
COORD_DENOMINATOR = (1 << COORD_FRACTIONAL_BITS)
COORD_RESOLUTION = (1.0 / COORD_DENOMINATOR)

COORD_INTEGER_BITS_MP = 11
COORD_FRACTIONAL_BITS_MP_LOWPRECISION = 3
COORD_DENOMINATOR_LOWPRECISION = (1 << COORD_FRACTIONAL_BITS_MP_LOWPRECISION)
COORD_RESOLUTION_LOWPRECISION = (1.0 / COORD_DENOMINATOR_LOWPRECISION)

NORMAL_FRACTIONAL_BITS = 11
NORMAL_DENOMINATOR = (1 << NORMAL_FRACTIONAL_BITS) - 1
NORMAL_RESOLUTION = (1.0 / NORMAL_DENOMINATOR)

MAX_EDICT_BITS = 11
NETWORKED_EHANDLE_ENT_ENTRY_MASK = (1 << MAX_EDICT_BITS) - 1
NUM_NETWORKED_EHANDLE_SERIAL_NUMBER_BITS = 10
NUM_NETWORKED_EHANDLE_BITS = \
    MAX_EDICT_BITS + NUM_NETWORKED_EHANDLE_SERIAL_NUMBER_BITS
INVALID_NETWORKED_EHANDLE_VALUE = (1 << NUM_NETWORKED_EHANDLE_BITS) - 1
