# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/cstrike15_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from demoparser.protobufs import steammessages_pb2 as demoparser_dot_protobufs_dot_steammessages__pb2
from demoparser.protobufs import engine_gcmessages_pb2 as demoparser_dot_protobufs_dot_engine__gcmessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/cstrike15_gcmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n/demoparser/protobufs/cstrike15_gcmessages.proto\x1a(demoparser/protobufs/steammessages.proto\x1a,demoparser/protobufs/engine_gcmessages.proto\"=\n\x0eGameServerPing\x12\x0c\n\x04ping\x18\x02 \x01(\x05\x12\n\n\x02ip\x18\x03 \x01(\r\x12\x11\n\tinstances\x18\x05 \x01(\r\"6\n\x0e\x44\x61taCenterPing\x12\x16\n\x0e\x64\x61ta_center_id\x18\x01 \x01(\x07\x12\x0c\n\x04ping\x18\x02 \x01(\x11\"`\n\x17\x44\x65tailedSearchStatistic\x12\x11\n\tgame_type\x18\x01 \x01(\r\x12\x17\n\x0fsearch_time_avg\x18\x02 \x01(\r\x12\x19\n\x11players_searching\x18\x04 \x01(\r\"\xa7\x01\n\x10TournamentPlayer\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0bplayer_nick\x18\x02 \x01(\t\x12\x13\n\x0bplayer_name\x18\x03 \x01(\t\x12\x12\n\nplayer_dob\x18\x04 \x01(\r\x12\x13\n\x0bplayer_flag\x18\x05 \x01(\t\x12\x17\n\x0fplayer_location\x18\x06 \x01(\t\x12\x13\n\x0bplayer_desc\x18\x07 \x01(\t\"}\n\x0eTournamentTeam\x12\x0f\n\x07team_id\x18\x01 \x01(\x05\x12\x10\n\x08team_tag\x18\x02 \x01(\t\x12\x11\n\tteam_flag\x18\x03 \x01(\t\x12\x11\n\tteam_name\x18\x04 \x01(\t\x12\"\n\x07players\x18\x05 \x03(\x0b\x32\x11.TournamentPlayer\"\xdf\x01\n\x0fTournamentEvent\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x05\x12\x11\n\tevent_tag\x18\x02 \x01(\t\x12\x12\n\nevent_name\x18\x03 \x01(\t\x12\x18\n\x10\x65vent_time_start\x18\x04 \x01(\r\x12\x16\n\x0e\x65vent_time_end\x18\x05 \x01(\r\x12\x14\n\x0c\x65vent_public\x18\x06 \x01(\x05\x12\x16\n\x0e\x65vent_stage_id\x18\x07 \x01(\x05\x12\x18\n\x10\x65vent_stage_name\x18\x08 \x01(\t\x12\x19\n\x11\x61\x63tive_section_id\x18\t \x01(\r\"\x8f\x03\n\x10GlobalStatistics\x12\x16\n\x0eplayers_online\x18\x01 \x01(\r\x12\x16\n\x0eservers_online\x18\x02 \x01(\r\x12\x19\n\x11players_searching\x18\x03 \x01(\r\x12\x19\n\x11servers_available\x18\x04 \x01(\r\x12\x17\n\x0fongoing_matches\x18\x05 \x01(\r\x12\x17\n\x0fsearch_time_avg\x18\x06 \x01(\r\x12\x33\n\x11search_statistics\x18\x07 \x03(\x0b\x32\x18.DetailedSearchStatistic\x12\x15\n\rmain_post_url\x18\x08 \x01(\t\x12\x1e\n\x16required_appid_version\x18\t \x01(\r\x12\x1a\n\x12pricesheet_version\x18\n \x01(\r\x12\x1e\n\x16twitch_streams_version\x18\x0b \x01(\r\x12!\n\x19\x61\x63tive_tournament_eventid\x18\x0c \x01(\r\x12\x18\n\x10\x61\x63tive_survey_id\x18\r \x01(\r\">\n\x1fOperationalStatisticDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05idkey\x18\x02 \x01(\r\"<\n\x1bOperationalStatisticElement\x12\r\n\x05idkey\x18\x01 \x01(\r\x12\x0e\n\x06values\x18\x02 \x03(\x05\"r\n\x1bOperationalStatisticsPacket\x12\x10\n\x08packetid\x18\x01 \x01(\x05\x12\x13\n\x0bmstimestamp\x18\x02 \x01(\x05\x12,\n\x06values\x18\x03 \x03(\x0b\x32\x1c.OperationalStatisticElement\"[\n\x11PlayerRankingInfo\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07rank_id\x18\x02 \x01(\r\x12\x0c\n\x04wins\x18\x03 \x01(\r\x12\x13\n\x0brank_change\x18\x04 \x01(\x02\"X\n\x16PlayerCommendationInfo\x12\x14\n\x0c\x63md_friendly\x18\x01 \x01(\r\x12\x14\n\x0c\x63md_teaching\x18\x02 \x01(\r\x12\x12\n\ncmd_leader\x18\x04 \x01(\r\"\xc0\x01\n\x10PlayerMedalsInfo\x12\x12\n\nmedal_team\x18\x01 \x01(\r\x12\x14\n\x0cmedal_combat\x18\x02 \x01(\r\x12\x14\n\x0cmedal_weapon\x18\x03 \x01(\r\x12\x14\n\x0cmedal_global\x18\x04 \x01(\r\x12\x12\n\nmedal_arms\x18\x05 \x01(\r\x12\x1c\n\x14\x64isplay_items_defidx\x18\x07 \x03(\r\x12$\n\x1c\x66\x65\x61tured_display_item_defidx\x18\x08 \x01(\r\">\n\x0f\x41\x63\x63ountActivity\x12\x10\n\x08\x61\x63tivity\x18\x01 \x01(\r\x12\x0c\n\x04mode\x18\x02 \x01(\r\x12\x0b\n\x03map\x18\x03 \x01(\r\"g\n\x14TournamentMatchSetup\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x05\x12\x12\n\nteam_id_ct\x18\x02 \x01(\x05\x12\x11\n\tteam_id_t\x18\x03 \x01(\x05\x12\x16\n\x0e\x65vent_stage_id\x18\x04 \x01(\x05\"\xc0\x03\n\x0eServerHltvInfo\x12\x13\n\x0btv_udp_port\x18\x01 \x01(\r\x12\x14\n\x0ctv_watch_key\x18\x02 \x01(\x04\x12\x10\n\x08tv_slots\x18\x03 \x01(\r\x12\x12\n\ntv_clients\x18\x04 \x01(\r\x12\x12\n\ntv_proxies\x18\x05 \x01(\r\x12\x0f\n\x07tv_time\x18\x06 \x01(\r\x12\x11\n\tgame_type\x18\x08 \x01(\r\x12\x15\n\rgame_mapgroup\x18\t \x01(\t\x12\x10\n\x08game_map\x18\n \x01(\t\x12\x19\n\x11tv_master_steamid\x18\x0b \x01(\x04\x12\x16\n\x0etv_local_slots\x18\x0c \x01(\r\x12\x18\n\x10tv_local_clients\x18\r \x01(\r\x12\x18\n\x10tv_local_proxies\x18\x0e \x01(\r\x12\x16\n\x0etv_relay_slots\x18\x0f \x01(\r\x12\x18\n\x10tv_relay_clients\x18\x10 \x01(\r\x12\x18\n\x10tv_relay_proxies\x18\x11 \x01(\r\x12\x18\n\x10tv_relay_address\x18\x12 \x01(\r\x12\x15\n\rtv_relay_port\x18\x13 \x01(\r\x12\x18\n\x10tv_relay_steamid\x18\x14 \x01(\x04\"X\n\rIpAddressMask\x12\t\n\x01\x61\x18\x01 \x01(\r\x12\t\n\x01\x62\x18\x02 \x01(\r\x12\t\n\x01\x63\x18\x03 \x01(\r\x12\t\n\x01\x64\x18\x04 \x01(\r\x12\x0c\n\x04\x62its\x18\x05 \x01(\r\x12\r\n\x05token\x18\x06 \x01(\r\"8\n\x0eXpProgressData\x12\x11\n\txp_points\x18\x01 \x01(\r\x12\x13\n\x0bxp_category\x18\x02 \x01(\x05\"_\n\x13MatchEndItemUpdates\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x18\n\x10item_attr_defidx\x18\x02 \x01(\r\x12\x1d\n\x15item_attr_delta_value\x18\x03 \x01(\r\"\x9e\x02\n\x14ScoreLeaderboardData\x12\x10\n\x08quest_id\x18\x01 \x01(\x04\x12\r\n\x05score\x18\x02 \x01(\r\x12<\n\x0e\x61\x63\x63ountentries\x18\x03 \x03(\x0b\x32$.ScoreLeaderboardData.AccountEntries\x12\x31\n\x0cmatchentries\x18\x05 \x03(\x0b\x32\x1b.ScoreLeaderboardData.Entry\x1a!\n\x05\x45ntry\x12\x0b\n\x03tag\x18\x01 \x01(\r\x12\x0b\n\x03val\x18\x02 \x01(\r\x1aQ\n\x0e\x41\x63\x63ountEntries\x12\x11\n\taccountid\x18\x01 \x01(\r\x12,\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x1b.ScoreLeaderboardData.Entry\"\xd2\x02\n\x0fPlayerQuestData\x12\x1a\n\x12quester_account_id\x18\x01 \x01(\r\x12\x37\n\x0fquest_item_data\x18\x02 \x03(\x0b\x32\x1e.PlayerQuestData.QuestItemData\x12)\n\x10xp_progress_data\x18\x03 \x03(\x0b\x32\x0f.XpProgressData\x12\x13\n\x0btime_played\x18\x04 \x01(\r\x12\x14\n\x0cmm_game_mode\x18\x05 \x01(\r\x12*\n\x0citem_updates\x18\x06 \x03(\x0b\x32\x14.MatchEndItemUpdates\x1ah\n\rQuestItemData\x12\x10\n\x08quest_id\x18\x01 \x01(\x04\x12\"\n\x1aquest_normal_points_earned\x18\x02 \x01(\x05\x12!\n\x19quest_bonus_points_earned\x18\x03 \x01(\x05\"\xa5\x01\n\x1c\x43MsgGC_ServerQuestUpdateData\x12+\n\x11player_quest_data\x18\x01 \x03(\x0b\x32\x10.PlayerQuestData\x12\x13\n\x0b\x62inary_data\x18\x02 \x01(\x0c\x12\x14\n\x0cmm_game_mode\x18\x03 \x01(\r\x12-\n\x0emissionlbsdata\x18\x04 \x01(\x0b\x32\x15.ScoreLeaderboardData\"\xa7\x01\n0CMsgGCCStrike15_v2_MatchmakingGCOperationalStats\x12\x10\n\x08packetid\x18\x01 \x01(\x05\x12\x32\n\x08namekeys\x18\x02 \x03(\x0b\x32 .OperationalStatisticDescription\x12-\n\x07packets\x18\x03 \x03(\x0b\x32\x1c.OperationalStatisticsPacket\"`\n.CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm\x12\r\n\x05token\x18\x01 \x01(\r\x12\r\n\x05stamp\x18\x02 \x01(\r\x12\x10\n\x08\x65xchange\x18\x03 \x01(\x04\"o\n-CMsgGCCStrike15_v2_GC2ServerReservationUpdate\x12\x1e\n\x16viewers_external_total\x18\x01 \x01(\r\x12\x1e\n\x16viewers_external_steam\x18\x02 \x01(\r\"\xbf\x01\n#CMsgGCCStrike15_v2_MatchmakingStart\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\r\x12\x11\n\tgame_type\x18\x02 \x01(\r\x12\x13\n\x0bticket_data\x18\x03 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x04 \x01(\r\x12/\n\x10tournament_match\x18\x05 \x01(\x0b\x32\x15.TournamentMatchSetup\x12\x12\n\nprime_only\x18\x06 \x01(\x08\"5\n\"CMsgGCCStrike15_v2_MatchmakingStop\x12\x0f\n\x07\x61\x62\x61ndon\x18\x01 \x01(\x05\"\xc4\x01\n/CMsgGCCStrike15_v2_MatchmakingClient2ServerPing\x12(\n\x0fgameserverpings\x18\x01 \x03(\x0b\x32\x0f.GameServerPing\x12\x14\n\x0coffset_index\x18\x02 \x01(\x05\x12\x13\n\x0b\x66inal_batch\x18\x03 \x01(\x05\x12*\n\x11\x64\x61ta_center_pings\x18\x04 \x03(\x0b\x32\x0f.DataCenterPing\x12\x10\n\x08max_ping\x18\x05 \x01(\r\"\x99\x05\n-CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate\x12\x13\n\x0bmatchmaking\x18\x01 \x01(\x05\x12#\n\x1bwaiting_account_id_sessions\x18\x02 \x03(\r\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12(\n ongoingmatch_account_id_sessions\x18\x06 \x03(\r\x12\'\n\x0cglobal_stats\x18\x07 \x01(\x0b\x32\x11.GlobalStatistics\x12$\n\x1c\x66\x61ilping_account_id_sessions\x18\x08 \x03(\r\x12#\n\x1bpenalty_account_id_sessions\x18\t \x03(\r\x12%\n\x1d\x66\x61ilready_account_id_sessions\x18\n \x03(\r\x12%\n\x1dvacbanned_account_id_sessions\x18\x0b \x03(\r\x12-\n\x15server_ipaddress_mask\x18\x0c \x01(\x0b\x32\x0e.IpAddressMask\x12\x42\n\x05notes\x18\r \x03(\x0b\x32\x33.CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.Note\x12)\n!penalty_account_id_sessions_green\x18\x0e \x03(\r\x12\"\n\x1ainsufficientlevel_sessions\x18\x0f \x03(\r\x12$\n\x1cvsncheck_account_id_sessions\x18\x10 \x03(\r\x1aK\n\x04Note\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x11\n\tregion_id\x18\x02 \x01(\x05\x12\x10\n\x08region_r\x18\x03 \x01(\x02\x12\x10\n\x08\x64istance\x18\x04 \x01(\x02\"\xd6\x02\n(CDataGCCStrike15_v2_TournamentMatchDraft\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x65vent_stage_id\x18\x02 \x01(\x05\x12\x11\n\tteam_id_0\x18\x03 \x01(\x05\x12\x11\n\tteam_id_1\x18\x04 \x01(\x05\x12\x12\n\nmaps_count\x18\x05 \x01(\x05\x12\x14\n\x0cmaps_current\x18\x06 \x01(\x05\x12\x15\n\rteam_id_start\x18\x07 \x01(\x05\x12\x15\n\rteam_id_veto1\x18\x08 \x01(\x05\x12\x15\n\rteam_id_pickn\x18\t \x01(\x05\x12?\n\x06\x64rafts\x18\n \x03(\x0b\x32/.CDataGCCStrike15_v2_TournamentMatchDraft.Entry\x1a*\n\x05\x45ntry\x12\r\n\x05mapid\x18\x01 \x01(\x05\x12\x12\n\nteam_id_ct\x18\x02 \x01(\x05\"\xed\x01\n\x11\x43PreMatchInfoData\x12\x17\n\x0fpredictions_pct\x18\x01 \x01(\x05\x12\x38\n\x05\x64raft\x18\x04 \x01(\x0b\x32).CDataGCCStrike15_v2_TournamentMatchDraft\x12+\n\x05stats\x18\x05 \x03(\x0b\x32\x1c.CPreMatchInfoData.TeamStats\x1aX\n\tTeamStats\x12\x19\n\x11match_info_idxtxt\x18\x01 \x01(\x05\x12\x16\n\x0ematch_info_txt\x18\x02 \x01(\t\x12\x18\n\x10match_info_teams\x18\x03 \x03(\t\"\xf2\x03\n.CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\r\x12\x11\n\tgame_type\x18\x02 \x01(\r\x12\x10\n\x08match_id\x18\x03 \x01(\x04\x12\x16\n\x0eserver_version\x18\x04 \x01(\r\x12$\n\x08rankings\x18\x05 \x03(\x0b\x32\x12.PlayerRankingInfo\x12\x16\n\x0e\x65ncryption_key\x18\x06 \x01(\x04\x12\x1a\n\x12\x65ncryption_key_pub\x18\x07 \x01(\x04\x12\x11\n\tparty_ids\x18\x08 \x03(\r\x12!\n\twhitelist\x18\t \x03(\x0b\x32\x0e.IpAddressMask\x12\x19\n\x11tv_master_steamid\x18\n \x01(\x04\x12*\n\x10tournament_event\x18\x0b \x01(\x0b\x32\x10.TournamentEvent\x12)\n\x10tournament_teams\x18\x0c \x03(\x0b\x32\x0f.TournamentTeam\x12&\n\x1etournament_casters_account_ids\x18\r \x03(\r\x12\x18\n\x10tv_relay_steamid\x18\x0e \x01(\x04\x12*\n\x0epre_match_data\x18\x0f \x01(\x0b\x32\x12.CPreMatchInfoData\"\xed\x03\n7CMsgGCCStrike15_v2_MatchmakingServerReservationResponse\x12\x15\n\rreservationid\x18\x01 \x01(\x04\x12\x44\n\x0breservation\x18\x02 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve\x12\x0b\n\x03map\x18\x03 \x01(\t\x12\x1b\n\x13gc_reservation_sent\x18\x04 \x01(\x04\x12\x16\n\x0eserver_version\x18\x05 \x01(\r\x12 \n\x07tv_info\x18\x06 \x01(\x0b\x32\x0f.ServerHltvInfo\x12\x1e\n\x16reward_player_accounts\x18\x07 \x03(\r\x12\x1c\n\x14idle_player_accounts\x18\x08 \x03(\r\x12 \n\x18reward_item_attr_def_idx\x18\t \x01(\r\x12\x1e\n\x16reward_item_attr_value\x18\n \x01(\r\x12#\n\x1breward_item_attr_reward_idx\x18\x0b \x01(\r\x12\x18\n\x10reward_drop_list\x18\x0c \x01(\r\x12\x16\n\x0etournament_tag\x18\r \x01(\t\x12\x1a\n\x12steamdatagram_port\x18\x0e \x01(\r\"\xf4\x01\n.CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve\x12\x10\n\x08serverid\x18\x01 \x01(\x04\x12\x15\n\rdirect_udp_ip\x18\x02 \x01(\r\x12\x17\n\x0f\x64irect_udp_port\x18\x03 \x01(\r\x12\x15\n\rreservationid\x18\x04 \x01(\x04\x12\x44\n\x0breservation\x18\x05 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve\x12\x0b\n\x03map\x18\x06 \x01(\t\x12\x16\n\x0eserver_address\x18\x07 \x01(\t\"\xff\x05\n.CMsgGCCStrike15_v2_MatchmakingServerRoundStats\x12\x15\n\rreservationid\x18\x01 \x01(\x04\x12\x44\n\x0breservation\x18\x02 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve\x12\x0b\n\x03map\x18\x03 \x01(\t\x12\r\n\x05round\x18\x04 \x01(\x05\x12\r\n\x05kills\x18\x05 \x03(\x05\x12\x0f\n\x07\x61ssists\x18\x06 \x03(\x05\x12\x0e\n\x06\x64\x65\x61ths\x18\x07 \x03(\x05\x12\x0e\n\x06scores\x18\x08 \x03(\x05\x12\r\n\x05pings\x18\t \x03(\x05\x12\x14\n\x0cround_result\x18\n \x01(\x05\x12\x14\n\x0cmatch_result\x18\x0b \x01(\x05\x12\x13\n\x0bteam_scores\x18\x0c \x03(\x05\x12@\n\x07\x63onfirm\x18\r \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm\x12\x19\n\x11reservation_stage\x18\x0e \x01(\x05\x12\x16\n\x0ematch_duration\x18\x0f \x01(\x05\x12\x13\n\x0b\x65nemy_kills\x18\x10 \x03(\x05\x12\x17\n\x0f\x65nemy_headshots\x18\x11 \x03(\x05\x12\x11\n\tenemy_3ks\x18\x12 \x03(\x05\x12\x11\n\tenemy_4ks\x18\x13 \x03(\x05\x12\x11\n\tenemy_5ks\x18\x14 \x03(\x05\x12\x0c\n\x04mvps\x18\x15 \x03(\x05\x12\x18\n\x10spectators_count\x18\x16 \x01(\r\x12\x1b\n\x13spectators_count_tv\x18\x17 \x01(\r\x12\x1c\n\x14spectators_count_lnk\x18\x18 \x01(\r\x12\x17\n\x0f\x65nemy_kills_agg\x18\x19 \x03(\x05\x12K\n\tdrop_info\x18\x1a \x01(\x0b\x32\x38.CMsgGCCStrike15_v2_MatchmakingServerRoundStats.DropInfo\x1a\x1f\n\x08\x44ropInfo\x12\x13\n\x0b\x61\x63\x63ount_mvp\x18\x01 \x01(\r\"\xde\x02\n,CMsgGCCStrike15_v2_MatchmakingServerMatchEnd\x12>\n\x05stats\x18\x01 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingServerRoundStats\x12@\n\x07\x63onfirm\x18\x03 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm\x12\x0f\n\x07rematch\x18\x04 \x01(\x04\x12\x14\n\x0creplay_token\x18\x05 \x01(\r\x12\x19\n\x11replay_cluster_id\x18\x06 \x01(\r\x12\x15\n\raborted_match\x18\x07 \x01(\x08\x12;\n\x14match_end_quest_data\x18\x08 \x01(\x0b\x32\x1d.CMsgGC_ServerQuestUpdateData\x12\x16\n\x0eserver_version\x18\t \x01(\r\".\n,CMsgGCCStrike15_v2_MatchmakingClient2GCHello\"\xad\x05\n,CMsgGCCStrike15_v2_MatchmakingGC2ClientHello\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x45\n\x0congoingmatch\x18\x02 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve\x12\'\n\x0cglobal_stats\x18\x03 \x01(\x0b\x32\x11.GlobalStatistics\x12\x17\n\x0fpenalty_seconds\x18\x04 \x01(\r\x12\x16\n\x0epenalty_reason\x18\x05 \x01(\r\x12\x12\n\nvac_banned\x18\x06 \x01(\x05\x12#\n\x07ranking\x18\x07 \x01(\x0b\x32\x12.PlayerRankingInfo\x12-\n\x0c\x63ommendation\x18\x08 \x01(\x0b\x32\x17.PlayerCommendationInfo\x12!\n\x06medals\x18\t \x01(\x0b\x32\x11.PlayerMedalsInfo\x12*\n\x10my_current_event\x18\n \x01(\x0b\x32\x10.TournamentEvent\x12/\n\x16my_current_event_teams\x18\x0b \x03(\x0b\x32\x0f.TournamentTeam\x12(\n\x0fmy_current_team\x18\x0c \x01(\x0b\x32\x0f.TournamentTeam\x12\x31\n\x17my_current_event_stages\x18\r \x03(\x0b\x32\x10.TournamentEvent\x12\x13\n\x0bsurvey_vote\x18\x0e \x01(\r\x12\"\n\x08\x61\x63tivity\x18\x0f \x01(\x0b\x32\x10.AccountActivity\x12\x14\n\x0cplayer_level\x18\x11 \x01(\x05\x12\x15\n\rplayer_cur_xp\x18\x12 \x01(\x05\x12\x1d\n\x15player_xp_bonus_flags\x18\x13 \x01(\x05\"\xa9\x01\n)CMsgGCCStrike15_v2_AccountPrivacySettings\x12\x44\n\x08settings\x18\x01 \x03(\x0b\x32\x32.CMsgGCCStrike15_v2_AccountPrivacySettings.Setting\x1a\x36\n\x07Setting\x12\x14\n\x0csetting_type\x18\x01 \x01(\r\x12\x15\n\rsetting_value\x18\x02 \x01(\r\"\xbf\x01\n.CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12H\n\x0f\x61\x62\x61ndoned_match\x18\x02 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve\x12\x17\n\x0fpenalty_seconds\x18\x03 \x01(\r\x12\x16\n\x0epenalty_reason\x18\x04 \x01(\r\"\x97\x01\n+CMsgGCCStrike15_v2_MatchmakingServer2GCKick\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x44\n\x0breservation\x18\x02 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve\x12\x0e\n\x06reason\x18\x03 \x01(\r\"k\n1CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate\x12$\n\x08rankings\x18\x01 \x03(\x0b\x32\x12.PlayerRankingInfo\x12\x10\n\x08match_id\x18\x02 \x01(\x04\"L\n3CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate\x12\x15\n\rmain_post_url\x18\x01 \x01(\t\"j\n3CMsgGCCStrike15_v2_ServerNotificationForUserPenalty\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0e\n\x06reason\x18\x02 \x01(\r\x12\x0f\n\x07seconds\x18\x03 \x01(\r\"\xd3\x01\n%CMsgGCCStrike15_v2_ClientReportPlayer\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x12\n\nrpt_aimbot\x18\x02 \x01(\r\x12\x14\n\x0crpt_wallhack\x18\x03 \x01(\r\x12\x15\n\rrpt_speedhack\x18\x04 \x01(\r\x12\x14\n\x0crpt_teamharm\x18\x05 \x01(\r\x12\x15\n\rrpt_textabuse\x18\x06 \x01(\r\x12\x16\n\x0erpt_voiceabuse\x18\x07 \x01(\r\x12\x10\n\x08match_id\x18\x08 \x01(\x04\"\x8d\x01\n&CMsgGCCStrike15_v2_ClientCommendPlayer\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08match_id\x18\x08 \x01(\x04\x12-\n\x0c\x63ommendation\x18\t \x01(\x0b\x32\x17.PlayerCommendationInfo\x12\x0e\n\x06tokens\x18\n \x01(\r\"\xb5\x01\n%CMsgGCCStrike15_v2_ClientReportServer\x12\x14\n\x0crpt_poorperf\x18\x01 \x01(\r\x12\x19\n\x11rpt_abusivemodels\x18\x02 \x01(\r\x12\x13\n\x0brpt_badmotd\x18\x03 \x01(\r\x12\x18\n\x10rpt_listingabuse\x18\x04 \x01(\r\x12\x1a\n\x12rpt_inventoryabuse\x18\x05 \x01(\r\x12\x10\n\x08match_id\x18\x08 \x01(\x04\"\xa9\x01\n\'CMsgGCCStrike15_v2_ClientReportResponse\x12\x17\n\x0f\x63onfirmation_id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x11\n\tserver_ip\x18\x03 \x01(\r\x12\x15\n\rresponse_type\x18\x04 \x01(\r\x12\x17\n\x0fresponse_result\x18\x05 \x01(\r\x12\x0e\n\x06tokens\x18\x06 \x01(\r\"~\n0CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends\x12\x12\n\nrequest_id\x18\x01 \x01(\r\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\r\x12\x10\n\x08serverid\x18\x03 \x01(\x04\x12\x0f\n\x07matchid\x18\x04 \x01(\x04\"\xb0\x02\n\x12WatchableMatchInfo\x12\x11\n\tserver_ip\x18\x01 \x01(\r\x12\x0f\n\x07tv_port\x18\x02 \x01(\r\x12\x15\n\rtv_spectators\x18\x03 \x01(\r\x12\x0f\n\x07tv_time\x18\x04 \x01(\r\x12\x19\n\x11tv_watch_password\x18\x05 \x01(\x0c\x12\x1a\n\x12\x63l_decryptdata_key\x18\x06 \x01(\x04\x12\x1e\n\x16\x63l_decryptdata_key_pub\x18\x07 \x01(\x04\x12\x11\n\tgame_type\x18\x08 \x01(\r\x12\x15\n\rgame_mapgroup\x18\t \x01(\t\x12\x10\n\x08game_map\x18\n \x01(\t\x12\x11\n\tserver_id\x18\x0b \x01(\x04\x12\x10\n\x08match_id\x18\x0c \x01(\x04\x12\x16\n\x0ereservation_id\x18\r \x01(\x04\"\xcb\x01\n.CMsgGCCStrike15_v2_ClientRequestJoinFriendData\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x12\n\njoin_token\x18\x03 \x01(\r\x12\x10\n\x08join_ipp\x18\x04 \x01(\r\x12<\n\x03res\x18\x05 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve\x12\x10\n\x08\x65rrormsg\x18\x06 \x01(\t\"\xcd\x01\n.CMsgGCCStrike15_v2_ClientRequestJoinServerData\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x10\n\x08serverid\x18\x03 \x01(\x04\x12\x11\n\tserver_ip\x18\x04 \x01(\r\x12\x13\n\x0bserver_port\x18\x05 \x01(\r\x12<\n\x03res\x18\x06 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve\"U\n*CMsgGCCstrike15_v2_ClientRequestNewMission\x12\x12\n\nmission_id\x18\x02 \x01(\r\x12\x13\n\x0b\x63\x61mpaign_id\x18\x03 \x01(\r\"\xb1\x01\n,CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded\x12)\n\x10xp_progress_data\x18\x01 \x03(\x0b\x32\x0f.XpProgressData\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x12\n\ncurrent_xp\x18\x03 \x01(\r\x12\x15\n\rcurrent_level\x18\x04 \x01(\r\x12\x17\n\x0fupgraded_defidx\x18\x05 \x01(\r\"\x9a\x01\n!CMsgGCCStrike15_v2_WatchInfoUsers\x12\x12\n\nrequest_id\x18\x01 \x01(\r\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\r\x12\x32\n\x15watchable_match_infos\x18\x03 \x03(\x0b\x32\x13.WatchableMatchInfo\x12\x18\n\x10\x65xtended_timeout\x18\x05 \x01(\r\"\x9c\x01\n.CMsgGCCStrike15_v2_ClientRequestPlayersProfile\x12\x1e\n\x16request_id__deprecated\x18\x01 \x01(\r\x12\x1f\n\x17\x61\x63\x63ount_ids__deprecated\x18\x02 \x03(\r\x12\x12\n\naccount_id\x18\x03 \x01(\r\x12\x15\n\rrequest_level\x18\x04 \x01(\r\"\x80\x01\n!CMsgGCCStrike15_v2_PlayersProfile\x12\x12\n\nrequest_id\x18\x01 \x01(\r\x12G\n\x10\x61\x63\x63ount_profiles\x18\x02 \x03(\x0b\x32-.CMsgGCCStrike15_v2_MatchmakingGC2ClientHello\"\xcc\x01\n,CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate\x12\x0e\n\x06\x63\x61seid\x18\x01 \x01(\x04\x12\x11\n\tsuspectid\x18\x03 \x01(\r\x12\x12\n\nfractionid\x18\x04 \x01(\r\x12\x12\n\nrpt_aimbot\x18\x05 \x01(\r\x12\x14\n\x0crpt_wallhack\x18\x06 \x01(\r\x12\x15\n\rrpt_speedhack\x18\x07 \x01(\r\x12\x14\n\x0crpt_teamharm\x18\x08 \x01(\r\x12\x0e\n\x06reason\x18\t \x01(\r\"\x8d\x02\n0CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment\x12\x0e\n\x06\x63\x61seid\x18\x01 \x01(\x04\x12\x0f\n\x07\x63\x61seurl\x18\x02 \x01(\t\x12\x0f\n\x07verdict\x18\x03 \x01(\r\x12\x11\n\ttimestamp\x18\x04 \x01(\r\x12\x17\n\x0fthrottleseconds\x18\x05 \x01(\r\x12\x11\n\tsuspectid\x18\x06 \x01(\r\x12\x12\n\nfractionid\x18\x07 \x01(\r\x12\x11\n\tnumrounds\x18\x08 \x01(\r\x12\x16\n\x0e\x66ractionrounds\x18\t \x01(\r\x12\x19\n\x11streakconvictions\x18\n \x01(\x05\x12\x0e\n\x06reason\x18\x0b \x01(\r\"P\n,CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus\x12\x0e\n\x06\x63\x61seid\x18\x01 \x01(\x04\x12\x10\n\x08statusid\x18\x02 \x01(\r\"C\n\x1e\x43\x43lientHeaderOverwatchEvidence\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0e\n\x06\x63\x61seid\x18\x02 \x01(\x04\"P\n#CMsgGCCStrike15_v2_GC2ClientTextMsg\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"?\n#CMsgGCCStrike15_v2_Client2GCTextMsg\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\x0c\"\xb6\x01\n)CMsgGCCStrike15_v2_MatchEndRunRewardDrops\x12L\n\nserverinfo\x18\x03 \x01(\x0b\x32\x38.CMsgGCCStrike15_v2_MatchmakingServerReservationResponse\x12;\n\x14match_end_quest_data\x18\x04 \x01(\x0b\x32\x1d.CMsgGC_ServerQuestUpdateData\"\xf2\x03\n\x19\x43\x45\x63onItemPreviewDataBlock\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08\x64\x65\x66index\x18\x03 \x01(\r\x12\x12\n\npaintindex\x18\x04 \x01(\r\x12\x0e\n\x06rarity\x18\x05 \x01(\r\x12\x0f\n\x07quality\x18\x06 \x01(\r\x12\x11\n\tpaintwear\x18\x07 \x01(\r\x12\x11\n\tpaintseed\x18\x08 \x01(\r\x12\x1a\n\x12killeaterscoretype\x18\t \x01(\r\x12\x16\n\x0ekilleatervalue\x18\n \x01(\r\x12\x12\n\ncustomname\x18\x0b \x01(\t\x12\x34\n\x08stickers\x18\x0c \x03(\x0b\x32\".CEconItemPreviewDataBlock.Sticker\x12\x11\n\tinventory\x18\r \x01(\r\x12\x0e\n\x06origin\x18\x0e \x01(\r\x12\x0f\n\x07questid\x18\x0f \x01(\r\x12\x12\n\ndropreason\x18\x10 \x01(\r\x12\x12\n\nmusicindex\x18\x11 \x01(\r\x1ak\n\x07Sticker\x12\x0c\n\x04slot\x18\x01 \x01(\r\x12\x12\n\nsticker_id\x18\x02 \x01(\r\x12\x0c\n\x04wear\x18\x03 \x01(\x02\x12\r\n\x05scale\x18\x04 \x01(\x02\x12\x10\n\x08rotation\x18\x05 \x01(\x02\x12\x0f\n\x07tint_id\x18\x06 \x01(\r\"b\n2CMsgGCCStrike15_v2_MatchEndRewardDropsNotification\x12,\n\x08iteminfo\x18\x06 \x01(\x0b\x32\x1a.CEconItemPreviewDataBlock\"D\n\x14\x43MsgItemAcknowledged\x12,\n\x08iteminfo\x18\x01 \x01(\x0b\x32\x1a.CEconItemPreviewDataBlock\"}\n7CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest\x12\x0f\n\x07param_s\x18\x01 \x01(\x04\x12\x0f\n\x07param_a\x18\x02 \x01(\x04\x12\x0f\n\x07param_d\x18\x03 \x01(\x04\x12\x0f\n\x07param_m\x18\x04 \x01(\x04\"h\n8CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse\x12,\n\x08iteminfo\x18\x01 \x01(\x0b\x32\x1a.CEconItemPreviewDataBlock\"s\n9CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x10\n\x08\x64\x65\x66index\x18\x02 \x01(\r\x12\x12\n\naccountids\x18\x03 \x03(\r\"5\n3CMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames\"G\n2CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser\x12\x11\n\taccountid\x18\x01 \x01(\r\"G\n2CMsgGCCStrike15_v2_MatchListRequestRecentUserGames\x12\x11\n\taccountid\x18\x01 \x01(\r\"E\n2CMsgGCCStrike15_v2_MatchListRequestTournamentGames\x12\x0f\n\x07\x65ventid\x18\x01 \x01(\x05\"d\n/CMsgGCCStrike15_v2_MatchListRequestFullGameInfo\x12\x0f\n\x07matchid\x18\x01 \x01(\x04\x12\x11\n\toutcomeid\x18\x02 \x01(\x04\x12\r\n\x05token\x18\x03 \x01(\r\"\x88\x02\n\x1d\x43\x44\x61taGCCStrike15_v2_MatchInfo\x12\x0f\n\x07matchid\x18\x01 \x01(\x04\x12\x11\n\tmatchtime\x18\x02 \x01(\r\x12/\n\x12watchablematchinfo\x18\x03 \x01(\x0b\x32\x13.WatchableMatchInfo\x12J\n\x11roundstats_legacy\x18\x04 \x01(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingServerRoundStats\x12\x46\n\rroundstatsall\x18\x05 \x03(\x0b\x32/.CMsgGCCStrike15_v2_MatchmakingServerRoundStats\"^\n\'CDataGCCStrike15_v2_TournamentGroupTeam\x12\x0f\n\x07team_id\x18\x01 \x01(\x05\x12\r\n\x05score\x18\x02 \x01(\x05\x12\x13\n\x0b\x63orrectpick\x18\x03 \x01(\x08\"\xd9\x02\n#CDataGCCStrike15_v2_TournamentGroup\x12\x0f\n\x07groupid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x19\n\x11picks__deprecated\x18\x04 \x01(\r\x12\x37\n\x05teams\x18\x05 \x03(\x0b\x32(.CDataGCCStrike15_v2_TournamentGroupTeam\x12\x11\n\tstage_ids\x18\x06 \x03(\x05\x12\x19\n\x11picklockuntiltime\x18\x07 \x01(\r\x12\x15\n\rpickableteams\x18\x08 \x01(\r\x12\x17\n\x0fpoints_per_pick\x18\t \x01(\r\x12\x39\n\x05picks\x18\n \x03(\x0b\x32*.CDataGCCStrike15_v2_TournamentGroup.Picks\x1a\x18\n\x05Picks\x12\x0f\n\x07pickids\x18\x01 \x03(\x05\"\x8c\x01\n%CDataGCCStrike15_v2_TournamentSection\x12\x11\n\tsectionid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x34\n\x06groups\x18\x04 \x03(\x0b\x32$.CDataGCCStrike15_v2_TournamentGroup\"\xb5\x01\n\"CDataGCCStrike15_v2_TournamentInfo\x12\x38\n\x08sections\x18\x01 \x03(\x0b\x32&.CDataGCCStrike15_v2_TournamentSection\x12*\n\x10tournament_event\x18\x02 \x01(\x0b\x32\x10.TournamentEvent\x12)\n\x10tournament_teams\x18\x03 \x03(\x0b\x32\x0f.TournamentTeam\"\xeb\x01\n\x1c\x43MsgGCCStrike15_v2_MatchList\x12\x14\n\x0cmsgrequestid\x18\x01 \x01(\r\x12\x11\n\taccountid\x18\x02 \x01(\r\x12\x12\n\nservertime\x18\x03 \x01(\r\x12/\n\x07matches\x18\x04 \x03(\x0b\x32\x1e.CDataGCCStrike15_v2_MatchInfo\x12 \n\x07streams\x18\x05 \x03(\x0b\x32\x0f.TournamentTeam\x12;\n\x0etournamentinfo\x18\x06 \x01(\x0b\x32#.CDataGCCStrike15_v2_TournamentInfo\"\xef\x01\n\x1e\x43MsgGCCStrike15_v2_Predictions\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12R\n\x16group_match_team_picks\x18\x02 \x03(\x0b\x32\x32.CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick\x1ag\n\x12GroupMatchTeamPick\x12\x11\n\tsectionid\x18\x01 \x01(\x05\x12\x0f\n\x07groupid\x18\x02 \x01(\x05\x12\r\n\x05index\x18\x03 \x01(\x05\x12\x0e\n\x06teamid\x18\x04 \x01(\x05\x12\x0e\n\x06itemid\x18\x05 \x01(\x04\"\xfb\x01\n\x1a\x43MsgGCCStrike15_v2_Fantasy\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x36\n\x05teams\x18\x02 \x03(\x0b\x32\'.CMsgGCCStrike15_v2_Fantasy.FantasyTeam\x1a\x39\n\x0b\x46\x61ntasySlot\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04pick\x18\x02 \x01(\x05\x12\x0e\n\x06itemid\x18\x03 \x01(\x04\x1aX\n\x0b\x46\x61ntasyTeam\x12\x11\n\tsectionid\x18\x01 \x01(\x05\x12\x36\n\x05slots\x18\x02 \x03(\x0b\x32\'.CMsgGCCStrike15_v2_Fantasy.FantasySlot\"\"\n\x11\x43\x41ttribute_String\x12\r\n\x05value\x18\x01 \x01(\t\"\x1a\n\x18\x43MsgGCToGCReloadVersions\"\xc4\x01\n\x14\x43MsgCStrike15Welcome\x12\x17\n\x0fstore_item_hash\x18\x05 \x01(\r\x12\x1f\n\x17timeplayedconsecutively\x18\x06 \x01(\r\x12\x19\n\x11time_first_played\x18\n \x01(\r\x12\x18\n\x10last_time_played\x18\x0c \x01(\r\x12\x17\n\x0flast_ip_address\x18\r \x01(\r\x12\x12\n\ngscookieid\x18\x12 \x01(\x04\x12\x10\n\x08uniqueid\x18\x13 \x01(\x04\"\x9b\x01\n1CMsgGCCStrike15_v2_ClientVarValueNotificationInfo\x12\x12\n\nvalue_name\x18\x01 \x01(\t\x12\x11\n\tvalue_int\x18\x02 \x01(\x05\x12\x13\n\x0bserver_addr\x18\x03 \x01(\r\x12\x13\n\x0bserver_port\x18\x04 \x01(\r\x12\x15\n\rchoked_blocks\x18\x05 \x03(\t\"h\n1CMsgGCCStrike15_v2_ServerVarValueNotificationInfo\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x12\n\nviewangles\x18\x02 \x03(\r\x12\x0c\n\x04type\x18\x03 \x01(\r\",\n*CMsgGCCStrike15_v2_GiftsLeaderboardRequest\"\x9d\x02\n+CMsgGCCStrike15_v2_GiftsLeaderboardResponse\x12\x12\n\nservertime\x18\x01 \x01(\r\x12\x1b\n\x13time_period_seconds\x18\x02 \x01(\r\x12\x19\n\x11total_gifts_given\x18\x03 \x01(\r\x12\x14\n\x0ctotal_givers\x18\x04 \x01(\r\x12R\n\x07\x65ntries\x18\x05 \x03(\x0b\x32\x41.CMsgGCCStrike15_v2_GiftsLeaderboardResponse.GiftLeaderboardEntry\x1a\x38\n\x14GiftLeaderboardEntry\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\r\n\x05gifts\x18\x02 \x01(\r\"L\n)CMsgGCCStrike15_v2_ClientSubmitSurveyVote\x12\x11\n\tsurvey_id\x18\x01 \x01(\r\x12\x0c\n\x04vote\x18\x02 \x01(\r\"?\n*CMsgGCCStrike15_v2_Server2GCClientValidate\x12\x11\n\taccountid\x18\x01 \x01(\r\"\xbb\x01\n7CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04\x66ile\x18\x03 \x01(\t\x12\x0b\n\x03\x63rc\x18\x04 \x01(\r\x12\x0c\n\x04hash\x18\x05 \x01(\x05\x12\x0b\n\x03len\x18\x06 \x01(\x05\x12\x13\n\x0bpack_number\x18\x07 \x01(\x05\x12\x14\n\x0cpack_file_id\x18\x08 \x01(\x05\"r\n*CMsgGCCStrike15_v2_GC2ClientTournamentInfo\x12\x0f\n\x07\x65ventid\x18\x01 \x01(\r\x12\x0f\n\x07stageid\x18\x02 \x01(\r\x12\x11\n\tgame_type\x18\x03 \x01(\r\x12\x0f\n\x07teamids\x18\x04 \x03(\r\"O\n\rCSOEconCoupon\x12\x15\n\x07\x65ntryid\x18\x01 \x01(\rB\x04\x80\xa6\x1d\x01\x12\x0e\n\x06\x64\x65\x66idx\x18\x02 \x01(\r\x12\x17\n\x0f\x65xpiration_date\x18\x03 \x01(\x07\"Y\n\x10\x43SOQuestProgress\x12\x15\n\x07questid\x18\x01 \x01(\rB\x04\x80\xa6\x1d\x01\x12\x18\n\x10points_remaining\x18\x02 \x01(\r\x12\x14\n\x0c\x62onus_points\x18\x03 \x01(\r\"s\n\x14\x43SOPersonaDataPublic\x12\x14\n\x0cplayer_level\x18\x01 \x01(\x05\x12-\n\x0c\x63ommendation\x18\x02 \x01(\x0b\x32\x17.PlayerCommendationInfo\x12\x16\n\x0e\x65levated_state\x18\x03 \x01(\x08\"-\n\x1b\x43MsgGC_GlobalGame_Subscribe\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\"1\n\x1d\x43MsgGC_GlobalGame_Unsubscribe\x12\x10\n\x08timeleft\x18\x01 \x01(\x05\"P\n\x16\x43MsgGC_GlobalGame_Play\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\x12\x12\n\ngametimems\x18\x02 \x01(\r\x12\x12\n\nmsperpoint\x18\x03 \x01(\r\"=\n%CMsgGCCStrike15_v2_AcknowledgePenalty\x12\x14\n\x0c\x61\x63knowledged\x18\x01 \x01(\x05\"1\n/CMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin\"F\n(CMsgGCCStrike15_v2_Client2GCStreamUnlock\x12\x0e\n\x06ticket\x18\x01 \x01(\x04\x12\n\n\x02os\x18\x02 \x01(\x05\"<\n+CMsgGCCStrike15_v2_ClientToGCRequestElevate\x12\r\n\x05stage\x18\x01 \x01(\r\"C\n!CMsgGCCStrike15_v2_ClientToGCChat\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x0c\n\x04text\x18\x02 \x01(\t\"E\n!CMsgGCCStrike15_v2_GCToClientChat\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0c\n\x04text\x18\x02 \x01(\t\"E\n$CMsgGCCStrike15_v2_ClientAuthKeyCode\x12\x0f\n\x07\x65ventid\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"F\n\x1e\x43MsgGCCStrike15_GotvSyncPacket\x12$\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x16.CEngineGotvSyncPacket\"\x94\x02\n\x1bPlayerDecalDigitalSignature\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12\x11\n\taccountid\x18\x02 \x01(\r\x12\r\n\x05rtime\x18\x03 \x01(\r\x12\x0e\n\x06\x65ndpos\x18\x04 \x03(\x02\x12\x10\n\x08startpos\x18\x05 \x03(\x02\x12\r\n\x05right\x18\x06 \x03(\x02\x12\x11\n\ttx_defidx\x18\x07 \x01(\r\x12\x10\n\x08\x65ntindex\x18\x08 \x01(\x05\x12\x0e\n\x06hitbox\x18\t \x01(\r\x12\x14\n\x0c\x63reationtime\x18\n \x01(\x02\x12\x11\n\tequipslot\x18\x0b \x01(\r\x12\x10\n\x08trace_id\x18\x0c \x01(\r\x12\x0e\n\x06normal\x18\r \x03(\x02\x12\x0f\n\x07tint_id\x18\x0e \x01(\r\"f\n(CMsgGCCStrike15_v2_ClientPlayerDecalSign\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.PlayerDecalDigitalSignature\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\"N\n(CMsgGCCStrike15_v2_ClientLogonFatalError\x12\x11\n\terrorcode\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"S\n\"CMsgGCCStrike15_v2_ClientPollState\x12\x0e\n\x06pollid\x18\x01 \x01(\r\x12\r\n\x05names\x18\x02 \x03(\t\x12\x0e\n\x06values\x18\x03 \x03(\x05\"\x91\x01\n!CMsgGCCStrike15_v2_Party_Register\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0b\n\x03ver\x18\x02 \x01(\r\x12\x0b\n\x03\x61pr\x18\x03 \x01(\r\x12\x0b\n\x03\x61rk\x18\x04 \x01(\r\x12\x0b\n\x03nby\x18\x05 \x01(\r\x12\x0b\n\x03grp\x18\x06 \x01(\r\x12\r\n\x05slots\x18\x07 \x01(\r\x12\x10\n\x08launcher\x18\x08 \x01(\r\"h\n\x1f\x43MsgGCCStrike15_v2_Party_Search\x12\x0b\n\x03ver\x18\x01 \x01(\r\x12\x0b\n\x03\x61pr\x18\x02 \x01(\r\x12\x0b\n\x03\x61rk\x18\x03 \x01(\r\x12\x0c\n\x04grps\x18\x04 \x03(\r\x12\x10\n\x08launcher\x18\x05 \x01(\r\"\x8a\x01\n&CMsgGCCStrike15_v2_Party_SearchResults\x12>\n\x07\x65ntries\x18\x01 \x03(\x0b\x32-.CMsgGCCStrike15_v2_Party_SearchResults.Entry\x1a \n\x05\x45ntry\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0b\n\x03grp\x18\x02 \x01(\r\"E\n\x1f\x43MsgGCCStrike15_v2_Party_Invite\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0f\n\x07lobbyid\x18\x02 \x01(\r\"\xc2\x01\n)CMsgGCCStrike15_v2_Account_RequestCoPlays\x12\x42\n\x07players\x18\x01 \x03(\x0b\x32\x31.CMsgGCCStrike15_v2_Account_RequestCoPlays.Player\x12\x12\n\nservertime\x18\x02 \x01(\r\x1a=\n\x06Player\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x10\n\x08rtcoplay\x18\x02 \x01(\r\x12\x0e\n\x06online\x18\x03 \x01(\x08\"\x9f\x01\n*CMsgGCCStrike15_v2_ClientToGCRequestTicket\x12\x1b\n\x13\x61uthorized_steam_id\x18\x01 \x01(\x06\x12\x1c\n\x14\x61uthorized_public_ip\x18\x02 \x01(\x07\x12\x1b\n\x13gameserver_steam_id\x18\x03 \x01(\x06\x12\x19\n\x11gameserver_net_id\x18\x04 \x01(\x06*\xf5#\n\nECsgoGCMsg\x12\x1e\n\x19k_EMsgGCCStrike15_v2_Base\x10\x8cG\x12*\n%k_EMsgGCCStrike15_v2_MatchmakingStart\x10\x8dG\x12)\n$k_EMsgGCCStrike15_v2_MatchmakingStop\x10\x8eG\x12\x36\n1k_EMsgGCCStrike15_v2_MatchmakingClient2ServerPing\x10\x8fG\x12\x34\n/k_EMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate\x10\x90G\x12\x35\n0k_EMsgGCCStrike15_v2_MatchmakingGC2ServerReserve\x10\x91G\x12>\n9k_EMsgGCCStrike15_v2_MatchmakingServerReservationResponse\x10\x92G\x12\x35\n0k_EMsgGCCStrike15_v2_MatchmakingGC2ClientReserve\x10\x93G\x12\x35\n0k_EMsgGCCStrike15_v2_MatchmakingServerRoundStats\x10\x94G\x12\x33\n.k_EMsgGCCStrike15_v2_MatchmakingClient2GCHello\x10\x95G\x12\x33\n.k_EMsgGCCStrike15_v2_MatchmakingGC2ClientHello\x10\x96G\x12\x33\n.k_EMsgGCCStrike15_v2_MatchmakingServerMatchEnd\x10\x97G\x12\x35\n0k_EMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon\x10\x98G\x12\x32\n-k_EMsgGCCStrike15_v2_MatchmakingServer2GCKick\x10\x99G\x12\x35\n0k_EMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm\x10\x9aG\x12\x37\n2k_EMsgGCCStrike15_v2_MatchmakingGCOperationalStats\x10\x9bG\x12\x38\n3k_EMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate\x10\x9cG\x12:\n5k_EMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate\x10\x9dG\x12:\n5k_EMsgGCCStrike15_v2_ServerNotificationForUserPenalty\x10\x9eG\x12,\n\'k_EMsgGCCStrike15_v2_ClientReportPlayer\x10\x9fG\x12,\n\'k_EMsgGCCStrike15_v2_ClientReportServer\x10\xa0G\x12-\n(k_EMsgGCCStrike15_v2_ClientCommendPlayer\x10\xa1G\x12.\n)k_EMsgGCCStrike15_v2_ClientReportResponse\x10\xa2G\x12\x32\n-k_EMsgGCCStrike15_v2_ClientCommendPlayerQuery\x10\xa3G\x12:\n5k_EMsgGCCStrike15_v2_ClientCommendPlayerQueryResponse\x10\xa4G\x12(\n#k_EMsgGCCStrike15_v2_WatchInfoUsers\x10\xa6G\x12\x35\n0k_EMsgGCCStrike15_v2_ClientRequestPlayersProfile\x10\xa7G\x12(\n#k_EMsgGCCStrike15_v2_PlayersProfile\x10\xa8G\x12)\n$k_EMsgGCCStrike15_v2_SetMyMedalsInfo\x10\xa9G\x12\x33\n.k_EMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate\x10\xabG\x12\x37\n2k_EMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment\x10\xacG\x12\x33\n.k_EMsgGCCStrike15_v2_PlayerOverwatchCaseStatus\x10\xadG\x12*\n%k_EMsgGCCStrike15_v2_GC2ClientTextMsg\x10\xaeG\x12*\n%k_EMsgGCCStrike15_v2_Client2GCTextMsg\x10\xafG\x12\x30\n+k_EMsgGCCStrike15_v2_MatchEndRunRewardDrops\x10\xb0G\x12\x39\n4k_EMsgGCCStrike15_v2_MatchEndRewardDropsNotification\x10\xb1G\x12\x38\n3k_EMsgGCCStrike15_v2_ClientRequestWatchInfoFriends2\x10\xb2G\x12#\n\x1ek_EMsgGCCStrike15_v2_MatchList\x10\xb3G\x12:\n5k_EMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames\x10\xb4G\x12\x39\n4k_EMsgGCCStrike15_v2_MatchListRequestRecentUserGames\x10\xb5G\x12\x34\n/k_EMsgGCCStrike15_v2_GC2ServerReservationUpdate\x10\xb6G\x12\x38\n3k_EMsgGCCStrike15_v2_ClientVarValueNotificationInfo\x10\xb8G\x12@\n;k_EMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification\x10\xb9G\x12\x39\n4k_EMsgGCCStrike15_v2_MatchListRequestTournamentGames\x10\xbaG\x12\x36\n1k_EMsgGCCStrike15_v2_MatchListRequestFullGameInfo\x10\xbbG\x12\x31\n,k_EMsgGCCStrike15_v2_GiftsLeaderboardRequest\x10\xbcG\x12\x32\n-k_EMsgGCCStrike15_v2_GiftsLeaderboardResponse\x10\xbdG\x12\x38\n3k_EMsgGCCStrike15_v2_ServerVarValueNotificationInfo\x10\xbeG\x12\x1f\n\x1ak_EMsgGCToGCReloadVersions\x10\xbfG\x12\x30\n+k_EMsgGCCStrike15_v2_ClientSubmitSurveyVote\x10\xc0G\x12\x31\n,k_EMsgGCCStrike15_v2_Server2GCClientValidate\x10\xc1G\x12\x39\n4k_EMsgGCCStrike15_v2_MatchListRequestLiveGameForUser\x10\xc2G\x12>\n9k_EMsgGCCStrike15_v2_Server2GCPureServerValidationFailure\x10\xc3G\x12>\n9k_EMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest\x10\xc4G\x12?\n:k_EMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse\x10\xc5G\x12\x30\n+k_EMsgGCCStrike15_v2_AccountPrivacySettings\x10\xc6G\x12+\n&k_EMsgGCCStrike15_v2_SetMyActivityInfo\x10\xc7G\x12?\n:k_EMsgGCCStrike15_v2_MatchListRequestTournamentPredictions\x10\xc8G\x12>\n9k_EMsgGCCStrike15_v2_MatchListUploadTournamentPredictions\x10\xc9G\x12&\n!k_EMsgGCCStrike15_v2_DraftSummary\x10\xcaG\x12\x35\n0k_EMsgGCCStrike15_v2_ClientRequestJoinFriendData\x10\xcbG\x12\x35\n0k_EMsgGCCStrike15_v2_ClientRequestJoinServerData\x10\xccG\x12\x31\n,k_EMsgGCCStrike15_v2_ClientRequestNewMission\x10\xcdG\x12\x33\n.k_EMsgGCCStrike15_v2_GC2ServerNotifyXPRewarded\x10\xceG\x12\x31\n,k_EMsgGCCStrike15_v2_GC2ClientTournamentInfo\x10\xcfG\x12\"\n\x1dk_EMsgGC_GlobalGame_Subscribe\x10\xd0G\x12$\n\x1fk_EMsgGC_GlobalGame_Unsubscribe\x10\xd1G\x12\x1d\n\x18k_EMsgGC_GlobalGame_Play\x10\xd2G\x12,\n\'k_EMsgGCCStrike15_v2_AcknowledgePenalty\x10\xd3G\x12\x36\n1k_EMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin\x10\xd4G\x12.\n)k_EMsgGCCStrike15_v2_GC2ClientGlobalStats\x10\xd5G\x12/\n*k_EMsgGCCStrike15_v2_Client2GCStreamUnlock\x10\xd6G\x12\x32\n-k_EMsgGCCStrike15_v2_FantasyRequestClientData\x10\xd7G\x12\x31\n,k_EMsgGCCStrike15_v2_FantasyUpdateClientData\x10\xd8G\x12\x37\n2k_EMsgGCCStrike15_v2_GCToClientSteamdatagramTicket\x10\xd9G\x12\x31\n,k_EMsgGCCStrike15_v2_ClientToGCRequestTicket\x10\xdaG\x12\x32\n-k_EMsgGCCStrike15_v2_ClientToGCRequestElevate\x10\xdbG\x12$\n\x1fk_EMsgGCCStrike15_v2_GlobalChat\x10\xdcG\x12.\n)k_EMsgGCCStrike15_v2_GlobalChat_Subscribe\x10\xddG\x12\x30\n+k_EMsgGCCStrike15_v2_GlobalChat_Unsubscribe\x10\xdeG\x12+\n&k_EMsgGCCStrike15_v2_ClientAuthKeyCode\x10\xdfG\x12(\n#k_EMsgGCCStrike15_v2_GotvSyncPacket\x10\xe0G\x12/\n*k_EMsgGCCStrike15_v2_ClientPlayerDecalSign\x10\xe1G\x12/\n*k_EMsgGCCStrike15_v2_ClientLogonFatalError\x10\xe3G\x12)\n$k_EMsgGCCStrike15_v2_ClientPollState\x10\xe4G\x12(\n#k_EMsgGCCStrike15_v2_Party_Register\x10\xe5G\x12*\n%k_EMsgGCCStrike15_v2_Party_Unregister\x10\xe6G\x12&\n!k_EMsgGCCStrike15_v2_Party_Search\x10\xe7G\x12&\n!k_EMsgGCCStrike15_v2_Party_Invite\x10\xe8G\x12\x30\n+k_EMsgGCCStrike15_v2_Account_RequestCoPlays\x10\xe9GB\x05H\x01\x80\x01\x00')
  ,
  dependencies=[demoparser_dot_protobufs_dot_steammessages__pb2.DESCRIPTOR,demoparser_dot_protobufs_dot_engine__gcmessages__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ECSGOGCMSG = _descriptor.EnumDescriptor(
  name='ECsgoGCMsg',
  full_name='ECsgoGCMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Base', index=0, number=9100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingStart', index=1, number=9101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingStop', index=2, number=9102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingClient2ServerPing', index=3, number=9103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate', index=4, number=9104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingGC2ServerReserve', index=5, number=9105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingServerReservationResponse', index=6, number=9106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingGC2ClientReserve', index=7, number=9107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingServerRoundStats', index=8, number=9108,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingClient2GCHello', index=9, number=9109,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingGC2ClientHello', index=10, number=9110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingServerMatchEnd', index=11, number=9111,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon', index=12, number=9112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingServer2GCKick', index=13, number=9113,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm', index=14, number=9114,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingGCOperationalStats', index=15, number=9115,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate', index=16, number=9116,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate', index=17, number=9117,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ServerNotificationForUserPenalty', index=18, number=9118,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientReportPlayer', index=19, number=9119,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientReportServer', index=20, number=9120,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientCommendPlayer', index=21, number=9121,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientReportResponse', index=22, number=9122,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientCommendPlayerQuery', index=23, number=9123,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientCommendPlayerQueryResponse', index=24, number=9124,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_WatchInfoUsers', index=25, number=9126,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientRequestPlayersProfile', index=26, number=9127,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_PlayersProfile', index=27, number=9128,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_SetMyMedalsInfo', index=28, number=9129,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate', index=29, number=9131,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment', index=30, number=9132,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_PlayerOverwatchCaseStatus', index=31, number=9133,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GC2ClientTextMsg', index=32, number=9134,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Client2GCTextMsg', index=33, number=9135,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchEndRunRewardDrops', index=34, number=9136,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchEndRewardDropsNotification', index=35, number=9137,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientRequestWatchInfoFriends2', index=36, number=9138,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchList', index=37, number=9139,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames', index=38, number=9140,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchListRequestRecentUserGames', index=39, number=9141,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GC2ServerReservationUpdate', index=40, number=9142,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientVarValueNotificationInfo', index=41, number=9144,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification', index=42, number=9145,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchListRequestTournamentGames', index=43, number=9146,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchListRequestFullGameInfo', index=44, number=9147,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GiftsLeaderboardRequest', index=45, number=9148,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GiftsLeaderboardResponse', index=46, number=9149,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ServerVarValueNotificationInfo', index=47, number=9150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCReloadVersions', index=48, number=9151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientSubmitSurveyVote', index=49, number=9152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Server2GCClientValidate', index=50, number=9153,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchListRequestLiveGameForUser', index=51, number=9154,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Server2GCPureServerValidationFailure', index=52, number=9155,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest', index=53, number=9156,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse', index=54, number=9157,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_AccountPrivacySettings', index=55, number=9158,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_SetMyActivityInfo', index=56, number=9159,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchListRequestTournamentPredictions', index=57, number=9160,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_MatchListUploadTournamentPredictions', index=58, number=9161,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_DraftSummary', index=59, number=9162,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientRequestJoinFriendData', index=60, number=9163,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientRequestJoinServerData', index=61, number=9164,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientRequestNewMission', index=62, number=9165,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GC2ServerNotifyXPRewarded', index=63, number=9166,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GC2ClientTournamentInfo', index=64, number=9167,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_GlobalGame_Subscribe', index=65, number=9168,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_GlobalGame_Unsubscribe', index=66, number=9169,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_GlobalGame_Play', index=67, number=9170,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_AcknowledgePenalty', index=68, number=9171,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin', index=69, number=9172,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GC2ClientGlobalStats', index=70, number=9173,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Client2GCStreamUnlock', index=71, number=9174,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_FantasyRequestClientData', index=72, number=9175,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_FantasyUpdateClientData', index=73, number=9176,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GCToClientSteamdatagramTicket', index=74, number=9177,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientToGCRequestTicket', index=75, number=9178,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientToGCRequestElevate', index=76, number=9179,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GlobalChat', index=77, number=9180,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GlobalChat_Subscribe', index=78, number=9181,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GlobalChat_Unsubscribe', index=79, number=9182,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientAuthKeyCode', index=80, number=9183,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_GotvSyncPacket', index=81, number=9184,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientPlayerDecalSign', index=82, number=9185,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientLogonFatalError', index=83, number=9187,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_ClientPollState', index=84, number=9188,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Party_Register', index=85, number=9189,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Party_Unregister', index=86, number=9190,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Party_Search', index=87, number=9191,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Party_Invite', index=88, number=9192,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCStrike15_v2_Account_RequestCoPlays', index=89, number=9193,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=19654,
  serialized_end=24251,
)
_sym_db.RegisterEnumDescriptor(_ECSGOGCMSG)

ECsgoGCMsg = enum_type_wrapper.EnumTypeWrapper(_ECSGOGCMSG)
k_EMsgGCCStrike15_v2_Base = 9100
k_EMsgGCCStrike15_v2_MatchmakingStart = 9101
k_EMsgGCCStrike15_v2_MatchmakingStop = 9102
k_EMsgGCCStrike15_v2_MatchmakingClient2ServerPing = 9103
k_EMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate = 9104
k_EMsgGCCStrike15_v2_MatchmakingGC2ServerReserve = 9105
k_EMsgGCCStrike15_v2_MatchmakingServerReservationResponse = 9106
k_EMsgGCCStrike15_v2_MatchmakingGC2ClientReserve = 9107
k_EMsgGCCStrike15_v2_MatchmakingServerRoundStats = 9108
k_EMsgGCCStrike15_v2_MatchmakingClient2GCHello = 9109
k_EMsgGCCStrike15_v2_MatchmakingGC2ClientHello = 9110
k_EMsgGCCStrike15_v2_MatchmakingServerMatchEnd = 9111
k_EMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon = 9112
k_EMsgGCCStrike15_v2_MatchmakingServer2GCKick = 9113
k_EMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm = 9114
k_EMsgGCCStrike15_v2_MatchmakingGCOperationalStats = 9115
k_EMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate = 9116
k_EMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate = 9117
k_EMsgGCCStrike15_v2_ServerNotificationForUserPenalty = 9118
k_EMsgGCCStrike15_v2_ClientReportPlayer = 9119
k_EMsgGCCStrike15_v2_ClientReportServer = 9120
k_EMsgGCCStrike15_v2_ClientCommendPlayer = 9121
k_EMsgGCCStrike15_v2_ClientReportResponse = 9122
k_EMsgGCCStrike15_v2_ClientCommendPlayerQuery = 9123
k_EMsgGCCStrike15_v2_ClientCommendPlayerQueryResponse = 9124
k_EMsgGCCStrike15_v2_WatchInfoUsers = 9126
k_EMsgGCCStrike15_v2_ClientRequestPlayersProfile = 9127
k_EMsgGCCStrike15_v2_PlayersProfile = 9128
k_EMsgGCCStrike15_v2_SetMyMedalsInfo = 9129
k_EMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate = 9131
k_EMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment = 9132
k_EMsgGCCStrike15_v2_PlayerOverwatchCaseStatus = 9133
k_EMsgGCCStrike15_v2_GC2ClientTextMsg = 9134
k_EMsgGCCStrike15_v2_Client2GCTextMsg = 9135
k_EMsgGCCStrike15_v2_MatchEndRunRewardDrops = 9136
k_EMsgGCCStrike15_v2_MatchEndRewardDropsNotification = 9137
k_EMsgGCCStrike15_v2_ClientRequestWatchInfoFriends2 = 9138
k_EMsgGCCStrike15_v2_MatchList = 9139
k_EMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames = 9140
k_EMsgGCCStrike15_v2_MatchListRequestRecentUserGames = 9141
k_EMsgGCCStrike15_v2_GC2ServerReservationUpdate = 9142
k_EMsgGCCStrike15_v2_ClientVarValueNotificationInfo = 9144
k_EMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification = 9145
k_EMsgGCCStrike15_v2_MatchListRequestTournamentGames = 9146
k_EMsgGCCStrike15_v2_MatchListRequestFullGameInfo = 9147
k_EMsgGCCStrike15_v2_GiftsLeaderboardRequest = 9148
k_EMsgGCCStrike15_v2_GiftsLeaderboardResponse = 9149
k_EMsgGCCStrike15_v2_ServerVarValueNotificationInfo = 9150
k_EMsgGCToGCReloadVersions = 9151
k_EMsgGCCStrike15_v2_ClientSubmitSurveyVote = 9152
k_EMsgGCCStrike15_v2_Server2GCClientValidate = 9153
k_EMsgGCCStrike15_v2_MatchListRequestLiveGameForUser = 9154
k_EMsgGCCStrike15_v2_Server2GCPureServerValidationFailure = 9155
k_EMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest = 9156
k_EMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse = 9157
k_EMsgGCCStrike15_v2_AccountPrivacySettings = 9158
k_EMsgGCCStrike15_v2_SetMyActivityInfo = 9159
k_EMsgGCCStrike15_v2_MatchListRequestTournamentPredictions = 9160
k_EMsgGCCStrike15_v2_MatchListUploadTournamentPredictions = 9161
k_EMsgGCCStrike15_v2_DraftSummary = 9162
k_EMsgGCCStrike15_v2_ClientRequestJoinFriendData = 9163
k_EMsgGCCStrike15_v2_ClientRequestJoinServerData = 9164
k_EMsgGCCStrike15_v2_ClientRequestNewMission = 9165
k_EMsgGCCStrike15_v2_GC2ServerNotifyXPRewarded = 9166
k_EMsgGCCStrike15_v2_GC2ClientTournamentInfo = 9167
k_EMsgGC_GlobalGame_Subscribe = 9168
k_EMsgGC_GlobalGame_Unsubscribe = 9169
k_EMsgGC_GlobalGame_Play = 9170
k_EMsgGCCStrike15_v2_AcknowledgePenalty = 9171
k_EMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin = 9172
k_EMsgGCCStrike15_v2_GC2ClientGlobalStats = 9173
k_EMsgGCCStrike15_v2_Client2GCStreamUnlock = 9174
k_EMsgGCCStrike15_v2_FantasyRequestClientData = 9175
k_EMsgGCCStrike15_v2_FantasyUpdateClientData = 9176
k_EMsgGCCStrike15_v2_GCToClientSteamdatagramTicket = 9177
k_EMsgGCCStrike15_v2_ClientToGCRequestTicket = 9178
k_EMsgGCCStrike15_v2_ClientToGCRequestElevate = 9179
k_EMsgGCCStrike15_v2_GlobalChat = 9180
k_EMsgGCCStrike15_v2_GlobalChat_Subscribe = 9181
k_EMsgGCCStrike15_v2_GlobalChat_Unsubscribe = 9182
k_EMsgGCCStrike15_v2_ClientAuthKeyCode = 9183
k_EMsgGCCStrike15_v2_GotvSyncPacket = 9184
k_EMsgGCCStrike15_v2_ClientPlayerDecalSign = 9185
k_EMsgGCCStrike15_v2_ClientLogonFatalError = 9187
k_EMsgGCCStrike15_v2_ClientPollState = 9188
k_EMsgGCCStrike15_v2_Party_Register = 9189
k_EMsgGCCStrike15_v2_Party_Unregister = 9190
k_EMsgGCCStrike15_v2_Party_Search = 9191
k_EMsgGCCStrike15_v2_Party_Invite = 9192
k_EMsgGCCStrike15_v2_Account_RequestCoPlays = 9193



_GAMESERVERPING = _descriptor.Descriptor(
  name='GameServerPing',
  full_name='GameServerPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ping', full_name='GameServerPing.ping', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='GameServerPing.ip', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instances', full_name='GameServerPing.instances', index=2,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=200,
)


_DATACENTERPING = _descriptor.Descriptor(
  name='DataCenterPing',
  full_name='DataCenterPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_center_id', full_name='DataCenterPing.data_center_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping', full_name='DataCenterPing.ping', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=256,
)


_DETAILEDSEARCHSTATISTIC = _descriptor.Descriptor(
  name='DetailedSearchStatistic',
  full_name='DetailedSearchStatistic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_type', full_name='DetailedSearchStatistic.game_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_time_avg', full_name='DetailedSearchStatistic.search_time_avg', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players_searching', full_name='DetailedSearchStatistic.players_searching', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=354,
)


_TOURNAMENTPLAYER = _descriptor.Descriptor(
  name='TournamentPlayer',
  full_name='TournamentPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='TournamentPlayer.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_nick', full_name='TournamentPlayer.player_nick', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='TournamentPlayer.player_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_dob', full_name='TournamentPlayer.player_dob', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_flag', full_name='TournamentPlayer.player_flag', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_location', full_name='TournamentPlayer.player_location', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_desc', full_name='TournamentPlayer.player_desc', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=524,
)


_TOURNAMENTTEAM = _descriptor.Descriptor(
  name='TournamentTeam',
  full_name='TournamentTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='TournamentTeam.team_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_tag', full_name='TournamentTeam.team_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_flag', full_name='TournamentTeam.team_flag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='TournamentTeam.team_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='TournamentTeam.players', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=651,
)


_TOURNAMENTEVENT = _descriptor.Descriptor(
  name='TournamentEvent',
  full_name='TournamentEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='TournamentEvent.event_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_tag', full_name='TournamentEvent.event_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_name', full_name='TournamentEvent.event_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_time_start', full_name='TournamentEvent.event_time_start', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_time_end', full_name='TournamentEvent.event_time_end', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_public', full_name='TournamentEvent.event_public', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_stage_id', full_name='TournamentEvent.event_stage_id', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_stage_name', full_name='TournamentEvent.event_stage_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_section_id', full_name='TournamentEvent.active_section_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=877,
)


_GLOBALSTATISTICS = _descriptor.Descriptor(
  name='GlobalStatistics',
  full_name='GlobalStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='players_online', full_name='GlobalStatistics.players_online', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='servers_online', full_name='GlobalStatistics.servers_online', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players_searching', full_name='GlobalStatistics.players_searching', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='servers_available', full_name='GlobalStatistics.servers_available', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ongoing_matches', full_name='GlobalStatistics.ongoing_matches', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_time_avg', full_name='GlobalStatistics.search_time_avg', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_statistics', full_name='GlobalStatistics.search_statistics', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='main_post_url', full_name='GlobalStatistics.main_post_url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='required_appid_version', full_name='GlobalStatistics.required_appid_version', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pricesheet_version', full_name='GlobalStatistics.pricesheet_version', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='twitch_streams_version', full_name='GlobalStatistics.twitch_streams_version', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_tournament_eventid', full_name='GlobalStatistics.active_tournament_eventid', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_survey_id', full_name='GlobalStatistics.active_survey_id', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=880,
  serialized_end=1279,
)


_OPERATIONALSTATISTICDESCRIPTION = _descriptor.Descriptor(
  name='OperationalStatisticDescription',
  full_name='OperationalStatisticDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='OperationalStatisticDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='idkey', full_name='OperationalStatisticDescription.idkey', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1343,
)


_OPERATIONALSTATISTICELEMENT = _descriptor.Descriptor(
  name='OperationalStatisticElement',
  full_name='OperationalStatisticElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='idkey', full_name='OperationalStatisticElement.idkey', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='OperationalStatisticElement.values', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1345,
  serialized_end=1405,
)


_OPERATIONALSTATISTICSPACKET = _descriptor.Descriptor(
  name='OperationalStatisticsPacket',
  full_name='OperationalStatisticsPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packetid', full_name='OperationalStatisticsPacket.packetid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mstimestamp', full_name='OperationalStatisticsPacket.mstimestamp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='OperationalStatisticsPacket.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1407,
  serialized_end=1521,
)


_PLAYERRANKINGINFO = _descriptor.Descriptor(
  name='PlayerRankingInfo',
  full_name='PlayerRankingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='PlayerRankingInfo.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_id', full_name='PlayerRankingInfo.rank_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wins', full_name='PlayerRankingInfo.wins', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_change', full_name='PlayerRankingInfo.rank_change', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1614,
)


_PLAYERCOMMENDATIONINFO = _descriptor.Descriptor(
  name='PlayerCommendationInfo',
  full_name='PlayerCommendationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd_friendly', full_name='PlayerCommendationInfo.cmd_friendly', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cmd_teaching', full_name='PlayerCommendationInfo.cmd_teaching', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cmd_leader', full_name='PlayerCommendationInfo.cmd_leader', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1616,
  serialized_end=1704,
)


_PLAYERMEDALSINFO = _descriptor.Descriptor(
  name='PlayerMedalsInfo',
  full_name='PlayerMedalsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='medal_team', full_name='PlayerMedalsInfo.medal_team', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='medal_combat', full_name='PlayerMedalsInfo.medal_combat', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='medal_weapon', full_name='PlayerMedalsInfo.medal_weapon', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='medal_global', full_name='PlayerMedalsInfo.medal_global', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='medal_arms', full_name='PlayerMedalsInfo.medal_arms', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='display_items_defidx', full_name='PlayerMedalsInfo.display_items_defidx', index=5,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='featured_display_item_defidx', full_name='PlayerMedalsInfo.featured_display_item_defidx', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1707,
  serialized_end=1899,
)


_ACCOUNTACTIVITY = _descriptor.Descriptor(
  name='AccountActivity',
  full_name='AccountActivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='activity', full_name='AccountActivity.activity', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mode', full_name='AccountActivity.mode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map', full_name='AccountActivity.map', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1901,
  serialized_end=1963,
)


_TOURNAMENTMATCHSETUP = _descriptor.Descriptor(
  name='TournamentMatchSetup',
  full_name='TournamentMatchSetup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='TournamentMatchSetup.event_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id_ct', full_name='TournamentMatchSetup.team_id_ct', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id_t', full_name='TournamentMatchSetup.team_id_t', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_stage_id', full_name='TournamentMatchSetup.event_stage_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1965,
  serialized_end=2068,
)


_SERVERHLTVINFO = _descriptor.Descriptor(
  name='ServerHltvInfo',
  full_name='ServerHltvInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tv_udp_port', full_name='ServerHltvInfo.tv_udp_port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_watch_key', full_name='ServerHltvInfo.tv_watch_key', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_slots', full_name='ServerHltvInfo.tv_slots', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_clients', full_name='ServerHltvInfo.tv_clients', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_proxies', full_name='ServerHltvInfo.tv_proxies', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_time', full_name='ServerHltvInfo.tv_time', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_type', full_name='ServerHltvInfo.game_type', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mapgroup', full_name='ServerHltvInfo.game_mapgroup', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_map', full_name='ServerHltvInfo.game_map', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_master_steamid', full_name='ServerHltvInfo.tv_master_steamid', index=9,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_local_slots', full_name='ServerHltvInfo.tv_local_slots', index=10,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_local_clients', full_name='ServerHltvInfo.tv_local_clients', index=11,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_local_proxies', full_name='ServerHltvInfo.tv_local_proxies', index=12,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_relay_slots', full_name='ServerHltvInfo.tv_relay_slots', index=13,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_relay_clients', full_name='ServerHltvInfo.tv_relay_clients', index=14,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_relay_proxies', full_name='ServerHltvInfo.tv_relay_proxies', index=15,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_relay_address', full_name='ServerHltvInfo.tv_relay_address', index=16,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_relay_port', full_name='ServerHltvInfo.tv_relay_port', index=17,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_relay_steamid', full_name='ServerHltvInfo.tv_relay_steamid', index=18,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2071,
  serialized_end=2519,
)


_IPADDRESSMASK = _descriptor.Descriptor(
  name='IpAddressMask',
  full_name='IpAddressMask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='IpAddressMask.a', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='IpAddressMask.b', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c', full_name='IpAddressMask.c', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='d', full_name='IpAddressMask.d', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bits', full_name='IpAddressMask.bits', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='IpAddressMask.token', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2521,
  serialized_end=2609,
)


_XPPROGRESSDATA = _descriptor.Descriptor(
  name='XpProgressData',
  full_name='XpProgressData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='xp_points', full_name='XpProgressData.xp_points', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xp_category', full_name='XpProgressData.xp_category', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2611,
  serialized_end=2667,
)


_MATCHENDITEMUPDATES = _descriptor.Descriptor(
  name='MatchEndItemUpdates',
  full_name='MatchEndItemUpdates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='MatchEndItemUpdates.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_attr_defidx', full_name='MatchEndItemUpdates.item_attr_defidx', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_attr_delta_value', full_name='MatchEndItemUpdates.item_attr_delta_value', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2669,
  serialized_end=2764,
)


_SCORELEADERBOARDDATA_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='ScoreLeaderboardData.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='ScoreLeaderboardData.Entry.tag', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='val', full_name='ScoreLeaderboardData.Entry.val', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2937,
  serialized_end=2970,
)

_SCORELEADERBOARDDATA_ACCOUNTENTRIES = _descriptor.Descriptor(
  name='AccountEntries',
  full_name='ScoreLeaderboardData.AccountEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='ScoreLeaderboardData.AccountEntries.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entries', full_name='ScoreLeaderboardData.AccountEntries.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2972,
  serialized_end=3053,
)

_SCORELEADERBOARDDATA = _descriptor.Descriptor(
  name='ScoreLeaderboardData',
  full_name='ScoreLeaderboardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_id', full_name='ScoreLeaderboardData.quest_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='ScoreLeaderboardData.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accountentries', full_name='ScoreLeaderboardData.accountentries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchentries', full_name='ScoreLeaderboardData.matchentries', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SCORELEADERBOARDDATA_ENTRY, _SCORELEADERBOARDDATA_ACCOUNTENTRIES, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2767,
  serialized_end=3053,
)


_PLAYERQUESTDATA_QUESTITEMDATA = _descriptor.Descriptor(
  name='QuestItemData',
  full_name='PlayerQuestData.QuestItemData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_id', full_name='PlayerQuestData.QuestItemData.quest_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quest_normal_points_earned', full_name='PlayerQuestData.QuestItemData.quest_normal_points_earned', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quest_bonus_points_earned', full_name='PlayerQuestData.QuestItemData.quest_bonus_points_earned', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3290,
  serialized_end=3394,
)

_PLAYERQUESTDATA = _descriptor.Descriptor(
  name='PlayerQuestData',
  full_name='PlayerQuestData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quester_account_id', full_name='PlayerQuestData.quester_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quest_item_data', full_name='PlayerQuestData.quest_item_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xp_progress_data', full_name='PlayerQuestData.xp_progress_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_played', full_name='PlayerQuestData.time_played', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mm_game_mode', full_name='PlayerQuestData.mm_game_mode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_updates', full_name='PlayerQuestData.item_updates', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PLAYERQUESTDATA_QUESTITEMDATA, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3056,
  serialized_end=3394,
)


_CMSGGC_SERVERQUESTUPDATEDATA = _descriptor.Descriptor(
  name='CMsgGC_ServerQuestUpdateData',
  full_name='CMsgGC_ServerQuestUpdateData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_quest_data', full_name='CMsgGC_ServerQuestUpdateData.player_quest_data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='binary_data', full_name='CMsgGC_ServerQuestUpdateData.binary_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mm_game_mode', full_name='CMsgGC_ServerQuestUpdateData.mm_game_mode', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='missionlbsdata', full_name='CMsgGC_ServerQuestUpdateData.missionlbsdata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3397,
  serialized_end=3562,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGGCOPERATIONALSTATS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingGCOperationalStats',
  full_name='CMsgGCCStrike15_v2_MatchmakingGCOperationalStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packetid', full_name='CMsgGCCStrike15_v2_MatchmakingGCOperationalStats.packetid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='namekeys', full_name='CMsgGCCStrike15_v2_MatchmakingGCOperationalStats.namekeys', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packets', full_name='CMsgGCCStrike15_v2_MatchmakingGCOperationalStats.packets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3565,
  serialized_end=3732,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERCONFIRM = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm',
  full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm.token', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm.stamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm.exchange', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3734,
  serialized_end=3830,
)


_CMSGGCCSTRIKE15_V2_GC2SERVERRESERVATIONUPDATE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_GC2ServerReservationUpdate',
  full_name='CMsgGCCStrike15_v2_GC2ServerReservationUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='viewers_external_total', full_name='CMsgGCCStrike15_v2_GC2ServerReservationUpdate.viewers_external_total', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='viewers_external_steam', full_name='CMsgGCCStrike15_v2_GC2ServerReservationUpdate.viewers_external_steam', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3832,
  serialized_end=3943,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGSTART = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingStart',
  full_name='CMsgGCCStrike15_v2_MatchmakingStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgGCCStrike15_v2_MatchmakingStart.account_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_type', full_name='CMsgGCCStrike15_v2_MatchmakingStart.game_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ticket_data', full_name='CMsgGCCStrike15_v2_MatchmakingStart.ticket_data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgGCCStrike15_v2_MatchmakingStart.client_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_match', full_name='CMsgGCCStrike15_v2_MatchmakingStart.tournament_match', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prime_only', full_name='CMsgGCCStrike15_v2_MatchmakingStart.prime_only', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3946,
  serialized_end=4137,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGSTOP = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingStop',
  full_name='CMsgGCCStrike15_v2_MatchmakingStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='abandon', full_name='CMsgGCCStrike15_v2_MatchmakingStop.abandon', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4139,
  serialized_end=4192,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGCLIENT2SERVERPING = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingClient2ServerPing',
  full_name='CMsgGCCStrike15_v2_MatchmakingClient2ServerPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gameserverpings', full_name='CMsgGCCStrike15_v2_MatchmakingClient2ServerPing.gameserverpings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset_index', full_name='CMsgGCCStrike15_v2_MatchmakingClient2ServerPing.offset_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='final_batch', full_name='CMsgGCCStrike15_v2_MatchmakingClient2ServerPing.final_batch', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_center_pings', full_name='CMsgGCCStrike15_v2_MatchmakingClient2ServerPing.data_center_pings', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_ping', full_name='CMsgGCCStrike15_v2_MatchmakingClient2ServerPing.max_ping', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4195,
  serialized_end=4391,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE_NOTE = _descriptor.Descriptor(
  name='Note',
  full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.Note',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.Note.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region_id', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.Note.region_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region_r', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.Note.region_r', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='distance', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.Note.distance', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4984,
  serialized_end=5059,
)

_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate',
  full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchmaking', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.matchmaking', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='waiting_account_id_sessions', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.waiting_account_id_sessions', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ongoingmatch_account_id_sessions', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.ongoingmatch_account_id_sessions', index=3,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='global_stats', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.global_stats', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='failping_account_id_sessions', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.failping_account_id_sessions', index=5,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_account_id_sessions', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.penalty_account_id_sessions', index=6,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='failready_account_id_sessions', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.failready_account_id_sessions', index=7,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vacbanned_account_id_sessions', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.vacbanned_account_id_sessions', index=8,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_ipaddress_mask', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.server_ipaddress_mask', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notes', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.notes', index=10,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_account_id_sessions_green', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.penalty_account_id_sessions_green', index=11,
      number=14, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='insufficientlevel_sessions', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.insufficientlevel_sessions', index=12,
      number=15, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vsncheck_account_id_sessions', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.vsncheck_account_id_sessions', index=13,
      number=16, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE_NOTE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4394,
  serialized_end=5059,
)


_CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='CDataGCCStrike15_v2_TournamentMatchDraft.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mapid', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.Entry.mapid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id_ct', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.Entry.team_id_ct', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5362,
  serialized_end=5404,
)

_CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT = _descriptor.Descriptor(
  name='CDataGCCStrike15_v2_TournamentMatchDraft',
  full_name='CDataGCCStrike15_v2_TournamentMatchDraft',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.event_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_stage_id', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.event_stage_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id_0', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.team_id_0', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id_1', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.team_id_1', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maps_count', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.maps_count', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maps_current', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.maps_current', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id_start', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.team_id_start', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id_veto1', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.team_id_veto1', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id_pickn', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.team_id_pickn', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='drafts', full_name='CDataGCCStrike15_v2_TournamentMatchDraft.drafts', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT_ENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5062,
  serialized_end=5404,
)


_CPREMATCHINFODATA_TEAMSTATS = _descriptor.Descriptor(
  name='TeamStats',
  full_name='CPreMatchInfoData.TeamStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_info_idxtxt', full_name='CPreMatchInfoData.TeamStats.match_info_idxtxt', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_info_txt', full_name='CPreMatchInfoData.TeamStats.match_info_txt', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_info_teams', full_name='CPreMatchInfoData.TeamStats.match_info_teams', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5556,
  serialized_end=5644,
)

_CPREMATCHINFODATA = _descriptor.Descriptor(
  name='CPreMatchInfoData',
  full_name='CPreMatchInfoData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predictions_pct', full_name='CPreMatchInfoData.predictions_pct', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='draft', full_name='CPreMatchInfoData.draft', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CPreMatchInfoData.stats', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CPREMATCHINFODATA_TEAMSTATS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5407,
  serialized_end=5644,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve',
  full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.account_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_type', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.game_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.match_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_version', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.server_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rankings', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.rankings', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encryption_key', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.encryption_key', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encryption_key_pub', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.encryption_key_pub', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_ids', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.party_ids', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whitelist', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.whitelist', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_master_steamid', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.tv_master_steamid', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_event', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.tournament_event', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_teams', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.tournament_teams', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_casters_account_ids', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.tournament_casters_account_ids', index=12,
      number=13, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_relay_steamid', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.tv_relay_steamid', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pre_match_data', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve.pre_match_data', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5647,
  serialized_end=6145,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERRESERVATIONRESPONSE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse',
  full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservationid', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.reservationid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservation', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.reservation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.map', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gc_reservation_sent', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.gc_reservation_sent', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_version', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.server_version', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_info', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.tv_info', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_player_accounts', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.reward_player_accounts', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='idle_player_accounts', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.idle_player_accounts', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_item_attr_def_idx', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.reward_item_attr_def_idx', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_item_attr_value', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.reward_item_attr_value', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_item_attr_reward_idx', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.reward_item_attr_reward_idx', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_drop_list', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.reward_drop_list', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_tag', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.tournament_tag', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamdatagram_port', full_name='CMsgGCCStrike15_v2_MatchmakingServerReservationResponse.steamdatagram_port', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6148,
  serialized_end=6641,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTRESERVE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve',
  full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverid', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve.serverid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='direct_udp_ip', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve.direct_udp_ip', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='direct_udp_port', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve.direct_udp_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservationid', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve.reservationid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservation', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve.reservation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve.map', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_address', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve.server_address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6644,
  serialized_end=6888,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS_DROPINFO = _descriptor.Descriptor(
  name='DropInfo',
  full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.DropInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_mvp', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.DropInfo.account_mvp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7627,
  serialized_end=7658,
)

_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats',
  full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservationid', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.reservationid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservation', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.reservation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.map', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.round', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.kills', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.assists', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.deaths', index=6,
      number=7, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scores', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.scores', index=7,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pings', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.pings', index=8,
      number=9, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round_result', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.round_result', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_result', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.match_result', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_scores', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.team_scores', index=11,
      number=12, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confirm', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.confirm', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservation_stage', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.reservation_stage', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_duration', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.match_duration', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enemy_kills', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.enemy_kills', index=15,
      number=16, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enemy_headshots', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.enemy_headshots', index=16,
      number=17, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enemy_3ks', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.enemy_3ks', index=17,
      number=18, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enemy_4ks', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.enemy_4ks', index=18,
      number=19, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enemy_5ks', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.enemy_5ks', index=19,
      number=20, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mvps', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.mvps', index=20,
      number=21, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectators_count', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.spectators_count', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectators_count_tv', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.spectators_count_tv', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectators_count_lnk', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.spectators_count_lnk', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enemy_kills_agg', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.enemy_kills_agg', index=24,
      number=25, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='drop_info', full_name='CMsgGCCStrike15_v2_MatchmakingServerRoundStats.drop_info', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS_DROPINFO, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6891,
  serialized_end=7658,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERMATCHEND = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd',
  full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd.stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confirm', full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd.confirm', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rematch', full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd.rematch', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_token', full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd.replay_token', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_cluster_id', full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd.replay_cluster_id', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aborted_match', full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd.aborted_match', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_end_quest_data', full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd.match_end_quest_data', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_version', full_name='CMsgGCCStrike15_v2_MatchmakingServerMatchEnd.server_version', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7661,
  serialized_end=8011,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGCLIENT2GCHELLO = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingClient2GCHello',
  full_name='CMsgGCCStrike15_v2_MatchmakingClient2GCHello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8013,
  serialized_end=8059,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello',
  full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ongoingmatch', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.ongoingmatch', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='global_stats', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.global_stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_seconds', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.penalty_seconds', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_reason', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.penalty_reason', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vac_banned', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.vac_banned', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ranking', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.ranking', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commendation', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.commendation', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='medals', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.medals', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='my_current_event', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.my_current_event', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='my_current_event_teams', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.my_current_event_teams', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='my_current_team', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.my_current_team', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='my_current_event_stages', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.my_current_event_stages', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='survey_vote', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.survey_vote', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='activity', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.activity', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_level', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.player_level', index=15,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_cur_xp', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.player_cur_xp', index=16,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_xp_bonus_flags', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientHello.player_xp_bonus_flags', index=17,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8062,
  serialized_end=8747,
)


_CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS_SETTING = _descriptor.Descriptor(
  name='Setting',
  full_name='CMsgGCCStrike15_v2_AccountPrivacySettings.Setting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='setting_type', full_name='CMsgGCCStrike15_v2_AccountPrivacySettings.Setting.setting_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='setting_value', full_name='CMsgGCCStrike15_v2_AccountPrivacySettings.Setting.setting_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8865,
  serialized_end=8919,
)

_CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_AccountPrivacySettings',
  full_name='CMsgGCCStrike15_v2_AccountPrivacySettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='settings', full_name='CMsgGCCStrike15_v2_AccountPrivacySettings.settings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS_SETTING, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8750,
  serialized_end=8919,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTABANDON = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon',
  full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='abandoned_match', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon.abandoned_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_seconds', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon.penalty_seconds', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='penalty_reason', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon.penalty_reason', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8922,
  serialized_end=9113,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVER2GCKICK = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingServer2GCKick',
  full_name='CMsgGCCStrike15_v2_MatchmakingServer2GCKick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_MatchmakingServer2GCKick.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservation', full_name='CMsgGCCStrike15_v2_MatchmakingServer2GCKick.reservation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='CMsgGCCStrike15_v2_MatchmakingServer2GCKick.reason', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9116,
  serialized_end=9267,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRANKUPDATE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate',
  full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rankings', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate.rankings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate.match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9269,
  serialized_end=9376,
)


_CMSGGCCSTRIKE15_V2_MATCHMAKINGOPERATOR2GCBLOGUPDATE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate',
  full_name='CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='main_post_url', full_name='CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate.main_post_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9378,
  serialized_end=9454,
)


_CMSGGCCSTRIKE15_V2_SERVERNOTIFICATIONFORUSERPENALTY = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ServerNotificationForUserPenalty',
  full_name='CMsgGCCStrike15_v2_ServerNotificationForUserPenalty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_ServerNotificationForUserPenalty.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='CMsgGCCStrike15_v2_ServerNotificationForUserPenalty.reason', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds', full_name='CMsgGCCStrike15_v2_ServerNotificationForUserPenalty.seconds', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9456,
  serialized_end=9562,
)


_CMSGGCCSTRIKE15_V2_CLIENTREPORTPLAYER = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientReportPlayer',
  full_name='CMsgGCCStrike15_v2_ClientReportPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_ClientReportPlayer.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_aimbot', full_name='CMsgGCCStrike15_v2_ClientReportPlayer.rpt_aimbot', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_wallhack', full_name='CMsgGCCStrike15_v2_ClientReportPlayer.rpt_wallhack', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_speedhack', full_name='CMsgGCCStrike15_v2_ClientReportPlayer.rpt_speedhack', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_teamharm', full_name='CMsgGCCStrike15_v2_ClientReportPlayer.rpt_teamharm', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_textabuse', full_name='CMsgGCCStrike15_v2_ClientReportPlayer.rpt_textabuse', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_voiceabuse', full_name='CMsgGCCStrike15_v2_ClientReportPlayer.rpt_voiceabuse', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCCStrike15_v2_ClientReportPlayer.match_id', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9565,
  serialized_end=9776,
)


_CMSGGCCSTRIKE15_V2_CLIENTCOMMENDPLAYER = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientCommendPlayer',
  full_name='CMsgGCCStrike15_v2_ClientCommendPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_ClientCommendPlayer.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCCStrike15_v2_ClientCommendPlayer.match_id', index=1,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commendation', full_name='CMsgGCCStrike15_v2_ClientCommendPlayer.commendation', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='CMsgGCCStrike15_v2_ClientCommendPlayer.tokens', index=3,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9779,
  serialized_end=9920,
)


_CMSGGCCSTRIKE15_V2_CLIENTREPORTSERVER = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientReportServer',
  full_name='CMsgGCCStrike15_v2_ClientReportServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rpt_poorperf', full_name='CMsgGCCStrike15_v2_ClientReportServer.rpt_poorperf', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_abusivemodels', full_name='CMsgGCCStrike15_v2_ClientReportServer.rpt_abusivemodels', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_badmotd', full_name='CMsgGCCStrike15_v2_ClientReportServer.rpt_badmotd', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_listingabuse', full_name='CMsgGCCStrike15_v2_ClientReportServer.rpt_listingabuse', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_inventoryabuse', full_name='CMsgGCCStrike15_v2_ClientReportServer.rpt_inventoryabuse', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCCStrike15_v2_ClientReportServer.match_id', index=5,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9923,
  serialized_end=10104,
)


_CMSGGCCSTRIKE15_V2_CLIENTREPORTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientReportResponse',
  full_name='CMsgGCCStrike15_v2_ClientReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='confirmation_id', full_name='CMsgGCCStrike15_v2_ClientReportResponse.confirmation_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_ClientReportResponse.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_ip', full_name='CMsgGCCStrike15_v2_ClientReportResponse.server_ip', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response_type', full_name='CMsgGCCStrike15_v2_ClientReportResponse.response_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response_result', full_name='CMsgGCCStrike15_v2_ClientReportResponse.response_result', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='CMsgGCCStrike15_v2_ClientReportResponse.tokens', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10107,
  serialized_end=10276,
)


_CMSGGCCSTRIKE15_V2_CLIENTREQUESTWATCHINFOFRIENDS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends',
  full_name='CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends.request_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends.account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serverid', full_name='CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends.serverid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends.matchid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10278,
  serialized_end=10404,
)


_WATCHABLEMATCHINFO = _descriptor.Descriptor(
  name='WatchableMatchInfo',
  full_name='WatchableMatchInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_ip', full_name='WatchableMatchInfo.server_ip', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_port', full_name='WatchableMatchInfo.tv_port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_spectators', full_name='WatchableMatchInfo.tv_spectators', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_time', full_name='WatchableMatchInfo.tv_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tv_watch_password', full_name='WatchableMatchInfo.tv_watch_password', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_decryptdata_key', full_name='WatchableMatchInfo.cl_decryptdata_key', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_decryptdata_key_pub', full_name='WatchableMatchInfo.cl_decryptdata_key_pub', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_type', full_name='WatchableMatchInfo.game_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mapgroup', full_name='WatchableMatchInfo.game_mapgroup', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_map', full_name='WatchableMatchInfo.game_map', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_id', full_name='WatchableMatchInfo.server_id', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='WatchableMatchInfo.match_id', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reservation_id', full_name='WatchableMatchInfo.reservation_id', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10407,
  serialized_end=10711,
)


_CMSGGCCSTRIKE15_V2_CLIENTREQUESTJOINFRIENDDATA = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientRequestJoinFriendData',
  full_name='CMsgGCCStrike15_v2_ClientRequestJoinFriendData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgGCCStrike15_v2_ClientRequestJoinFriendData.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_ClientRequestJoinFriendData.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='join_token', full_name='CMsgGCCStrike15_v2_ClientRequestJoinFriendData.join_token', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='join_ipp', full_name='CMsgGCCStrike15_v2_ClientRequestJoinFriendData.join_ipp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='res', full_name='CMsgGCCStrike15_v2_ClientRequestJoinFriendData.res', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errormsg', full_name='CMsgGCCStrike15_v2_ClientRequestJoinFriendData.errormsg', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10714,
  serialized_end=10917,
)


_CMSGGCCSTRIKE15_V2_CLIENTREQUESTJOINSERVERDATA = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientRequestJoinServerData',
  full_name='CMsgGCCStrike15_v2_ClientRequestJoinServerData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgGCCStrike15_v2_ClientRequestJoinServerData.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_ClientRequestJoinServerData.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serverid', full_name='CMsgGCCStrike15_v2_ClientRequestJoinServerData.serverid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_ip', full_name='CMsgGCCStrike15_v2_ClientRequestJoinServerData.server_ip', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_port', full_name='CMsgGCCStrike15_v2_ClientRequestJoinServerData.server_port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='res', full_name='CMsgGCCStrike15_v2_ClientRequestJoinServerData.res', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10920,
  serialized_end=11125,
)


_CMSGGCCSTRIKE15_V2_CLIENTREQUESTNEWMISSION = _descriptor.Descriptor(
  name='CMsgGCCstrike15_v2_ClientRequestNewMission',
  full_name='CMsgGCCstrike15_v2_ClientRequestNewMission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='CMsgGCCstrike15_v2_ClientRequestNewMission.mission_id', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='campaign_id', full_name='CMsgGCCstrike15_v2_ClientRequestNewMission.campaign_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11127,
  serialized_end=11212,
)


_CMSGGCCSTRIKE15_V2_GC2SERVERNOTIFYXPREWARDED = _descriptor.Descriptor(
  name='CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded',
  full_name='CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='xp_progress_data', full_name='CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded.xp_progress_data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_xp', full_name='CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded.current_xp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_level', full_name='CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded.current_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upgraded_defidx', full_name='CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded.upgraded_defidx', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11215,
  serialized_end=11392,
)


_CMSGGCCSTRIKE15_V2_WATCHINFOUSERS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_WatchInfoUsers',
  full_name='CMsgGCCStrike15_v2_WatchInfoUsers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='CMsgGCCStrike15_v2_WatchInfoUsers.request_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgGCCStrike15_v2_WatchInfoUsers.account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='watchable_match_infos', full_name='CMsgGCCStrike15_v2_WatchInfoUsers.watchable_match_infos', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extended_timeout', full_name='CMsgGCCStrike15_v2_WatchInfoUsers.extended_timeout', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11395,
  serialized_end=11549,
)


_CMSGGCCSTRIKE15_V2_CLIENTREQUESTPLAYERSPROFILE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientRequestPlayersProfile',
  full_name='CMsgGCCStrike15_v2_ClientRequestPlayersProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id__deprecated', full_name='CMsgGCCStrike15_v2_ClientRequestPlayersProfile.request_id__deprecated', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids__deprecated', full_name='CMsgGCCStrike15_v2_ClientRequestPlayersProfile.account_ids__deprecated', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_ClientRequestPlayersProfile.account_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_level', full_name='CMsgGCCStrike15_v2_ClientRequestPlayersProfile.request_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11552,
  serialized_end=11708,
)


_CMSGGCCSTRIKE15_V2_PLAYERSPROFILE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_PlayersProfile',
  full_name='CMsgGCCStrike15_v2_PlayersProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='CMsgGCCStrike15_v2_PlayersProfile.request_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_profiles', full_name='CMsgGCCStrike15_v2_PlayersProfile.account_profiles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11711,
  serialized_end=11839,
)


_CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASEUPDATE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate',
  full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseid', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate.caseid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='suspectid', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate.suspectid', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fractionid', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate.fractionid', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_aimbot', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate.rpt_aimbot', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_wallhack', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate.rpt_wallhack', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_speedhack', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate.rpt_speedhack', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpt_teamharm', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate.rpt_teamharm', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate.reason', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11842,
  serialized_end=12046,
)


_CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASEASSIGNMENT = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment',
  full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseid', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.caseid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caseurl', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.caseurl', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='verdict', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.verdict', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='throttleseconds', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.throttleseconds', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='suspectid', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.suspectid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fractionid', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.fractionid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numrounds', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.numrounds', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fractionrounds', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.fractionrounds', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='streakconvictions', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.streakconvictions', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment.reason', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12049,
  serialized_end=12318,
)


_CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASESTATUS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus',
  full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='caseid', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus.caseid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='statusid', full_name='CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus.statusid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12320,
  serialized_end=12400,
)


_CCLIENTHEADEROVERWATCHEVIDENCE = _descriptor.Descriptor(
  name='CClientHeaderOverwatchEvidence',
  full_name='CClientHeaderOverwatchEvidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CClientHeaderOverwatchEvidence.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caseid', full_name='CClientHeaderOverwatchEvidence.caseid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12402,
  serialized_end=12469,
)


_CMSGGCCSTRIKE15_V2_GC2CLIENTTEXTMSG = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_GC2ClientTextMsg',
  full_name='CMsgGCCStrike15_v2_GC2ClientTextMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgGCCStrike15_v2_GC2ClientTextMsg.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgGCCStrike15_v2_GC2ClientTextMsg.type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payload', full_name='CMsgGCCStrike15_v2_GC2ClientTextMsg.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12471,
  serialized_end=12551,
)


_CMSGGCCSTRIKE15_V2_CLIENT2GCTEXTMSG = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Client2GCTextMsg',
  full_name='CMsgGCCStrike15_v2_Client2GCTextMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgGCCStrike15_v2_Client2GCTextMsg.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='args', full_name='CMsgGCCStrike15_v2_Client2GCTextMsg.args', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12553,
  serialized_end=12616,
)


_CMSGGCCSTRIKE15_V2_MATCHENDRUNREWARDDROPS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchEndRunRewardDrops',
  full_name='CMsgGCCStrike15_v2_MatchEndRunRewardDrops',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverinfo', full_name='CMsgGCCStrike15_v2_MatchEndRunRewardDrops.serverinfo', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_end_quest_data', full_name='CMsgGCCStrike15_v2_MatchEndRunRewardDrops.match_end_quest_data', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12619,
  serialized_end=12801,
)


_CECONITEMPREVIEWDATABLOCK_STICKER = _descriptor.Descriptor(
  name='Sticker',
  full_name='CEconItemPreviewDataBlock.Sticker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot', full_name='CEconItemPreviewDataBlock.Sticker.slot', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sticker_id', full_name='CEconItemPreviewDataBlock.Sticker.sticker_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wear', full_name='CEconItemPreviewDataBlock.Sticker.wear', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scale', full_name='CEconItemPreviewDataBlock.Sticker.scale', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='CEconItemPreviewDataBlock.Sticker.rotation', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tint_id', full_name='CEconItemPreviewDataBlock.Sticker.tint_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13195,
  serialized_end=13302,
)

_CECONITEMPREVIEWDATABLOCK = _descriptor.Descriptor(
  name='CEconItemPreviewDataBlock',
  full_name='CEconItemPreviewDataBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CEconItemPreviewDataBlock.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CEconItemPreviewDataBlock.itemid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='defindex', full_name='CEconItemPreviewDataBlock.defindex', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='paintindex', full_name='CEconItemPreviewDataBlock.paintindex', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rarity', full_name='CEconItemPreviewDataBlock.rarity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality', full_name='CEconItemPreviewDataBlock.quality', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='paintwear', full_name='CEconItemPreviewDataBlock.paintwear', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='paintseed', full_name='CEconItemPreviewDataBlock.paintseed', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='killeaterscoretype', full_name='CEconItemPreviewDataBlock.killeaterscoretype', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='killeatervalue', full_name='CEconItemPreviewDataBlock.killeatervalue', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='customname', full_name='CEconItemPreviewDataBlock.customname', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stickers', full_name='CEconItemPreviewDataBlock.stickers', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inventory', full_name='CEconItemPreviewDataBlock.inventory', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='CEconItemPreviewDataBlock.origin', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='questid', full_name='CEconItemPreviewDataBlock.questid', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dropreason', full_name='CEconItemPreviewDataBlock.dropreason', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='musicindex', full_name='CEconItemPreviewDataBlock.musicindex', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CECONITEMPREVIEWDATABLOCK_STICKER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12804,
  serialized_end=13302,
)


_CMSGGCCSTRIKE15_V2_MATCHENDREWARDDROPSNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchEndRewardDropsNotification',
  full_name='CMsgGCCStrike15_v2_MatchEndRewardDropsNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iteminfo', full_name='CMsgGCCStrike15_v2_MatchEndRewardDropsNotification.iteminfo', index=0,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13304,
  serialized_end=13402,
)


_CMSGITEMACKNOWLEDGED = _descriptor.Descriptor(
  name='CMsgItemAcknowledged',
  full_name='CMsgItemAcknowledged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iteminfo', full_name='CMsgItemAcknowledged.iteminfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13404,
  serialized_end=13472,
)


_CMSGGCCSTRIKE15_V2_CLIENT2GCECONPREVIEWDATABLOCKREQUEST = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest',
  full_name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='param_s', full_name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest.param_s', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_a', full_name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest.param_a', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_d', full_name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest.param_d', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param_m', full_name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest.param_m', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13474,
  serialized_end=13599,
)


_CMSGGCCSTRIKE15_V2_CLIENT2GCECONPREVIEWDATABLOCKRESPONSE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse',
  full_name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iteminfo', full_name='CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse.iteminfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13601,
  serialized_end=13705,
)


_CMSGGCCSTRIKE15_V2_TOURNAMENTMATCHREWARDDROPSNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification',
  full_name='CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='defindex', full_name='CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification.defindex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accountids', full_name='CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification.accountids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13707,
  serialized_end=13822,
)


_CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTCURRENTLIVEGAMES = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames',
  full_name='CMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13824,
  serialized_end=13877,
)


_CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTLIVEGAMEFORUSER = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser',
  full_name='CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13879,
  serialized_end=13950,
)


_CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTRECENTUSERGAMES = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchListRequestRecentUserGames',
  full_name='CMsgGCCStrike15_v2_MatchListRequestRecentUserGames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_MatchListRequestRecentUserGames.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13952,
  serialized_end=14023,
)


_CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTTOURNAMENTGAMES = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchListRequestTournamentGames',
  full_name='CMsgGCCStrike15_v2_MatchListRequestTournamentGames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventid', full_name='CMsgGCCStrike15_v2_MatchListRequestTournamentGames.eventid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14025,
  serialized_end=14094,
)


_CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTFULLGAMEINFO = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchListRequestFullGameInfo',
  full_name='CMsgGCCStrike15_v2_MatchListRequestFullGameInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CMsgGCCStrike15_v2_MatchListRequestFullGameInfo.matchid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outcomeid', full_name='CMsgGCCStrike15_v2_MatchListRequestFullGameInfo.outcomeid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgGCCStrike15_v2_MatchListRequestFullGameInfo.token', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14096,
  serialized_end=14196,
)


_CDATAGCCSTRIKE15_V2_MATCHINFO = _descriptor.Descriptor(
  name='CDataGCCStrike15_v2_MatchInfo',
  full_name='CDataGCCStrike15_v2_MatchInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CDataGCCStrike15_v2_MatchInfo.matchid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchtime', full_name='CDataGCCStrike15_v2_MatchInfo.matchtime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='watchablematchinfo', full_name='CDataGCCStrike15_v2_MatchInfo.watchablematchinfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='roundstats_legacy', full_name='CDataGCCStrike15_v2_MatchInfo.roundstats_legacy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='roundstatsall', full_name='CDataGCCStrike15_v2_MatchInfo.roundstatsall', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14199,
  serialized_end=14463,
)


_CDATAGCCSTRIKE15_V2_TOURNAMENTGROUPTEAM = _descriptor.Descriptor(
  name='CDataGCCStrike15_v2_TournamentGroupTeam',
  full_name='CDataGCCStrike15_v2_TournamentGroupTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CDataGCCStrike15_v2_TournamentGroupTeam.team_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CDataGCCStrike15_v2_TournamentGroupTeam.score', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='correctpick', full_name='CDataGCCStrike15_v2_TournamentGroupTeam.correctpick', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14465,
  serialized_end=14559,
)


_CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP_PICKS = _descriptor.Descriptor(
  name='Picks',
  full_name='CDataGCCStrike15_v2_TournamentGroup.Picks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pickids', full_name='CDataGCCStrike15_v2_TournamentGroup.Picks.pickids', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14883,
  serialized_end=14907,
)

_CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP = _descriptor.Descriptor(
  name='CDataGCCStrike15_v2_TournamentGroup',
  full_name='CDataGCCStrike15_v2_TournamentGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CDataGCCStrike15_v2_TournamentGroup.groupid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CDataGCCStrike15_v2_TournamentGroup.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc', full_name='CDataGCCStrike15_v2_TournamentGroup.desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='picks__deprecated', full_name='CDataGCCStrike15_v2_TournamentGroup.picks__deprecated', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CDataGCCStrike15_v2_TournamentGroup.teams', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stage_ids', full_name='CDataGCCStrike15_v2_TournamentGroup.stage_ids', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='picklockuntiltime', full_name='CDataGCCStrike15_v2_TournamentGroup.picklockuntiltime', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pickableteams', full_name='CDataGCCStrike15_v2_TournamentGroup.pickableteams', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='points_per_pick', full_name='CDataGCCStrike15_v2_TournamentGroup.points_per_pick', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='picks', full_name='CDataGCCStrike15_v2_TournamentGroup.picks', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP_PICKS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14562,
  serialized_end=14907,
)


_CDATAGCCSTRIKE15_V2_TOURNAMENTSECTION = _descriptor.Descriptor(
  name='CDataGCCStrike15_v2_TournamentSection',
  full_name='CDataGCCStrike15_v2_TournamentSection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sectionid', full_name='CDataGCCStrike15_v2_TournamentSection.sectionid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CDataGCCStrike15_v2_TournamentSection.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc', full_name='CDataGCCStrike15_v2_TournamentSection.desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='groups', full_name='CDataGCCStrike15_v2_TournamentSection.groups', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14910,
  serialized_end=15050,
)


_CDATAGCCSTRIKE15_V2_TOURNAMENTINFO = _descriptor.Descriptor(
  name='CDataGCCStrike15_v2_TournamentInfo',
  full_name='CDataGCCStrike15_v2_TournamentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sections', full_name='CDataGCCStrike15_v2_TournamentInfo.sections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_event', full_name='CDataGCCStrike15_v2_TournamentInfo.tournament_event', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_teams', full_name='CDataGCCStrike15_v2_TournamentInfo.tournament_teams', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15053,
  serialized_end=15234,
)


_CMSGGCCSTRIKE15_V2_MATCHLIST = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_MatchList',
  full_name='CMsgGCCStrike15_v2_MatchList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msgrequestid', full_name='CMsgGCCStrike15_v2_MatchList.msgrequestid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_MatchList.accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='servertime', full_name='CMsgGCCStrike15_v2_MatchList.servertime', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgGCCStrike15_v2_MatchList.matches', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='streams', full_name='CMsgGCCStrike15_v2_MatchList.streams', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournamentinfo', full_name='CMsgGCCStrike15_v2_MatchList.tournamentinfo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15237,
  serialized_end=15472,
)


_CMSGGCCSTRIKE15_V2_PREDICTIONS_GROUPMATCHTEAMPICK = _descriptor.Descriptor(
  name='GroupMatchTeamPick',
  full_name='CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sectionid', full_name='CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick.sectionid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick.groupid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='index', full_name='CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick.index', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teamid', full_name='CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick.teamid', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick.itemid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15611,
  serialized_end=15714,
)

_CMSGGCCSTRIKE15_V2_PREDICTIONS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Predictions',
  full_name='CMsgGCCStrike15_v2_Predictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgGCCStrike15_v2_Predictions.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_match_team_picks', full_name='CMsgGCCStrike15_v2_Predictions.group_match_team_picks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCCSTRIKE15_V2_PREDICTIONS_GROUPMATCHTEAMPICK, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15475,
  serialized_end=15714,
)


_CMSGGCCSTRIKE15_V2_FANTASY_FANTASYSLOT = _descriptor.Descriptor(
  name='FantasySlot',
  full_name='CMsgGCCStrike15_v2_Fantasy.FantasySlot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgGCCStrike15_v2_Fantasy.FantasySlot.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pick', full_name='CMsgGCCStrike15_v2_Fantasy.FantasySlot.pick', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CMsgGCCStrike15_v2_Fantasy.FantasySlot.itemid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15821,
  serialized_end=15878,
)

_CMSGGCCSTRIKE15_V2_FANTASY_FANTASYTEAM = _descriptor.Descriptor(
  name='FantasyTeam',
  full_name='CMsgGCCStrike15_v2_Fantasy.FantasyTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sectionid', full_name='CMsgGCCStrike15_v2_Fantasy.FantasyTeam.sectionid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slots', full_name='CMsgGCCStrike15_v2_Fantasy.FantasyTeam.slots', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15880,
  serialized_end=15968,
)

_CMSGGCCSTRIKE15_V2_FANTASY = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Fantasy',
  full_name='CMsgGCCStrike15_v2_Fantasy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgGCCStrike15_v2_Fantasy.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgGCCStrike15_v2_Fantasy.teams', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCCSTRIKE15_V2_FANTASY_FANTASYSLOT, _CMSGGCCSTRIKE15_V2_FANTASY_FANTASYTEAM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15717,
  serialized_end=15968,
)


_CATTRIBUTE_STRING = _descriptor.Descriptor(
  name='CAttribute_String',
  full_name='CAttribute_String',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='CAttribute_String.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15970,
  serialized_end=16004,
)


_CMSGGCTOGCRELOADVERSIONS = _descriptor.Descriptor(
  name='CMsgGCToGCReloadVersions',
  full_name='CMsgGCToGCReloadVersions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16006,
  serialized_end=16032,
)


_CMSGCSTRIKE15WELCOME = _descriptor.Descriptor(
  name='CMsgCStrike15Welcome',
  full_name='CMsgCStrike15Welcome',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='store_item_hash', full_name='CMsgCStrike15Welcome.store_item_hash', index=0,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeplayedconsecutively', full_name='CMsgCStrike15Welcome.timeplayedconsecutively', index=1,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_first_played', full_name='CMsgCStrike15Welcome.time_first_played', index=2,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_time_played', full_name='CMsgCStrike15Welcome.last_time_played', index=3,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_ip_address', full_name='CMsgCStrike15Welcome.last_ip_address', index=4,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gscookieid', full_name='CMsgCStrike15Welcome.gscookieid', index=5,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uniqueid', full_name='CMsgCStrike15Welcome.uniqueid', index=6,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16035,
  serialized_end=16231,
)


_CMSGGCCSTRIKE15_V2_CLIENTVARVALUENOTIFICATIONINFO = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientVarValueNotificationInfo',
  full_name='CMsgGCCStrike15_v2_ClientVarValueNotificationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_name', full_name='CMsgGCCStrike15_v2_ClientVarValueNotificationInfo.value_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value_int', full_name='CMsgGCCStrike15_v2_ClientVarValueNotificationInfo.value_int', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_addr', full_name='CMsgGCCStrike15_v2_ClientVarValueNotificationInfo.server_addr', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_port', full_name='CMsgGCCStrike15_v2_ClientVarValueNotificationInfo.server_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='choked_blocks', full_name='CMsgGCCStrike15_v2_ClientVarValueNotificationInfo.choked_blocks', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16234,
  serialized_end=16389,
)


_CMSGGCCSTRIKE15_V2_SERVERVARVALUENOTIFICATIONINFO = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ServerVarValueNotificationInfo',
  full_name='CMsgGCCStrike15_v2_ServerVarValueNotificationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_ServerVarValueNotificationInfo.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='viewangles', full_name='CMsgGCCStrike15_v2_ServerVarValueNotificationInfo.viewangles', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgGCCStrike15_v2_ServerVarValueNotificationInfo.type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16391,
  serialized_end=16495,
)


_CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDREQUEST = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_GiftsLeaderboardRequest',
  full_name='CMsgGCCStrike15_v2_GiftsLeaderboardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16497,
  serialized_end=16541,
)


_CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE_GIFTLEADERBOARDENTRY = _descriptor.Descriptor(
  name='GiftLeaderboardEntry',
  full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse.GiftLeaderboardEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse.GiftLeaderboardEntry.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gifts', full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse.GiftLeaderboardEntry.gifts', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16773,
  serialized_end=16829,
)

_CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse',
  full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='servertime', full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse.servertime', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_period_seconds', full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse.time_period_seconds', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_gifts_given', full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse.total_gifts_given', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_givers', full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse.total_givers', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entries', full_name='CMsgGCCStrike15_v2_GiftsLeaderboardResponse.entries', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE_GIFTLEADERBOARDENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16544,
  serialized_end=16829,
)


_CMSGGCCSTRIKE15_V2_CLIENTSUBMITSURVEYVOTE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientSubmitSurveyVote',
  full_name='CMsgGCCStrike15_v2_ClientSubmitSurveyVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='survey_id', full_name='CMsgGCCStrike15_v2_ClientSubmitSurveyVote.survey_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote', full_name='CMsgGCCStrike15_v2_ClientSubmitSurveyVote.vote', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16831,
  serialized_end=16907,
)


_CMSGGCCSTRIKE15_V2_SERVER2GCCLIENTVALIDATE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Server2GCClientValidate',
  full_name='CMsgGCCStrike15_v2_Server2GCClientValidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_Server2GCClientValidate.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16909,
  serialized_end=16972,
)


_CMSGGCCSTRIKE15_V2_SERVER2GCPURESERVERVALIDATIONFAILURE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure',
  full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file', full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure.file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='crc', full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure.crc', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hash', full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure.hash', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='len', full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure.len', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pack_number', full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure.pack_number', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pack_file_id', full_name='CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure.pack_file_id', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16975,
  serialized_end=17162,
)


_CMSGGCCSTRIKE15_V2_GC2CLIENTTOURNAMENTINFO = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_GC2ClientTournamentInfo',
  full_name='CMsgGCCStrike15_v2_GC2ClientTournamentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventid', full_name='CMsgGCCStrike15_v2_GC2ClientTournamentInfo.eventid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stageid', full_name='CMsgGCCStrike15_v2_GC2ClientTournamentInfo.stageid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_type', full_name='CMsgGCCStrike15_v2_GC2ClientTournamentInfo.game_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teamids', full_name='CMsgGCCStrike15_v2_GC2ClientTournamentInfo.teamids', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17164,
  serialized_end=17278,
)


_CSOECONCOUPON = _descriptor.Descriptor(
  name='CSOEconCoupon',
  full_name='CSOEconCoupon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entryid', full_name='CSOEconCoupon.entryid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='defidx', full_name='CSOEconCoupon.defidx', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expiration_date', full_name='CSOEconCoupon.expiration_date', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17280,
  serialized_end=17359,
)


_CSOQUESTPROGRESS = _descriptor.Descriptor(
  name='CSOQuestProgress',
  full_name='CSOQuestProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='questid', full_name='CSOQuestProgress.questid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))),
    _descriptor.FieldDescriptor(
      name='points_remaining', full_name='CSOQuestProgress.points_remaining', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus_points', full_name='CSOQuestProgress.bonus_points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17361,
  serialized_end=17450,
)


_CSOPERSONADATAPUBLIC = _descriptor.Descriptor(
  name='CSOPersonaDataPublic',
  full_name='CSOPersonaDataPublic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_level', full_name='CSOPersonaDataPublic.player_level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commendation', full_name='CSOPersonaDataPublic.commendation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='elevated_state', full_name='CSOPersonaDataPublic.elevated_state', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17452,
  serialized_end=17567,
)


_CMSGGC_GLOBALGAME_SUBSCRIBE = _descriptor.Descriptor(
  name='CMsgGC_GlobalGame_Subscribe',
  full_name='CMsgGC_GlobalGame_Subscribe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgGC_GlobalGame_Subscribe.ticket', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17569,
  serialized_end=17614,
)


_CMSGGC_GLOBALGAME_UNSUBSCRIBE = _descriptor.Descriptor(
  name='CMsgGC_GlobalGame_Unsubscribe',
  full_name='CMsgGC_GlobalGame_Unsubscribe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeleft', full_name='CMsgGC_GlobalGame_Unsubscribe.timeleft', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17616,
  serialized_end=17665,
)


_CMSGGC_GLOBALGAME_PLAY = _descriptor.Descriptor(
  name='CMsgGC_GlobalGame_Play',
  full_name='CMsgGC_GlobalGame_Play',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgGC_GlobalGame_Play.ticket', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gametimems', full_name='CMsgGC_GlobalGame_Play.gametimems', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msperpoint', full_name='CMsgGC_GlobalGame_Play.msperpoint', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17667,
  serialized_end=17747,
)


_CMSGGCCSTRIKE15_V2_ACKNOWLEDGEPENALTY = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_AcknowledgePenalty',
  full_name='CMsgGCCStrike15_v2_AcknowledgePenalty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acknowledged', full_name='CMsgGCCStrike15_v2_AcknowledgePenalty.acknowledged', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17749,
  serialized_end=17810,
)


_CMSGGCCSTRIKE15_V2_CLIENT2GCREQUESTPRESTIGECOIN = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin',
  full_name='CMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17812,
  serialized_end=17861,
)


_CMSGGCCSTRIKE15_V2_CLIENT2GCSTREAMUNLOCK = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Client2GCStreamUnlock',
  full_name='CMsgGCCStrike15_v2_Client2GCStreamUnlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgGCCStrike15_v2_Client2GCStreamUnlock.ticket', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='os', full_name='CMsgGCCStrike15_v2_Client2GCStreamUnlock.os', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17863,
  serialized_end=17933,
)


_CMSGGCCSTRIKE15_V2_CLIENTTOGCREQUESTELEVATE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientToGCRequestElevate',
  full_name='CMsgGCCStrike15_v2_ClientToGCRequestElevate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stage', full_name='CMsgGCCStrike15_v2_ClientToGCRequestElevate.stage', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17935,
  serialized_end=17995,
)


_CMSGGCCSTRIKE15_V2_CLIENTTOGCCHAT = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientToGCChat',
  full_name='CMsgGCCStrike15_v2_ClientToGCChat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCCStrike15_v2_ClientToGCChat.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='CMsgGCCStrike15_v2_ClientToGCChat.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17997,
  serialized_end=18064,
)


_CMSGGCCSTRIKE15_V2_GCTOCLIENTCHAT = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_GCToClientChat',
  full_name='CMsgGCCStrike15_v2_GCToClientChat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCCStrike15_v2_GCToClientChat.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='CMsgGCCStrike15_v2_GCToClientChat.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18066,
  serialized_end=18135,
)


_CMSGGCCSTRIKE15_V2_CLIENTAUTHKEYCODE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientAuthKeyCode',
  full_name='CMsgGCCStrike15_v2_ClientAuthKeyCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventid', full_name='CMsgGCCStrike15_v2_ClientAuthKeyCode.eventid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='CMsgGCCStrike15_v2_ClientAuthKeyCode.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18137,
  serialized_end=18206,
)


_CMSGGCCSTRIKE15_GOTVSYNCPACKET = _descriptor.Descriptor(
  name='CMsgGCCStrike15_GotvSyncPacket',
  full_name='CMsgGCCStrike15_GotvSyncPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CMsgGCCStrike15_GotvSyncPacket.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18208,
  serialized_end=18278,
)


_PLAYERDECALDIGITALSIGNATURE = _descriptor.Descriptor(
  name='PlayerDecalDigitalSignature',
  full_name='PlayerDecalDigitalSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='PlayerDecalDigitalSignature.signature', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='PlayerDecalDigitalSignature.accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rtime', full_name='PlayerDecalDigitalSignature.rtime', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endpos', full_name='PlayerDecalDigitalSignature.endpos', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startpos', full_name='PlayerDecalDigitalSignature.startpos', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='right', full_name='PlayerDecalDigitalSignature.right', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tx_defidx', full_name='PlayerDecalDigitalSignature.tx_defidx', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entindex', full_name='PlayerDecalDigitalSignature.entindex', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hitbox', full_name='PlayerDecalDigitalSignature.hitbox', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creationtime', full_name='PlayerDecalDigitalSignature.creationtime', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='equipslot', full_name='PlayerDecalDigitalSignature.equipslot', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='PlayerDecalDigitalSignature.trace_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normal', full_name='PlayerDecalDigitalSignature.normal', index=12,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tint_id', full_name='PlayerDecalDigitalSignature.tint_id', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18281,
  serialized_end=18557,
)


_CMSGGCCSTRIKE15_V2_CLIENTPLAYERDECALSIGN = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientPlayerDecalSign',
  full_name='CMsgGCCStrike15_v2_ClientPlayerDecalSign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CMsgGCCStrike15_v2_ClientPlayerDecalSign.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CMsgGCCStrike15_v2_ClientPlayerDecalSign.itemid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18559,
  serialized_end=18661,
)


_CMSGGCCSTRIKE15_V2_CLIENTLOGONFATALERROR = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientLogonFatalError',
  full_name='CMsgGCCStrike15_v2_ClientLogonFatalError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errorcode', full_name='CMsgGCCStrike15_v2_ClientLogonFatalError.errorcode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgGCCStrike15_v2_ClientLogonFatalError.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18663,
  serialized_end=18741,
)


_CMSGGCCSTRIKE15_V2_CLIENTPOLLSTATE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientPollState',
  full_name='CMsgGCCStrike15_v2_ClientPollState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pollid', full_name='CMsgGCCStrike15_v2_ClientPollState.pollid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='names', full_name='CMsgGCCStrike15_v2_ClientPollState.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='CMsgGCCStrike15_v2_ClientPollState.values', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18743,
  serialized_end=18826,
)


_CMSGGCCSTRIKE15_V2_PARTY_REGISTER = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Party_Register',
  full_name='CMsgGCCStrike15_v2_Party_Register',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgGCCStrike15_v2_Party_Register.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ver', full_name='CMsgGCCStrike15_v2_Party_Register.ver', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='apr', full_name='CMsgGCCStrike15_v2_Party_Register.apr', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ark', full_name='CMsgGCCStrike15_v2_Party_Register.ark', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nby', full_name='CMsgGCCStrike15_v2_Party_Register.nby', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='grp', full_name='CMsgGCCStrike15_v2_Party_Register.grp', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slots', full_name='CMsgGCCStrike15_v2_Party_Register.slots', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='launcher', full_name='CMsgGCCStrike15_v2_Party_Register.launcher', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18829,
  serialized_end=18974,
)


_CMSGGCCSTRIKE15_V2_PARTY_SEARCH = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Party_Search',
  full_name='CMsgGCCStrike15_v2_Party_Search',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ver', full_name='CMsgGCCStrike15_v2_Party_Search.ver', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='apr', full_name='CMsgGCCStrike15_v2_Party_Search.apr', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ark', full_name='CMsgGCCStrike15_v2_Party_Search.ark', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='grps', full_name='CMsgGCCStrike15_v2_Party_Search.grps', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='launcher', full_name='CMsgGCCStrike15_v2_Party_Search.launcher', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18976,
  serialized_end=19080,
)


_CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='CMsgGCCStrike15_v2_Party_SearchResults.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgGCCStrike15_v2_Party_SearchResults.Entry.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='grp', full_name='CMsgGCCStrike15_v2_Party_SearchResults.Entry.grp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19189,
  serialized_end=19221,
)

_CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Party_SearchResults',
  full_name='CMsgGCCStrike15_v2_Party_SearchResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='CMsgGCCStrike15_v2_Party_SearchResults.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS_ENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19083,
  serialized_end=19221,
)


_CMSGGCCSTRIKE15_V2_PARTY_INVITE = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Party_Invite',
  full_name='CMsgGCCStrike15_v2_Party_Invite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_Party_Invite.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobbyid', full_name='CMsgGCCStrike15_v2_Party_Invite.lobbyid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19223,
  serialized_end=19292,
)


_CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CMsgGCCStrike15_v2_Account_RequestCoPlays.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCCStrike15_v2_Account_RequestCoPlays.Player.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rtcoplay', full_name='CMsgGCCStrike15_v2_Account_RequestCoPlays.Player.rtcoplay', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='online', full_name='CMsgGCCStrike15_v2_Account_RequestCoPlays.Player.online', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19428,
  serialized_end=19489,
)

_CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_Account_RequestCoPlays',
  full_name='CMsgGCCStrike15_v2_Account_RequestCoPlays',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgGCCStrike15_v2_Account_RequestCoPlays.players', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='servertime', full_name='CMsgGCCStrike15_v2_Account_RequestCoPlays.servertime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS_PLAYER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19295,
  serialized_end=19489,
)


_CMSGGCCSTRIKE15_V2_CLIENTTOGCREQUESTTICKET = _descriptor.Descriptor(
  name='CMsgGCCStrike15_v2_ClientToGCRequestTicket',
  full_name='CMsgGCCStrike15_v2_ClientToGCRequestTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorized_steam_id', full_name='CMsgGCCStrike15_v2_ClientToGCRequestTicket.authorized_steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='authorized_public_ip', full_name='CMsgGCCStrike15_v2_ClientToGCRequestTicket.authorized_public_ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameserver_steam_id', full_name='CMsgGCCStrike15_v2_ClientToGCRequestTicket.gameserver_steam_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameserver_net_id', full_name='CMsgGCCStrike15_v2_ClientToGCRequestTicket.gameserver_net_id', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19492,
  serialized_end=19651,
)

_TOURNAMENTTEAM.fields_by_name['players'].message_type = _TOURNAMENTPLAYER
_GLOBALSTATISTICS.fields_by_name['search_statistics'].message_type = _DETAILEDSEARCHSTATISTIC
_OPERATIONALSTATISTICSPACKET.fields_by_name['values'].message_type = _OPERATIONALSTATISTICELEMENT
_SCORELEADERBOARDDATA_ENTRY.containing_type = _SCORELEADERBOARDDATA
_SCORELEADERBOARDDATA_ACCOUNTENTRIES.fields_by_name['entries'].message_type = _SCORELEADERBOARDDATA_ENTRY
_SCORELEADERBOARDDATA_ACCOUNTENTRIES.containing_type = _SCORELEADERBOARDDATA
_SCORELEADERBOARDDATA.fields_by_name['accountentries'].message_type = _SCORELEADERBOARDDATA_ACCOUNTENTRIES
_SCORELEADERBOARDDATA.fields_by_name['matchentries'].message_type = _SCORELEADERBOARDDATA_ENTRY
_PLAYERQUESTDATA_QUESTITEMDATA.containing_type = _PLAYERQUESTDATA
_PLAYERQUESTDATA.fields_by_name['quest_item_data'].message_type = _PLAYERQUESTDATA_QUESTITEMDATA
_PLAYERQUESTDATA.fields_by_name['xp_progress_data'].message_type = _XPPROGRESSDATA
_PLAYERQUESTDATA.fields_by_name['item_updates'].message_type = _MATCHENDITEMUPDATES
_CMSGGC_SERVERQUESTUPDATEDATA.fields_by_name['player_quest_data'].message_type = _PLAYERQUESTDATA
_CMSGGC_SERVERQUESTUPDATEDATA.fields_by_name['missionlbsdata'].message_type = _SCORELEADERBOARDDATA
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGCOPERATIONALSTATS.fields_by_name['namekeys'].message_type = _OPERATIONALSTATISTICDESCRIPTION
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGCOPERATIONALSTATS.fields_by_name['packets'].message_type = _OPERATIONALSTATISTICSPACKET
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSTART.fields_by_name['tournament_match'].message_type = _TOURNAMENTMATCHSETUP
_CMSGGCCSTRIKE15_V2_MATCHMAKINGCLIENT2SERVERPING.fields_by_name['gameserverpings'].message_type = _GAMESERVERPING
_CMSGGCCSTRIKE15_V2_MATCHMAKINGCLIENT2SERVERPING.fields_by_name['data_center_pings'].message_type = _DATACENTERPING
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE_NOTE.containing_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE.fields_by_name['global_stats'].message_type = _GLOBALSTATISTICS
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE.fields_by_name['server_ipaddress_mask'].message_type = _IPADDRESSMASK
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE.fields_by_name['notes'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE_NOTE
_CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT_ENTRY.containing_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT
_CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT.fields_by_name['drafts'].message_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT_ENTRY
_CPREMATCHINFODATA_TEAMSTATS.containing_type = _CPREMATCHINFODATA
_CPREMATCHINFODATA.fields_by_name['draft'].message_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT
_CPREMATCHINFODATA.fields_by_name['stats'].message_type = _CPREMATCHINFODATA_TEAMSTATS
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE.fields_by_name['rankings'].message_type = _PLAYERRANKINGINFO
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE.fields_by_name['whitelist'].message_type = _IPADDRESSMASK
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE.fields_by_name['tournament_event'].message_type = _TOURNAMENTEVENT
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE.fields_by_name['tournament_teams'].message_type = _TOURNAMENTTEAM
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE.fields_by_name['pre_match_data'].message_type = _CPREMATCHINFODATA
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERRESERVATIONRESPONSE.fields_by_name['reservation'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERRESERVATIONRESPONSE.fields_by_name['tv_info'].message_type = _SERVERHLTVINFO
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTRESERVE.fields_by_name['reservation'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS_DROPINFO.containing_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS.fields_by_name['reservation'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS.fields_by_name['confirm'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERCONFIRM
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS.fields_by_name['drop_info'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS_DROPINFO
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERMATCHEND.fields_by_name['stats'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERMATCHEND.fields_by_name['confirm'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERCONFIRM
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERMATCHEND.fields_by_name['match_end_quest_data'].message_type = _CMSGGC_SERVERQUESTUPDATEDATA
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['ongoingmatch'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTRESERVE
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['global_stats'].message_type = _GLOBALSTATISTICS
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['ranking'].message_type = _PLAYERRANKINGINFO
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['commendation'].message_type = _PLAYERCOMMENDATIONINFO
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['medals'].message_type = _PLAYERMEDALSINFO
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['my_current_event'].message_type = _TOURNAMENTEVENT
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['my_current_event_teams'].message_type = _TOURNAMENTTEAM
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['my_current_team'].message_type = _TOURNAMENTTEAM
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['my_current_event_stages'].message_type = _TOURNAMENTEVENT
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO.fields_by_name['activity'].message_type = _ACCOUNTACTIVITY
_CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS_SETTING.containing_type = _CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS
_CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS.fields_by_name['settings'].message_type = _CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS_SETTING
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTABANDON.fields_by_name['abandoned_match'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTRESERVE
_CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVER2GCKICK.fields_by_name['reservation'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE
_CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRANKUPDATE.fields_by_name['rankings'].message_type = _PLAYERRANKINGINFO
_CMSGGCCSTRIKE15_V2_CLIENTCOMMENDPLAYER.fields_by_name['commendation'].message_type = _PLAYERCOMMENDATIONINFO
_CMSGGCCSTRIKE15_V2_CLIENTREQUESTJOINFRIENDDATA.fields_by_name['res'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTRESERVE
_CMSGGCCSTRIKE15_V2_CLIENTREQUESTJOINSERVERDATA.fields_by_name['res'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTRESERVE
_CMSGGCCSTRIKE15_V2_GC2SERVERNOTIFYXPREWARDED.fields_by_name['xp_progress_data'].message_type = _XPPROGRESSDATA
_CMSGGCCSTRIKE15_V2_WATCHINFOUSERS.fields_by_name['watchable_match_infos'].message_type = _WATCHABLEMATCHINFO
_CMSGGCCSTRIKE15_V2_PLAYERSPROFILE.fields_by_name['account_profiles'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO
_CMSGGCCSTRIKE15_V2_MATCHENDRUNREWARDDROPS.fields_by_name['serverinfo'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERRESERVATIONRESPONSE
_CMSGGCCSTRIKE15_V2_MATCHENDRUNREWARDDROPS.fields_by_name['match_end_quest_data'].message_type = _CMSGGC_SERVERQUESTUPDATEDATA
_CECONITEMPREVIEWDATABLOCK_STICKER.containing_type = _CECONITEMPREVIEWDATABLOCK
_CECONITEMPREVIEWDATABLOCK.fields_by_name['stickers'].message_type = _CECONITEMPREVIEWDATABLOCK_STICKER
_CMSGGCCSTRIKE15_V2_MATCHENDREWARDDROPSNOTIFICATION.fields_by_name['iteminfo'].message_type = _CECONITEMPREVIEWDATABLOCK
_CMSGITEMACKNOWLEDGED.fields_by_name['iteminfo'].message_type = _CECONITEMPREVIEWDATABLOCK
_CMSGGCCSTRIKE15_V2_CLIENT2GCECONPREVIEWDATABLOCKRESPONSE.fields_by_name['iteminfo'].message_type = _CECONITEMPREVIEWDATABLOCK
_CDATAGCCSTRIKE15_V2_MATCHINFO.fields_by_name['watchablematchinfo'].message_type = _WATCHABLEMATCHINFO
_CDATAGCCSTRIKE15_V2_MATCHINFO.fields_by_name['roundstats_legacy'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS
_CDATAGCCSTRIKE15_V2_MATCHINFO.fields_by_name['roundstatsall'].message_type = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS
_CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP_PICKS.containing_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP
_CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP.fields_by_name['teams'].message_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUPTEAM
_CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP.fields_by_name['picks'].message_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP_PICKS
_CDATAGCCSTRIKE15_V2_TOURNAMENTSECTION.fields_by_name['groups'].message_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP
_CDATAGCCSTRIKE15_V2_TOURNAMENTINFO.fields_by_name['sections'].message_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTSECTION
_CDATAGCCSTRIKE15_V2_TOURNAMENTINFO.fields_by_name['tournament_event'].message_type = _TOURNAMENTEVENT
_CDATAGCCSTRIKE15_V2_TOURNAMENTINFO.fields_by_name['tournament_teams'].message_type = _TOURNAMENTTEAM
_CMSGGCCSTRIKE15_V2_MATCHLIST.fields_by_name['matches'].message_type = _CDATAGCCSTRIKE15_V2_MATCHINFO
_CMSGGCCSTRIKE15_V2_MATCHLIST.fields_by_name['streams'].message_type = _TOURNAMENTTEAM
_CMSGGCCSTRIKE15_V2_MATCHLIST.fields_by_name['tournamentinfo'].message_type = _CDATAGCCSTRIKE15_V2_TOURNAMENTINFO
_CMSGGCCSTRIKE15_V2_PREDICTIONS_GROUPMATCHTEAMPICK.containing_type = _CMSGGCCSTRIKE15_V2_PREDICTIONS
_CMSGGCCSTRIKE15_V2_PREDICTIONS.fields_by_name['group_match_team_picks'].message_type = _CMSGGCCSTRIKE15_V2_PREDICTIONS_GROUPMATCHTEAMPICK
_CMSGGCCSTRIKE15_V2_FANTASY_FANTASYSLOT.containing_type = _CMSGGCCSTRIKE15_V2_FANTASY
_CMSGGCCSTRIKE15_V2_FANTASY_FANTASYTEAM.fields_by_name['slots'].message_type = _CMSGGCCSTRIKE15_V2_FANTASY_FANTASYSLOT
_CMSGGCCSTRIKE15_V2_FANTASY_FANTASYTEAM.containing_type = _CMSGGCCSTRIKE15_V2_FANTASY
_CMSGGCCSTRIKE15_V2_FANTASY.fields_by_name['teams'].message_type = _CMSGGCCSTRIKE15_V2_FANTASY_FANTASYTEAM
_CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE_GIFTLEADERBOARDENTRY.containing_type = _CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE
_CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE.fields_by_name['entries'].message_type = _CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE_GIFTLEADERBOARDENTRY
_CSOPERSONADATAPUBLIC.fields_by_name['commendation'].message_type = _PLAYERCOMMENDATIONINFO
_CMSGGCCSTRIKE15_GOTVSYNCPACKET.fields_by_name['data'].message_type = demoparser_dot_protobufs_dot_engine__gcmessages__pb2._CENGINEGOTVSYNCPACKET
_CMSGGCCSTRIKE15_V2_CLIENTPLAYERDECALSIGN.fields_by_name['data'].message_type = _PLAYERDECALDIGITALSIGNATURE
_CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS_ENTRY.containing_type = _CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS
_CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS.fields_by_name['entries'].message_type = _CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS_ENTRY
_CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS_PLAYER.containing_type = _CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS
_CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS.fields_by_name['players'].message_type = _CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS_PLAYER
DESCRIPTOR.message_types_by_name['GameServerPing'] = _GAMESERVERPING
DESCRIPTOR.message_types_by_name['DataCenterPing'] = _DATACENTERPING
DESCRIPTOR.message_types_by_name['DetailedSearchStatistic'] = _DETAILEDSEARCHSTATISTIC
DESCRIPTOR.message_types_by_name['TournamentPlayer'] = _TOURNAMENTPLAYER
DESCRIPTOR.message_types_by_name['TournamentTeam'] = _TOURNAMENTTEAM
DESCRIPTOR.message_types_by_name['TournamentEvent'] = _TOURNAMENTEVENT
DESCRIPTOR.message_types_by_name['GlobalStatistics'] = _GLOBALSTATISTICS
DESCRIPTOR.message_types_by_name['OperationalStatisticDescription'] = _OPERATIONALSTATISTICDESCRIPTION
DESCRIPTOR.message_types_by_name['OperationalStatisticElement'] = _OPERATIONALSTATISTICELEMENT
DESCRIPTOR.message_types_by_name['OperationalStatisticsPacket'] = _OPERATIONALSTATISTICSPACKET
DESCRIPTOR.message_types_by_name['PlayerRankingInfo'] = _PLAYERRANKINGINFO
DESCRIPTOR.message_types_by_name['PlayerCommendationInfo'] = _PLAYERCOMMENDATIONINFO
DESCRIPTOR.message_types_by_name['PlayerMedalsInfo'] = _PLAYERMEDALSINFO
DESCRIPTOR.message_types_by_name['AccountActivity'] = _ACCOUNTACTIVITY
DESCRIPTOR.message_types_by_name['TournamentMatchSetup'] = _TOURNAMENTMATCHSETUP
DESCRIPTOR.message_types_by_name['ServerHltvInfo'] = _SERVERHLTVINFO
DESCRIPTOR.message_types_by_name['IpAddressMask'] = _IPADDRESSMASK
DESCRIPTOR.message_types_by_name['XpProgressData'] = _XPPROGRESSDATA
DESCRIPTOR.message_types_by_name['MatchEndItemUpdates'] = _MATCHENDITEMUPDATES
DESCRIPTOR.message_types_by_name['ScoreLeaderboardData'] = _SCORELEADERBOARDDATA
DESCRIPTOR.message_types_by_name['PlayerQuestData'] = _PLAYERQUESTDATA
DESCRIPTOR.message_types_by_name['CMsgGC_ServerQuestUpdateData'] = _CMSGGC_SERVERQUESTUPDATEDATA
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingGCOperationalStats'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGCOPERATIONALSTATS
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERCONFIRM
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_GC2ServerReservationUpdate'] = _CMSGGCCSTRIKE15_V2_GC2SERVERRESERVATIONUPDATE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingStart'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSTART
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingStop'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSTOP
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingClient2ServerPing'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGCLIENT2SERVERPING
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE
DESCRIPTOR.message_types_by_name['CDataGCCStrike15_v2_TournamentMatchDraft'] = _CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT
DESCRIPTOR.message_types_by_name['CPreMatchInfoData'] = _CPREMATCHINFODATA
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingServerReservationResponse'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERRESERVATIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTRESERVE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingServerRoundStats'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingServerMatchEnd'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERMATCHEND
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingClient2GCHello'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGCLIENT2GCHELLO
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingGC2ClientHello'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_AccountPrivacySettings'] = _CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTABANDON
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingServer2GCKick'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVER2GCKICK
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRANKUPDATE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate'] = _CMSGGCCSTRIKE15_V2_MATCHMAKINGOPERATOR2GCBLOGUPDATE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ServerNotificationForUserPenalty'] = _CMSGGCCSTRIKE15_V2_SERVERNOTIFICATIONFORUSERPENALTY
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientReportPlayer'] = _CMSGGCCSTRIKE15_V2_CLIENTREPORTPLAYER
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientCommendPlayer'] = _CMSGGCCSTRIKE15_V2_CLIENTCOMMENDPLAYER
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientReportServer'] = _CMSGGCCSTRIKE15_V2_CLIENTREPORTSERVER
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientReportResponse'] = _CMSGGCCSTRIKE15_V2_CLIENTREPORTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends'] = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTWATCHINFOFRIENDS
DESCRIPTOR.message_types_by_name['WatchableMatchInfo'] = _WATCHABLEMATCHINFO
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientRequestJoinFriendData'] = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTJOINFRIENDDATA
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientRequestJoinServerData'] = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTJOINSERVERDATA
DESCRIPTOR.message_types_by_name['CMsgGCCstrike15_v2_ClientRequestNewMission'] = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTNEWMISSION
DESCRIPTOR.message_types_by_name['CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded'] = _CMSGGCCSTRIKE15_V2_GC2SERVERNOTIFYXPREWARDED
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_WatchInfoUsers'] = _CMSGGCCSTRIKE15_V2_WATCHINFOUSERS
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientRequestPlayersProfile'] = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTPLAYERSPROFILE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_PlayersProfile'] = _CMSGGCCSTRIKE15_V2_PLAYERSPROFILE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate'] = _CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASEUPDATE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment'] = _CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASEASSIGNMENT
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus'] = _CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASESTATUS
DESCRIPTOR.message_types_by_name['CClientHeaderOverwatchEvidence'] = _CCLIENTHEADEROVERWATCHEVIDENCE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_GC2ClientTextMsg'] = _CMSGGCCSTRIKE15_V2_GC2CLIENTTEXTMSG
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Client2GCTextMsg'] = _CMSGGCCSTRIKE15_V2_CLIENT2GCTEXTMSG
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchEndRunRewardDrops'] = _CMSGGCCSTRIKE15_V2_MATCHENDRUNREWARDDROPS
DESCRIPTOR.message_types_by_name['CEconItemPreviewDataBlock'] = _CECONITEMPREVIEWDATABLOCK
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchEndRewardDropsNotification'] = _CMSGGCCSTRIKE15_V2_MATCHENDREWARDDROPSNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgItemAcknowledged'] = _CMSGITEMACKNOWLEDGED
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest'] = _CMSGGCCSTRIKE15_V2_CLIENT2GCECONPREVIEWDATABLOCKREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse'] = _CMSGGCCSTRIKE15_V2_CLIENT2GCECONPREVIEWDATABLOCKRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification'] = _CMSGGCCSTRIKE15_V2_TOURNAMENTMATCHREWARDDROPSNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames'] = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTCURRENTLIVEGAMES
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser'] = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTLIVEGAMEFORUSER
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchListRequestRecentUserGames'] = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTRECENTUSERGAMES
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchListRequestTournamentGames'] = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTTOURNAMENTGAMES
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchListRequestFullGameInfo'] = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTFULLGAMEINFO
DESCRIPTOR.message_types_by_name['CDataGCCStrike15_v2_MatchInfo'] = _CDATAGCCSTRIKE15_V2_MATCHINFO
DESCRIPTOR.message_types_by_name['CDataGCCStrike15_v2_TournamentGroupTeam'] = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUPTEAM
DESCRIPTOR.message_types_by_name['CDataGCCStrike15_v2_TournamentGroup'] = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP
DESCRIPTOR.message_types_by_name['CDataGCCStrike15_v2_TournamentSection'] = _CDATAGCCSTRIKE15_V2_TOURNAMENTSECTION
DESCRIPTOR.message_types_by_name['CDataGCCStrike15_v2_TournamentInfo'] = _CDATAGCCSTRIKE15_V2_TOURNAMENTINFO
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_MatchList'] = _CMSGGCCSTRIKE15_V2_MATCHLIST
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Predictions'] = _CMSGGCCSTRIKE15_V2_PREDICTIONS
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Fantasy'] = _CMSGGCCSTRIKE15_V2_FANTASY
DESCRIPTOR.message_types_by_name['CAttribute_String'] = _CATTRIBUTE_STRING
DESCRIPTOR.message_types_by_name['CMsgGCToGCReloadVersions'] = _CMSGGCTOGCRELOADVERSIONS
DESCRIPTOR.message_types_by_name['CMsgCStrike15Welcome'] = _CMSGCSTRIKE15WELCOME
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientVarValueNotificationInfo'] = _CMSGGCCSTRIKE15_V2_CLIENTVARVALUENOTIFICATIONINFO
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ServerVarValueNotificationInfo'] = _CMSGGCCSTRIKE15_V2_SERVERVARVALUENOTIFICATIONINFO
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_GiftsLeaderboardRequest'] = _CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_GiftsLeaderboardResponse'] = _CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientSubmitSurveyVote'] = _CMSGGCCSTRIKE15_V2_CLIENTSUBMITSURVEYVOTE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Server2GCClientValidate'] = _CMSGGCCSTRIKE15_V2_SERVER2GCCLIENTVALIDATE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure'] = _CMSGGCCSTRIKE15_V2_SERVER2GCPURESERVERVALIDATIONFAILURE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_GC2ClientTournamentInfo'] = _CMSGGCCSTRIKE15_V2_GC2CLIENTTOURNAMENTINFO
DESCRIPTOR.message_types_by_name['CSOEconCoupon'] = _CSOECONCOUPON
DESCRIPTOR.message_types_by_name['CSOQuestProgress'] = _CSOQUESTPROGRESS
DESCRIPTOR.message_types_by_name['CSOPersonaDataPublic'] = _CSOPERSONADATAPUBLIC
DESCRIPTOR.message_types_by_name['CMsgGC_GlobalGame_Subscribe'] = _CMSGGC_GLOBALGAME_SUBSCRIBE
DESCRIPTOR.message_types_by_name['CMsgGC_GlobalGame_Unsubscribe'] = _CMSGGC_GLOBALGAME_UNSUBSCRIBE
DESCRIPTOR.message_types_by_name['CMsgGC_GlobalGame_Play'] = _CMSGGC_GLOBALGAME_PLAY
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_AcknowledgePenalty'] = _CMSGGCCSTRIKE15_V2_ACKNOWLEDGEPENALTY
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin'] = _CMSGGCCSTRIKE15_V2_CLIENT2GCREQUESTPRESTIGECOIN
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Client2GCStreamUnlock'] = _CMSGGCCSTRIKE15_V2_CLIENT2GCSTREAMUNLOCK
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientToGCRequestElevate'] = _CMSGGCCSTRIKE15_V2_CLIENTTOGCREQUESTELEVATE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientToGCChat'] = _CMSGGCCSTRIKE15_V2_CLIENTTOGCCHAT
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_GCToClientChat'] = _CMSGGCCSTRIKE15_V2_GCTOCLIENTCHAT
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientAuthKeyCode'] = _CMSGGCCSTRIKE15_V2_CLIENTAUTHKEYCODE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_GotvSyncPacket'] = _CMSGGCCSTRIKE15_GOTVSYNCPACKET
DESCRIPTOR.message_types_by_name['PlayerDecalDigitalSignature'] = _PLAYERDECALDIGITALSIGNATURE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientPlayerDecalSign'] = _CMSGGCCSTRIKE15_V2_CLIENTPLAYERDECALSIGN
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientLogonFatalError'] = _CMSGGCCSTRIKE15_V2_CLIENTLOGONFATALERROR
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientPollState'] = _CMSGGCCSTRIKE15_V2_CLIENTPOLLSTATE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Party_Register'] = _CMSGGCCSTRIKE15_V2_PARTY_REGISTER
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Party_Search'] = _CMSGGCCSTRIKE15_V2_PARTY_SEARCH
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Party_SearchResults'] = _CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Party_Invite'] = _CMSGGCCSTRIKE15_V2_PARTY_INVITE
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_Account_RequestCoPlays'] = _CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS
DESCRIPTOR.message_types_by_name['CMsgGCCStrike15_v2_ClientToGCRequestTicket'] = _CMSGGCCSTRIKE15_V2_CLIENTTOGCREQUESTTICKET
DESCRIPTOR.enum_types_by_name['ECsgoGCMsg'] = _ECSGOGCMSG

GameServerPing = _reflection.GeneratedProtocolMessageType('GameServerPing', (_message.Message,), dict(
  DESCRIPTOR = _GAMESERVERPING,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:GameServerPing)
  ))
_sym_db.RegisterMessage(GameServerPing)

DataCenterPing = _reflection.GeneratedProtocolMessageType('DataCenterPing', (_message.Message,), dict(
  DESCRIPTOR = _DATACENTERPING,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:DataCenterPing)
  ))
_sym_db.RegisterMessage(DataCenterPing)

DetailedSearchStatistic = _reflection.GeneratedProtocolMessageType('DetailedSearchStatistic', (_message.Message,), dict(
  DESCRIPTOR = _DETAILEDSEARCHSTATISTIC,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:DetailedSearchStatistic)
  ))
_sym_db.RegisterMessage(DetailedSearchStatistic)

TournamentPlayer = _reflection.GeneratedProtocolMessageType('TournamentPlayer', (_message.Message,), dict(
  DESCRIPTOR = _TOURNAMENTPLAYER,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:TournamentPlayer)
  ))
_sym_db.RegisterMessage(TournamentPlayer)

TournamentTeam = _reflection.GeneratedProtocolMessageType('TournamentTeam', (_message.Message,), dict(
  DESCRIPTOR = _TOURNAMENTTEAM,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:TournamentTeam)
  ))
_sym_db.RegisterMessage(TournamentTeam)

TournamentEvent = _reflection.GeneratedProtocolMessageType('TournamentEvent', (_message.Message,), dict(
  DESCRIPTOR = _TOURNAMENTEVENT,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:TournamentEvent)
  ))
_sym_db.RegisterMessage(TournamentEvent)

GlobalStatistics = _reflection.GeneratedProtocolMessageType('GlobalStatistics', (_message.Message,), dict(
  DESCRIPTOR = _GLOBALSTATISTICS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:GlobalStatistics)
  ))
_sym_db.RegisterMessage(GlobalStatistics)

OperationalStatisticDescription = _reflection.GeneratedProtocolMessageType('OperationalStatisticDescription', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONALSTATISTICDESCRIPTION,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:OperationalStatisticDescription)
  ))
_sym_db.RegisterMessage(OperationalStatisticDescription)

OperationalStatisticElement = _reflection.GeneratedProtocolMessageType('OperationalStatisticElement', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONALSTATISTICELEMENT,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:OperationalStatisticElement)
  ))
_sym_db.RegisterMessage(OperationalStatisticElement)

OperationalStatisticsPacket = _reflection.GeneratedProtocolMessageType('OperationalStatisticsPacket', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONALSTATISTICSPACKET,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:OperationalStatisticsPacket)
  ))
_sym_db.RegisterMessage(OperationalStatisticsPacket)

PlayerRankingInfo = _reflection.GeneratedProtocolMessageType('PlayerRankingInfo', (_message.Message,), dict(
  DESCRIPTOR = _PLAYERRANKINGINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:PlayerRankingInfo)
  ))
_sym_db.RegisterMessage(PlayerRankingInfo)

PlayerCommendationInfo = _reflection.GeneratedProtocolMessageType('PlayerCommendationInfo', (_message.Message,), dict(
  DESCRIPTOR = _PLAYERCOMMENDATIONINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:PlayerCommendationInfo)
  ))
_sym_db.RegisterMessage(PlayerCommendationInfo)

PlayerMedalsInfo = _reflection.GeneratedProtocolMessageType('PlayerMedalsInfo', (_message.Message,), dict(
  DESCRIPTOR = _PLAYERMEDALSINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:PlayerMedalsInfo)
  ))
_sym_db.RegisterMessage(PlayerMedalsInfo)

AccountActivity = _reflection.GeneratedProtocolMessageType('AccountActivity', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTACTIVITY,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:AccountActivity)
  ))
_sym_db.RegisterMessage(AccountActivity)

TournamentMatchSetup = _reflection.GeneratedProtocolMessageType('TournamentMatchSetup', (_message.Message,), dict(
  DESCRIPTOR = _TOURNAMENTMATCHSETUP,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:TournamentMatchSetup)
  ))
_sym_db.RegisterMessage(TournamentMatchSetup)

ServerHltvInfo = _reflection.GeneratedProtocolMessageType('ServerHltvInfo', (_message.Message,), dict(
  DESCRIPTOR = _SERVERHLTVINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:ServerHltvInfo)
  ))
_sym_db.RegisterMessage(ServerHltvInfo)

IpAddressMask = _reflection.GeneratedProtocolMessageType('IpAddressMask', (_message.Message,), dict(
  DESCRIPTOR = _IPADDRESSMASK,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:IpAddressMask)
  ))
_sym_db.RegisterMessage(IpAddressMask)

XpProgressData = _reflection.GeneratedProtocolMessageType('XpProgressData', (_message.Message,), dict(
  DESCRIPTOR = _XPPROGRESSDATA,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:XpProgressData)
  ))
_sym_db.RegisterMessage(XpProgressData)

MatchEndItemUpdates = _reflection.GeneratedProtocolMessageType('MatchEndItemUpdates', (_message.Message,), dict(
  DESCRIPTOR = _MATCHENDITEMUPDATES,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:MatchEndItemUpdates)
  ))
_sym_db.RegisterMessage(MatchEndItemUpdates)

ScoreLeaderboardData = _reflection.GeneratedProtocolMessageType('ScoreLeaderboardData', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _SCORELEADERBOARDDATA_ENTRY,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:ScoreLeaderboardData.Entry)
    ))
  ,

  AccountEntries = _reflection.GeneratedProtocolMessageType('AccountEntries', (_message.Message,), dict(
    DESCRIPTOR = _SCORELEADERBOARDDATA_ACCOUNTENTRIES,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:ScoreLeaderboardData.AccountEntries)
    ))
  ,
  DESCRIPTOR = _SCORELEADERBOARDDATA,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:ScoreLeaderboardData)
  ))
_sym_db.RegisterMessage(ScoreLeaderboardData)
_sym_db.RegisterMessage(ScoreLeaderboardData.Entry)
_sym_db.RegisterMessage(ScoreLeaderboardData.AccountEntries)

PlayerQuestData = _reflection.GeneratedProtocolMessageType('PlayerQuestData', (_message.Message,), dict(

  QuestItemData = _reflection.GeneratedProtocolMessageType('QuestItemData', (_message.Message,), dict(
    DESCRIPTOR = _PLAYERQUESTDATA_QUESTITEMDATA,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:PlayerQuestData.QuestItemData)
    ))
  ,
  DESCRIPTOR = _PLAYERQUESTDATA,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:PlayerQuestData)
  ))
_sym_db.RegisterMessage(PlayerQuestData)
_sym_db.RegisterMessage(PlayerQuestData.QuestItemData)

CMsgGC_ServerQuestUpdateData = _reflection.GeneratedProtocolMessageType('CMsgGC_ServerQuestUpdateData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGC_SERVERQUESTUPDATEDATA,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGC_ServerQuestUpdateData)
  ))
_sym_db.RegisterMessage(CMsgGC_ServerQuestUpdateData)

CMsgGCCStrike15_v2_MatchmakingGCOperationalStats = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingGCOperationalStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGCOPERATIONALSTATS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGCOperationalStats)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGCOperationalStats)

CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERCONFIRM,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGC2ServerConfirm)

CMsgGCCStrike15_v2_GC2ServerReservationUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_GC2ServerReservationUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_GC2SERVERRESERVATIONUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_GC2ServerReservationUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_GC2ServerReservationUpdate)

CMsgGCCStrike15_v2_MatchmakingStart = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingStart', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSTART,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingStart)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingStart)

CMsgGCCStrike15_v2_MatchmakingStop = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingStop', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSTOP,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingStop)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingStop)

CMsgGCCStrike15_v2_MatchmakingClient2ServerPing = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingClient2ServerPing', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGCLIENT2SERVERPING,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingClient2ServerPing)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingClient2ServerPing)

CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate', (_message.Message,), dict(

  Note = _reflection.GeneratedProtocolMessageType('Note', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE_NOTE,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.Note)
    ))
  ,
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGC2ClientUpdate.Note)

CDataGCCStrike15_v2_TournamentMatchDraft = _reflection.GeneratedProtocolMessageType('CDataGCCStrike15_v2_TournamentMatchDraft', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT_ENTRY,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CDataGCCStrike15_v2_TournamentMatchDraft.Entry)
    ))
  ,
  DESCRIPTOR = _CDATAGCCSTRIKE15_V2_TOURNAMENTMATCHDRAFT,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CDataGCCStrike15_v2_TournamentMatchDraft)
  ))
_sym_db.RegisterMessage(CDataGCCStrike15_v2_TournamentMatchDraft)
_sym_db.RegisterMessage(CDataGCCStrike15_v2_TournamentMatchDraft.Entry)

CPreMatchInfoData = _reflection.GeneratedProtocolMessageType('CPreMatchInfoData', (_message.Message,), dict(

  TeamStats = _reflection.GeneratedProtocolMessageType('TeamStats', (_message.Message,), dict(
    DESCRIPTOR = _CPREMATCHINFODATA_TEAMSTATS,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CPreMatchInfoData.TeamStats)
    ))
  ,
  DESCRIPTOR = _CPREMATCHINFODATA,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CPreMatchInfoData)
  ))
_sym_db.RegisterMessage(CPreMatchInfoData)
_sym_db.RegisterMessage(CPreMatchInfoData.TeamStats)

CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRESERVE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGC2ServerReserve)

CMsgGCCStrike15_v2_MatchmakingServerReservationResponse = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingServerReservationResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERRESERVATIONRESPONSE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingServerReservationResponse)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingServerReservationResponse)

CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTRESERVE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGC2ClientReserve)

CMsgGCCStrike15_v2_MatchmakingServerRoundStats = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingServerRoundStats', (_message.Message,), dict(

  DropInfo = _reflection.GeneratedProtocolMessageType('DropInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS_DROPINFO,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingServerRoundStats.DropInfo)
    ))
  ,
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERROUNDSTATS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingServerRoundStats)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingServerRoundStats)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingServerRoundStats.DropInfo)

CMsgGCCStrike15_v2_MatchmakingServerMatchEnd = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingServerMatchEnd', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVERMATCHEND,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingServerMatchEnd)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingServerMatchEnd)

CMsgGCCStrike15_v2_MatchmakingClient2GCHello = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingClient2GCHello', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGCLIENT2GCHELLO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingClient2GCHello)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingClient2GCHello)

CMsgGCCStrike15_v2_MatchmakingGC2ClientHello = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingGC2ClientHello', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTHELLO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGC2ClientHello)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGC2ClientHello)

CMsgGCCStrike15_v2_AccountPrivacySettings = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_AccountPrivacySettings', (_message.Message,), dict(

  Setting = _reflection.GeneratedProtocolMessageType('Setting', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS_SETTING,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_AccountPrivacySettings.Setting)
    ))
  ,
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_ACCOUNTPRIVACYSETTINGS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_AccountPrivacySettings)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_AccountPrivacySettings)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_AccountPrivacySettings.Setting)

CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2CLIENTABANDON,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGC2ClientAbandon)

CMsgGCCStrike15_v2_MatchmakingServer2GCKick = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingServer2GCKick', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGSERVER2GCKICK,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingServer2GCKick)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingServer2GCKick)

CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGGC2SERVERRANKUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingGC2ServerRankUpdate)

CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHMAKINGOPERATOR2GCBLOGUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchmakingOperator2GCBlogUpdate)

CMsgGCCStrike15_v2_ServerNotificationForUserPenalty = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ServerNotificationForUserPenalty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_SERVERNOTIFICATIONFORUSERPENALTY,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ServerNotificationForUserPenalty)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ServerNotificationForUserPenalty)

CMsgGCCStrike15_v2_ClientReportPlayer = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientReportPlayer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTREPORTPLAYER,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientReportPlayer)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientReportPlayer)

CMsgGCCStrike15_v2_ClientCommendPlayer = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientCommendPlayer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTCOMMENDPLAYER,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientCommendPlayer)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientCommendPlayer)

CMsgGCCStrike15_v2_ClientReportServer = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientReportServer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTREPORTSERVER,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientReportServer)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientReportServer)

CMsgGCCStrike15_v2_ClientReportResponse = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientReportResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTREPORTRESPONSE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientReportResponse)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientReportResponse)

CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTWATCHINFOFRIENDS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientRequestWatchInfoFriends)

WatchableMatchInfo = _reflection.GeneratedProtocolMessageType('WatchableMatchInfo', (_message.Message,), dict(
  DESCRIPTOR = _WATCHABLEMATCHINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:WatchableMatchInfo)
  ))
_sym_db.RegisterMessage(WatchableMatchInfo)

CMsgGCCStrike15_v2_ClientRequestJoinFriendData = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientRequestJoinFriendData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTJOINFRIENDDATA,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientRequestJoinFriendData)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientRequestJoinFriendData)

CMsgGCCStrike15_v2_ClientRequestJoinServerData = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientRequestJoinServerData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTJOINSERVERDATA,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientRequestJoinServerData)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientRequestJoinServerData)

CMsgGCCstrike15_v2_ClientRequestNewMission = _reflection.GeneratedProtocolMessageType('CMsgGCCstrike15_v2_ClientRequestNewMission', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTNEWMISSION,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCstrike15_v2_ClientRequestNewMission)
  ))
_sym_db.RegisterMessage(CMsgGCCstrike15_v2_ClientRequestNewMission)

CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded = _reflection.GeneratedProtocolMessageType('CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_GC2SERVERNOTIFYXPREWARDED,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded)
  ))
_sym_db.RegisterMessage(CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded)

CMsgGCCStrike15_v2_WatchInfoUsers = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_WatchInfoUsers', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_WATCHINFOUSERS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_WatchInfoUsers)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_WatchInfoUsers)

CMsgGCCStrike15_v2_ClientRequestPlayersProfile = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientRequestPlayersProfile', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTREQUESTPLAYERSPROFILE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientRequestPlayersProfile)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientRequestPlayersProfile)

CMsgGCCStrike15_v2_PlayersProfile = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_PlayersProfile', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PLAYERSPROFILE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_PlayersProfile)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_PlayersProfile)

CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASEUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_PlayerOverwatchCaseUpdate)

CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASEASSIGNMENT,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_PlayerOverwatchCaseAssignment)

CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PLAYEROVERWATCHCASESTATUS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_PlayerOverwatchCaseStatus)

CClientHeaderOverwatchEvidence = _reflection.GeneratedProtocolMessageType('CClientHeaderOverwatchEvidence', (_message.Message,), dict(
  DESCRIPTOR = _CCLIENTHEADEROVERWATCHEVIDENCE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CClientHeaderOverwatchEvidence)
  ))
_sym_db.RegisterMessage(CClientHeaderOverwatchEvidence)

CMsgGCCStrike15_v2_GC2ClientTextMsg = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_GC2ClientTextMsg', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_GC2CLIENTTEXTMSG,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_GC2ClientTextMsg)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_GC2ClientTextMsg)

CMsgGCCStrike15_v2_Client2GCTextMsg = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Client2GCTextMsg', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENT2GCTEXTMSG,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Client2GCTextMsg)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Client2GCTextMsg)

CMsgGCCStrike15_v2_MatchEndRunRewardDrops = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchEndRunRewardDrops', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHENDRUNREWARDDROPS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchEndRunRewardDrops)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchEndRunRewardDrops)

CEconItemPreviewDataBlock = _reflection.GeneratedProtocolMessageType('CEconItemPreviewDataBlock', (_message.Message,), dict(

  Sticker = _reflection.GeneratedProtocolMessageType('Sticker', (_message.Message,), dict(
    DESCRIPTOR = _CECONITEMPREVIEWDATABLOCK_STICKER,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CEconItemPreviewDataBlock.Sticker)
    ))
  ,
  DESCRIPTOR = _CECONITEMPREVIEWDATABLOCK,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CEconItemPreviewDataBlock)
  ))
_sym_db.RegisterMessage(CEconItemPreviewDataBlock)
_sym_db.RegisterMessage(CEconItemPreviewDataBlock.Sticker)

CMsgGCCStrike15_v2_MatchEndRewardDropsNotification = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchEndRewardDropsNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHENDREWARDDROPSNOTIFICATION,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchEndRewardDropsNotification)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchEndRewardDropsNotification)

CMsgItemAcknowledged = _reflection.GeneratedProtocolMessageType('CMsgItemAcknowledged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGITEMACKNOWLEDGED,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgItemAcknowledged)
  ))
_sym_db.RegisterMessage(CMsgItemAcknowledged)

CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENT2GCECONPREVIEWDATABLOCKREQUEST,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockRequest)

CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENT2GCECONPREVIEWDATABLOCKRESPONSE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Client2GCEconPreviewDataBlockResponse)

CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_TOURNAMENTMATCHREWARDDROPSNOTIFICATION,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_TournamentMatchRewardDropsNotification)

CMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTCURRENTLIVEGAMES,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchListRequestCurrentLiveGames)

CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTLIVEGAMEFORUSER,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchListRequestLiveGameForUser)

CMsgGCCStrike15_v2_MatchListRequestRecentUserGames = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchListRequestRecentUserGames', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTRECENTUSERGAMES,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchListRequestRecentUserGames)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchListRequestRecentUserGames)

CMsgGCCStrike15_v2_MatchListRequestTournamentGames = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchListRequestTournamentGames', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTTOURNAMENTGAMES,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchListRequestTournamentGames)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchListRequestTournamentGames)

CMsgGCCStrike15_v2_MatchListRequestFullGameInfo = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchListRequestFullGameInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHLISTREQUESTFULLGAMEINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchListRequestFullGameInfo)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchListRequestFullGameInfo)

CDataGCCStrike15_v2_MatchInfo = _reflection.GeneratedProtocolMessageType('CDataGCCStrike15_v2_MatchInfo', (_message.Message,), dict(
  DESCRIPTOR = _CDATAGCCSTRIKE15_V2_MATCHINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CDataGCCStrike15_v2_MatchInfo)
  ))
_sym_db.RegisterMessage(CDataGCCStrike15_v2_MatchInfo)

CDataGCCStrike15_v2_TournamentGroupTeam = _reflection.GeneratedProtocolMessageType('CDataGCCStrike15_v2_TournamentGroupTeam', (_message.Message,), dict(
  DESCRIPTOR = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUPTEAM,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CDataGCCStrike15_v2_TournamentGroupTeam)
  ))
_sym_db.RegisterMessage(CDataGCCStrike15_v2_TournamentGroupTeam)

CDataGCCStrike15_v2_TournamentGroup = _reflection.GeneratedProtocolMessageType('CDataGCCStrike15_v2_TournamentGroup', (_message.Message,), dict(

  Picks = _reflection.GeneratedProtocolMessageType('Picks', (_message.Message,), dict(
    DESCRIPTOR = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP_PICKS,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CDataGCCStrike15_v2_TournamentGroup.Picks)
    ))
  ,
  DESCRIPTOR = _CDATAGCCSTRIKE15_V2_TOURNAMENTGROUP,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CDataGCCStrike15_v2_TournamentGroup)
  ))
_sym_db.RegisterMessage(CDataGCCStrike15_v2_TournamentGroup)
_sym_db.RegisterMessage(CDataGCCStrike15_v2_TournamentGroup.Picks)

CDataGCCStrike15_v2_TournamentSection = _reflection.GeneratedProtocolMessageType('CDataGCCStrike15_v2_TournamentSection', (_message.Message,), dict(
  DESCRIPTOR = _CDATAGCCSTRIKE15_V2_TOURNAMENTSECTION,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CDataGCCStrike15_v2_TournamentSection)
  ))
_sym_db.RegisterMessage(CDataGCCStrike15_v2_TournamentSection)

CDataGCCStrike15_v2_TournamentInfo = _reflection.GeneratedProtocolMessageType('CDataGCCStrike15_v2_TournamentInfo', (_message.Message,), dict(
  DESCRIPTOR = _CDATAGCCSTRIKE15_V2_TOURNAMENTINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CDataGCCStrike15_v2_TournamentInfo)
  ))
_sym_db.RegisterMessage(CDataGCCStrike15_v2_TournamentInfo)

CMsgGCCStrike15_v2_MatchList = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_MatchList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_MATCHLIST,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_MatchList)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_MatchList)

CMsgGCCStrike15_v2_Predictions = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Predictions', (_message.Message,), dict(

  GroupMatchTeamPick = _reflection.GeneratedProtocolMessageType('GroupMatchTeamPick', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PREDICTIONS_GROUPMATCHTEAMPICK,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick)
    ))
  ,
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PREDICTIONS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Predictions)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Predictions)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Predictions.GroupMatchTeamPick)

CMsgGCCStrike15_v2_Fantasy = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Fantasy', (_message.Message,), dict(

  FantasySlot = _reflection.GeneratedProtocolMessageType('FantasySlot', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_FANTASY_FANTASYSLOT,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Fantasy.FantasySlot)
    ))
  ,

  FantasyTeam = _reflection.GeneratedProtocolMessageType('FantasyTeam', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_FANTASY_FANTASYTEAM,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Fantasy.FantasyTeam)
    ))
  ,
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_FANTASY,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Fantasy)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Fantasy)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Fantasy.FantasySlot)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Fantasy.FantasyTeam)

CAttribute_String = _reflection.GeneratedProtocolMessageType('CAttribute_String', (_message.Message,), dict(
  DESCRIPTOR = _CATTRIBUTE_STRING,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CAttribute_String)
  ))
_sym_db.RegisterMessage(CAttribute_String)

CMsgGCToGCReloadVersions = _reflection.GeneratedProtocolMessageType('CMsgGCToGCReloadVersions', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCRELOADVERSIONS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCReloadVersions)
  ))
_sym_db.RegisterMessage(CMsgGCToGCReloadVersions)

CMsgCStrike15Welcome = _reflection.GeneratedProtocolMessageType('CMsgCStrike15Welcome', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCSTRIKE15WELCOME,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCStrike15Welcome)
  ))
_sym_db.RegisterMessage(CMsgCStrike15Welcome)

CMsgGCCStrike15_v2_ClientVarValueNotificationInfo = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientVarValueNotificationInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTVARVALUENOTIFICATIONINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientVarValueNotificationInfo)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientVarValueNotificationInfo)

CMsgGCCStrike15_v2_ServerVarValueNotificationInfo = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ServerVarValueNotificationInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_SERVERVARVALUENOTIFICATIONINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ServerVarValueNotificationInfo)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ServerVarValueNotificationInfo)

CMsgGCCStrike15_v2_GiftsLeaderboardRequest = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_GiftsLeaderboardRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDREQUEST,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_GiftsLeaderboardRequest)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_GiftsLeaderboardRequest)

CMsgGCCStrike15_v2_GiftsLeaderboardResponse = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_GiftsLeaderboardResponse', (_message.Message,), dict(

  GiftLeaderboardEntry = _reflection.GeneratedProtocolMessageType('GiftLeaderboardEntry', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE_GIFTLEADERBOARDENTRY,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_GiftsLeaderboardResponse.GiftLeaderboardEntry)
    ))
  ,
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_GIFTSLEADERBOARDRESPONSE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_GiftsLeaderboardResponse)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_GiftsLeaderboardResponse)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_GiftsLeaderboardResponse.GiftLeaderboardEntry)

CMsgGCCStrike15_v2_ClientSubmitSurveyVote = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientSubmitSurveyVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTSUBMITSURVEYVOTE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientSubmitSurveyVote)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientSubmitSurveyVote)

CMsgGCCStrike15_v2_Server2GCClientValidate = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Server2GCClientValidate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_SERVER2GCCLIENTVALIDATE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Server2GCClientValidate)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Server2GCClientValidate)

CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_SERVER2GCPURESERVERVALIDATIONFAILURE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Server2GCPureServerValidationFailure)

CMsgGCCStrike15_v2_GC2ClientTournamentInfo = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_GC2ClientTournamentInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_GC2CLIENTTOURNAMENTINFO,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_GC2ClientTournamentInfo)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_GC2ClientTournamentInfo)

CSOEconCoupon = _reflection.GeneratedProtocolMessageType('CSOEconCoupon', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONCOUPON,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconCoupon)
  ))
_sym_db.RegisterMessage(CSOEconCoupon)

CSOQuestProgress = _reflection.GeneratedProtocolMessageType('CSOQuestProgress', (_message.Message,), dict(
  DESCRIPTOR = _CSOQUESTPROGRESS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOQuestProgress)
  ))
_sym_db.RegisterMessage(CSOQuestProgress)

CSOPersonaDataPublic = _reflection.GeneratedProtocolMessageType('CSOPersonaDataPublic', (_message.Message,), dict(
  DESCRIPTOR = _CSOPERSONADATAPUBLIC,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOPersonaDataPublic)
  ))
_sym_db.RegisterMessage(CSOPersonaDataPublic)

CMsgGC_GlobalGame_Subscribe = _reflection.GeneratedProtocolMessageType('CMsgGC_GlobalGame_Subscribe', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGC_GLOBALGAME_SUBSCRIBE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGC_GlobalGame_Subscribe)
  ))
_sym_db.RegisterMessage(CMsgGC_GlobalGame_Subscribe)

CMsgGC_GlobalGame_Unsubscribe = _reflection.GeneratedProtocolMessageType('CMsgGC_GlobalGame_Unsubscribe', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGC_GLOBALGAME_UNSUBSCRIBE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGC_GlobalGame_Unsubscribe)
  ))
_sym_db.RegisterMessage(CMsgGC_GlobalGame_Unsubscribe)

CMsgGC_GlobalGame_Play = _reflection.GeneratedProtocolMessageType('CMsgGC_GlobalGame_Play', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGC_GLOBALGAME_PLAY,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGC_GlobalGame_Play)
  ))
_sym_db.RegisterMessage(CMsgGC_GlobalGame_Play)

CMsgGCCStrike15_v2_AcknowledgePenalty = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_AcknowledgePenalty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_ACKNOWLEDGEPENALTY,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_AcknowledgePenalty)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_AcknowledgePenalty)

CMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENT2GCREQUESTPRESTIGECOIN,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Client2GCRequestPrestigeCoin)

CMsgGCCStrike15_v2_Client2GCStreamUnlock = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Client2GCStreamUnlock', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENT2GCSTREAMUNLOCK,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Client2GCStreamUnlock)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Client2GCStreamUnlock)

CMsgGCCStrike15_v2_ClientToGCRequestElevate = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientToGCRequestElevate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTTOGCREQUESTELEVATE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientToGCRequestElevate)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientToGCRequestElevate)

CMsgGCCStrike15_v2_ClientToGCChat = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientToGCChat', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTTOGCCHAT,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientToGCChat)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientToGCChat)

CMsgGCCStrike15_v2_GCToClientChat = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_GCToClientChat', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_GCTOCLIENTCHAT,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_GCToClientChat)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_GCToClientChat)

CMsgGCCStrike15_v2_ClientAuthKeyCode = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientAuthKeyCode', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTAUTHKEYCODE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientAuthKeyCode)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientAuthKeyCode)

CMsgGCCStrike15_GotvSyncPacket = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_GotvSyncPacket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_GOTVSYNCPACKET,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_GotvSyncPacket)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_GotvSyncPacket)

PlayerDecalDigitalSignature = _reflection.GeneratedProtocolMessageType('PlayerDecalDigitalSignature', (_message.Message,), dict(
  DESCRIPTOR = _PLAYERDECALDIGITALSIGNATURE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:PlayerDecalDigitalSignature)
  ))
_sym_db.RegisterMessage(PlayerDecalDigitalSignature)

CMsgGCCStrike15_v2_ClientPlayerDecalSign = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientPlayerDecalSign', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTPLAYERDECALSIGN,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientPlayerDecalSign)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientPlayerDecalSign)

CMsgGCCStrike15_v2_ClientLogonFatalError = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientLogonFatalError', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTLOGONFATALERROR,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientLogonFatalError)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientLogonFatalError)

CMsgGCCStrike15_v2_ClientPollState = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientPollState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTPOLLSTATE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientPollState)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientPollState)

CMsgGCCStrike15_v2_Party_Register = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Party_Register', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PARTY_REGISTER,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Party_Register)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Party_Register)

CMsgGCCStrike15_v2_Party_Search = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Party_Search', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PARTY_SEARCH,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Party_Search)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Party_Search)

CMsgGCCStrike15_v2_Party_SearchResults = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Party_SearchResults', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS_ENTRY,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Party_SearchResults.Entry)
    ))
  ,
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PARTY_SEARCHRESULTS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Party_SearchResults)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Party_SearchResults)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Party_SearchResults.Entry)

CMsgGCCStrike15_v2_Party_Invite = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Party_Invite', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_PARTY_INVITE,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Party_Invite)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Party_Invite)

CMsgGCCStrike15_v2_Account_RequestCoPlays = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_Account_RequestCoPlays', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS_PLAYER,
    __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Account_RequestCoPlays.Player)
    ))
  ,
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_ACCOUNT_REQUESTCOPLAYS,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_Account_RequestCoPlays)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Account_RequestCoPlays)
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_Account_RequestCoPlays.Player)

CMsgGCCStrike15_v2_ClientToGCRequestTicket = _reflection.GeneratedProtocolMessageType('CMsgGCCStrike15_v2_ClientToGCRequestTicket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCSTRIKE15_V2_CLIENTTOGCREQUESTTICKET,
  __module__ = 'demoparser.protobufs.cstrike15_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCStrike15_v2_ClientToGCRequestTicket)
  ))
_sym_db.RegisterMessage(CMsgGCCStrike15_v2_ClientToGCRequestTicket)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\200\001\000'))
_CSOECONCOUPON.fields_by_name['entryid'].has_options = True
_CSOECONCOUPON.fields_by_name['entryid']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
_CSOQUESTPROGRESS.fields_by_name['questid'].has_options = True
_CSOQUESTPROGRESS.fields_by_name['questid']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\246\035\001'))
# @@protoc_insertion_point(module_scope)
